/**
 * @author Maksim Kaszynski
 *	@classDescription
 * Base class for drop zones
 */
DnD.Dropzone = function(){};
DnD.Dropzone.DROP_TARGET_ID = "dropTargetId";
DnD.Dropzone.prototype = {

	getElement: function() {
		return $(this.id);
	},

	getDnDParams: function() {
		var elt = this.getElement();
		var attr = elt.attributes["rich:dropdndparams"];
		var dndParams;

		if (attr) {
			dndParams = attr.value.parseJSON();
		}

		attr = elt.attributes["rich:defaultdndparams"];

		if (attr) {
			if (dndParams) {
				Object.extend(dndParams, attr.value.parseJSON());
			} else {
				dndParams = attr.value.parseJSON();
			}
		}

		return dndParams;
	},

	/**
	 *
	 * @param {Object} drag
	 * @return
	 */
	accept: function(drag) {
		return this.getAcceptedTypes().indexOf(drag.type) > -1 ;
	},
	getAcceptedTypes: function() {
		return [];
	},
	getTypeMapping: function() {
		return {};
	},
	drop: function(event, drag){
	},

	getIconCodeForType: function(type) {
		var types = this.getTypeMapping();
		if (type && types) {
			return types[type];
		}
		return null;
	},

	/**
	 * implementations call this method when mouse over them
	 * @param {Object} drag
	 */
	dragEnter: function(event) {
		var drag = window.drag;
		drag.dropzone = this;
		var indicator = drag.indicator;

		if (indicator) {
			var icon = this.getIconCodeForType(drag.type);

			var dndParams = drag.source.getDnDParams();
			if (dndParams) {
				Object.extend(dndParams, this.getDnDParams());
			} else {
				dndParams = this.getDnDParams();
			}

			if (dndParams) {
				if (icon) {
					dndParams['marker'] = dndParams[icon];
				} else {
					dndParams['marker'] = null;
				}
			}

            var accepts = this.accept(drag);
			var markerType = accepts ? "accept" : "reject";
            
            if (drag.source.getDraggableItems && drag.source.getDraggableItems() > 1) {
	            if (!dndParams) {
	            	dndParams = {};
	            }
	            
	            dndParams["draggableItems"] = drag.source.getDraggableItems();
	            
	            indicator.setContent(markerType, false, dndParams);
            } else {
	            indicator.setContent(markerType, true, dndParams);
            }

			if (accepts) {
				indicator.accept();
			} else {
				indicator.reject();
			}
		}
	},


	/**
	 * Implementations call this method when mouse exits them
	 * @param {Object} drag
	 */
	dragLeave: function(event) {
		var drag = window.drag;
		drag.dropzone = null;

		drag.source.setIndicator(event);

		var indicator = drag.indicator;
		if (indicator) {
			indicator.leave();
		}
		
	},

	dragUp: function(event) {		
		this.ondropend(event, drag);
		
		if( this.options && this.options.ondropend) {
			this.options.ondropend();
		}
	},


	ondropend: function(event) {
	},

	onafterdrag: function(event) {
	},

	onbeforedrag: function(event, drag){
	},

	ondragenter: function(event) {

	},
	ondragexit : function(event) {

	}

};

