/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.io.IOException;

import javax.faces.FacesException;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.el.MethodBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.ActionEvent;
import javax.faces.event.FacesEvent;
import javax.faces.event.PhaseId;

import org.ajax4jsf.ajax.UIAjaxSupport;
import org.ajax4jsf.dnd.Draggable;
import org.ajax4jsf.dnd.event.DragEvent;
import org.ajax4jsf.dnd.event.DragListener;
import org.ajax4jsf.framework.ajax.AjaxEvent;
import org.ajax4jsf.framework.ajax.AjaxSupport;
import org.ajax4jsf.framework.ajax.EventValueBinding;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.richfaces.renderkit.DnDParametersEncoder;
import org.richfaces.renderkit.DraggableRendererContributor;
import org.richfaces.renderkit.RendererContributor;
import org.richfaces.renderkit.ScriptOptions;

/**
 * JSF component class
 *
 */
public abstract class UIDragSupport extends UIAjaxSupport implements AjaxSupport, Draggable {
	
	private static final String COMPONENT_TYPE = "org.richfaces.DragSupport";
	
	private static final String COMPONENT_FAMILY = "org.richfaces.DragSupport";

	public void addDragListener(DragListener listener) {
		addFacesListener(listener);
	}

	public void removeDragListener(DragListener listener) {
		removeFacesListener(listener);
	}

	public DragListener[] getDragListeners() {
		return (DragListener[]) getFacesListeners(DragListener.class);
	}

	public void broadcast(FacesEvent event) throws AbortProcessingException {
		super.broadcast(event);
		if (event instanceof DragEvent) {
			MethodBinding binding = getDragListener();
			if (binding != null) {
				binding.invoke(getFacesContext(), new Object[] {event});
			}

			new AjaxEvent(this).queue();
			new ActionEvent(this).queue();
		}
	}

	public void setParentProperties(UIComponent component) {
		component.setValueBinding(getEvent(), new EventValueBinding(this));
	}
	
	public void queueEvent(FacesEvent event) {
		super.queueEvent(event);
		if (event instanceof DragEvent) {
			if (isImmediate()) {
				event.setPhaseId(PhaseId.APPLY_REQUEST_VALUES);
			} else {
				event.setPhaseId(PhaseId.INVOKE_APPLICATION);
			}
		}
	}
	
	public void setEvent(String event) {
		//TODO nick - exception message
		throw new UnsupportedOperationException();
	}
	
	public String getEventHandler(FacesContext context) {
        // Due to JSF RI 1.1 bug, clear cached clientId
        setId(getId());

        try {
			StringBuffer buffer = new StringBuffer("if (this.draggable) { this.draggable.eventMouseDown(event); return ;} this.draggable = ");
			JSFunction function = new JSFunction("new DnD.SimpleDraggable");
			function.addParameter(this.getParent().getClientId(context));
			RendererContributor contributor = DraggableRendererContributor.getInstance();
			ScriptOptions dragOptions = contributor.buildOptions(context, this);
			
			DnDParametersEncoder parametersEncoder = DnDParametersEncoder.getInstance();
			dragOptions.addOption("dndParams", parametersEncoder.doEncodeAsString(context, this));
			
			function.addParameter(dragOptions);
			function.appendScript(buffer);

			String scriptContribution = contributor.getScriptContribution(context, this);
			if (scriptContribution != null && scriptContribution.length() != 0) {
				buffer.append("; this.draggable" + scriptContribution);
			}

			buffer.append("; this.draggable.eventMouseDown(event);");

			return buffer.toString();
		} catch (IOException e) {
			throw new FacesException(e);
		}
	}
	
	public String getEventString() {
		FacesContext context = FacesContext.getCurrentInstance();
		return getEventHandler(context);
	}
	
	public String getEvent() {
		return "onmousedown";
	}
}
