/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.io.IOException;

import javax.faces.FacesException;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.el.MethodBinding;
import javax.faces.event.AbortProcessingException;
import javax.faces.event.ActionEvent;
import javax.faces.event.FacesEvent;
import javax.faces.event.PhaseId;

import org.ajax4jsf.ajax.UIAjaxSupport;
import org.ajax4jsf.dnd.Dropzone;
import org.ajax4jsf.dnd.event.DropEvent;
import org.ajax4jsf.dnd.event.DropListener;
import org.ajax4jsf.framework.ajax.AjaxEvent;
import org.ajax4jsf.framework.ajax.AjaxSupport;
import org.ajax4jsf.framework.ajax.EventValueBinding;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.richfaces.renderkit.DnDParametersEncoder;
import org.richfaces.renderkit.DropzoneRendererContributor;
import org.richfaces.renderkit.RendererContributor;
import org.richfaces.renderkit.ScriptOptions;

/**
 * JSF component class
 *
 */
public abstract class UIDropSupport extends UIAjaxSupport implements AjaxSupport, Dropzone {

	private static final String COMPONENT_TYPE = "org.richfaces.DropSupport";

	private static final String COMPONENT_FAMILY = "org.richfaces.DropSupport";

	public void addDropListener(DropListener listener) {
		addFacesListener(listener);
	}

	public void removeDropListener(DropListener listener) {
		removeFacesListener(listener);
	}

	public DropListener[] getDropListeners() {
		return (DropListener[]) getFacesListeners(DropListener.class);
	}

	public void setParentProperties(UIComponent component) {
		component.setValueBinding(getEvent(), new EventValueBinding(this));
	}

	public void broadcast(FacesEvent event) throws AbortProcessingException {
		super.broadcast(event);
		if (event instanceof DropEvent) {
			MethodBinding binding = getDropListener();
			if (binding != null) {
				binding.invoke(getFacesContext(), new Object[] {event});
			}

			new AjaxEvent(this).queue();
			new ActionEvent(this).queue();
			
		}
	}

	public void queueEvent(FacesEvent event) {
		super.queueEvent(event);
		if (event instanceof DropEvent) {
			if (isImmediate()) {
				event.setPhaseId(PhaseId.APPLY_REQUEST_VALUES);
			} else {
				event.setPhaseId(PhaseId.INVOKE_APPLICATION);
			}
		}
	}

	public String getEventString() {
        // Due to JSF RI 1.1 bug, clear cached clientId
        setId(getId());

		try {
			FacesContext context = FacesContext.getCurrentInstance();

			RendererContributor contributor = DropzoneRendererContributor.getInstance();
			StringBuffer buffer = new StringBuffer("if (this.dropZone) { this.dropZone.mouseoverBound(event); return ;} this.dropZone = ");
			JSFunction function = new JSFunction("new DnD.SimpleDropZone");
			function.addParameter(this.getParent().getClientId(context));
			ScriptOptions dropOptions = contributor.buildOptions(context, this);

			DnDParametersEncoder parametersEncoder = DnDParametersEncoder.getInstance();
			dropOptions.addOption("dndParams", parametersEncoder.doEncodeAsString(context, this));

			function.addParameter(dropOptions);
			function.appendScript(buffer);

			String scriptContribution = contributor.getScriptContribution(context, this);
			if (scriptContribution != null && scriptContribution.length() != 0) {
				buffer.append("; this.dropZone" + scriptContribution);
			}

			return buffer.toString() + "; this.dropZone.mouseoverBound(event);";
		} catch (IOException e) {
			throw new FacesException(e);
		}
	}

	public void setEvent(String event) {
		//TODO nick - exception message
		throw new UnsupportedOperationException();
	}

	public String getEvent() {
		return "onmouseover";
	}

}
