/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component;

import java.util.Iterator;

import javax.faces.component.UIComponent;

import org.richfaces.model.Tab;

/**
 * JSF component class
 *
 */
public abstract class UITabPanel extends UISwitchablePanel
{
    public static final String COMPONENT_TYPE = "org.richfaces.TabPanel";

    public boolean getRendersChildren() {
    	return true;
    }
    
    protected Iterator getSwitchedFacetsAndChildren() {
    	final Object renderedValue = getRenderedValue();
    	
    	return new TabsIterator(this, new TabsIterator.FilterCondition() {

			public boolean isSuitable(UITab tab) {
				if (CLIENT_METHOD.equals(tab.getSwitchType())) {
					
					return true;
				}
				
				Object name = tab.getName();
				
				return name != null && name.equals(renderedValue);
			}
    		
    	});
    }
    
	public Object convertSwitchValue(UIComponent component, Object object) {
		if (object != null) {
			return object;
		}
		
		return ((UITab) component).getName();
	}
	
	/**
	 * Get value for current selected tab. Possible classes - prefered {@link Integer} for tab number, or other Object for tab model value.
	 * @return
	 */
	public abstract Object getSelectedTab();
	
	/**
	 * Set currently selected tab.
	 * @param tab
	 */
	public abstract void setSelectedTab(Object tab);
	
	
	/**
	 * Create iterator for all tabs in this component ( in future, can be added special attribute for tabs collection.
	 * {@link Iterator#next()} method will return tab model - {@link Tab}
	 * @return
	 */
	public Iterator getTabs() {
		return new TabsIterator(this);
	}

	/**
	 * Get Tab selection behavior for panel - one of "client", "server", "ajax", "page".
	 * @return
	 */
	public abstract String getSwitchType();

	/**
	 * Set Tab selection behavior for panel - one of "client", "server", "ajax", "page".
	 * @param newvalue
	 */
	public abstract void setSwitchType(String newvalue);
	
	/**
	 * Get headers alignment - one of "left", "center" and "right".
	 * @return
	 */
	public abstract String getHeaderAlignment();
	
	/**
	 * Set headers alignment - one of "left", "center" and "right".
	 * @param newAlignment
	 */
	public abstract void setHeaderAlignment(String newAlignment);

	public abstract String getHeaderSpacing();

	public abstract void setHeaderSpacing(String value);
}
