/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIDataTable ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.DataTable
 * Component-Family org.richfaces.DataTable
  	 * Renderer-Type org.richfaces.DataTableRenderer
  	 * 
 */
 public class HtmlDataTable extends org.richfaces.component.UIDataTable {

  public static final String COMPONENT_TYPE = "org.richfaces.DataTable";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlDataTable (){
  	  	setRendererType("org.richfaces.DataTableRenderer");
  	  }

// Component properties fields
  	/**
	 * cellpadding
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private String  _cellpadding = null; /* Default is "0"*/
	 	  	/**
	 * width
	 * This attribute specifies the desired width of the entire table and is intended for visual user agents. When the value is percentage value, the value is relative to the user agent's available horizontal space. In the absence of any width specification, table width is determined by the user agent
	 */
	 	 private String  _width = null; /* Default is null*/
	 	   	/**
	 * rowClasses
	 * A comma-delimited list of CSS style classes that is applied to popup table rows. A space separated list of classes may also be specified for any individual row. Thes styles are applied, in turn, to each row in the table. For example, if the list has two elements, the first style class in the list is applied to the first row, the second to the second row, the first to the third row, the second to the fourth row, etc. In other words, we keep iterating through the list until we reach the end, and then we start at the beginning again.
	 */
	 	 private String  _rowClasses = null; /* Default is null*/
	 	  	/**
	 * title
	 * Advisory title information about markup elements generated for this component
	 */
	 	 private String  _title = null; /* Default is null*/
	 	  	/**
	 * rules
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 */
	 	 private String  _rules = null; /* Default is null*/
	 	   	/**
	 * onRowClick
	 * 
	 */
	 	 private String  _onRowClick = null; /* Default is null*/
	 	  	/**
	 * onRowDblClick
	 * 
	 */
	 	 private String  _onRowDblClick = null; /* Default is null*/
	 	  	/**
	 * onRowMouseDown
	 * 
	 */
	 	 private String  _onRowMouseDown = null; /* Default is null*/
	 	  	/**
	 * columns
	 * 
	 */
	 	 private int  _columns = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what columns is set.
	 */
	 private boolean _columnsSet = false;	
	 	   	/**
	 * footerClass
	 * 
	 */
	 	 private String  _footerClass = null; /* Default is null*/
	 	  	/**
	 * captionStyle
	 * 
	 */
	 	 private String  _captionStyle = null; /* Default is null*/
	 	  	/**
	 * dir
	 * Alternate textual description of the element rendered by this component
	 */
	 	 private String  _dir = null; /* Default is null*/
	 	    	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	   	/**
	 * captionClass
	 * 
	 */
	 	 private String  _captionClass = null; /* Default is null*/
	 	   	/**
	 * align
	 * left|center|right [CI]
            Deprecated. This attribute specifies the position of the table with respect to the document. Permitted values:
            
            * left: The table is to the left of the document.
            * center: The table is to the center of the document.
            * right: The table is to the right of the document.
	 */
	 	 private String  _align = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * border
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private String  _border = null; /* Default is "0"*/
	 	  	/**
	 * bgcolor
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 */
	 	 private String  _bgcolor = null; /* Default is null*/
	 	   	/**
	 * onRowMouseOver
	 * 
	 */
	 	 private String  _onRowMouseOver = null; /* Default is null*/
	 	   	/**
	 * summary
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 */
	 	 private String  _summary = null; /* Default is null*/
	 	     	/**
	 * onRowMouseUp
	 * 
	 */
	 	 private String  _onRowMouseUp = null; /* Default is null*/
	 	  	/**
	 * lang
	 * Code describing the language used in the generated markup for this component
	 */
	 	 private String  _lang = null; /* Default is null*/
	 	  	/**
	 * columnClasses
	 * Comma-delimited list of CSS style classes that are be applied to the columns of this table. A space separated list of classes may also be specified for any individual column. If the number of elements in this list is less than the number of columns specified in the "columns" attribute, no "class" attribute is output for each column greater than the number of elements in the list. If the number of elements in the list is greater than the number of columns specified in the "columns" attribute, the elements at the posisiton in the list after the value of the "columns" attribute are ignored.
	 */
	 	 private String  _columnClasses = null; /* Default is null*/
	 	    	/**
	 * cellspacing
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private String  _cellspacing = null; /* Default is "0"*/
	 	  	/**
	 * headerClass
	 * 
	 */
	 	 private String  _headerClass = null; /* Default is null*/
	 	  	/**
	 * onRowMouseMove
	 * 
	 */
	 	 private String  _onRowMouseMove = null; /* Default is null*/
	 	  	/**
	 * frame
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 */
	 	 private String  _frame = null; /* Default is null*/
	 	  	/**
	 * onRowMouseOut
	 * 
	 */
	 	 private String  _onRowMouseOut = null; /* Default is null*/
	 	  	/**
	 * columnsWidth
	 * Comma-separated list of width attribute for every column.
			Specifies a default width for each column in the table. 
			In addition to the standard pixel, percentage, and relative values, 
			this attribute allows the special form "0*" (zero asterisk) which 
			means that the width of the each column in the group should be the minimum width necessary 
			to hold the column's contents. This implies that a column's entire contents must be known before its width may be correctly computed. Authors should be aware that specifying "0*" will prevent visual user agents from rendering a table incrementally.
	 */
	 	 private String  _columnsWidth = null; /* Default is null*/
	 	   
// Getters-setters
  	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for cellpadding
	 * @param cellpadding - new value
	 */
	 public void setCellpadding( String  __cellpadding ){
		this._cellpadding = __cellpadding;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for cellpadding
	 * @return cellpadding value from local variable or value bindings
	 */
	 public String getCellpadding(  ){
	         if (null != this._cellpadding)
        {
            return this._cellpadding;
        	    }
        ValueBinding vb = getValueBinding("cellpadding");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "0";
        }
	 	 }
	   	/*
	 * This attribute specifies the desired width of the entire table and is intended for visual user agents. When the value is percentage value, the value is relative to the user agent's available horizontal space. In the absence of any width specification, table width is determined by the user agent
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * This attribute specifies the desired width of the entire table and is intended for visual user agents. When the value is percentage value, the value is relative to the user agent's available horizontal space. In the absence of any width specification, table width is determined by the user agent
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A comma-delimited list of CSS style classes that is applied to popup table rows. A space separated list of classes may also be specified for any individual row. Thes styles are applied, in turn, to each row in the table. For example, if the list has two elements, the first style class in the list is applied to the first row, the second to the second row, the first to the third row, the second to the fourth row, etc. In other words, we keep iterating through the list until we reach the end, and then we start at the beginning again.
	 * Setter for rowClasses
	 * @param rowClasses - new value
	 */
	 public void setRowClasses( String  __rowClasses ){
		this._rowClasses = __rowClasses;
	 	 }


	/*
	 * A comma-delimited list of CSS style classes that is applied to popup table rows. A space separated list of classes may also be specified for any individual row. Thes styles are applied, in turn, to each row in the table. For example, if the list has two elements, the first style class in the list is applied to the first row, the second to the second row, the first to the third row, the second to the fourth row, etc. In other words, we keep iterating through the list until we reach the end, and then we start at the beginning again.
	 * Getter for rowClasses
	 * @return rowClasses value from local variable or value bindings
	 */
	 public String getRowClasses(  ){
	         if (null != this._rowClasses)
        {
            return this._rowClasses;
        	    }
        ValueBinding vb = getValueBinding("rowClasses");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Advisory title information about markup elements generated for this component
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * Advisory title information about markup elements generated for this component
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 * Setter for rules
	 * @param rules - new value
	 */
	 public void setRules( String  __rules ){
		this._rules = __rules;
	 	 }


	/*
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 * Getter for rules
	 * @return rules value from local variable or value bindings
	 */
	 public String getRules(  ){
	         if (null != this._rules)
        {
            return this._rules;
        	    }
        ValueBinding vb = getValueBinding("rules");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for onRowClick
	 * @param onRowClick - new value
	 */
	 public void setOnRowClick( String  __onRowClick ){
		this._onRowClick = __onRowClick;
	 	 }


	/*
	 * 
	 * Getter for onRowClick
	 * @return onRowClick value from local variable or value bindings
	 */
	 public String getOnRowClick(  ){
	         if (null != this._onRowClick)
        {
            return this._onRowClick;
        	    }
        ValueBinding vb = getValueBinding("onRowClick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for onRowDblClick
	 * @param onRowDblClick - new value
	 */
	 public void setOnRowDblClick( String  __onRowDblClick ){
		this._onRowDblClick = __onRowDblClick;
	 	 }


	/*
	 * 
	 * Getter for onRowDblClick
	 * @return onRowDblClick value from local variable or value bindings
	 */
	 public String getOnRowDblClick(  ){
	         if (null != this._onRowDblClick)
        {
            return this._onRowDblClick;
        	    }
        ValueBinding vb = getValueBinding("onRowDblClick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for onRowMouseDown
	 * @param onRowMouseDown - new value
	 */
	 public void setOnRowMouseDown( String  __onRowMouseDown ){
		this._onRowMouseDown = __onRowMouseDown;
	 	 }


	/*
	 * 
	 * Getter for onRowMouseDown
	 * @return onRowMouseDown value from local variable or value bindings
	 */
	 public String getOnRowMouseDown(  ){
	         if (null != this._onRowMouseDown)
        {
            return this._onRowMouseDown;
        	    }
        ValueBinding vb = getValueBinding("onRowMouseDown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for columns
	 * @param columns - new value
	 */
	 public void setColumns( int  __columns ){
		this._columns = __columns;
	 		this._columnsSet = true;
	 	 }


	/*
	 * 
	 * Getter for columns
	 * @return columns value from local variable or value bindings
	 */
	 public int getColumns(  ){
	 		 if(this._columnsSet){
			return this._columns;
		 }
    	ValueBinding vb = getValueBinding("columns");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._columns;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._columns);
    	}
	 	 }
	    	/*
	 * 
	 * Setter for footerClass
	 * @param footerClass - new value
	 */
	 public void setFooterClass( String  __footerClass ){
		this._footerClass = __footerClass;
	 	 }


	/*
	 * 
	 * Getter for footerClass
	 * @return footerClass value from local variable or value bindings
	 */
	 public String getFooterClass(  ){
	         if (null != this._footerClass)
        {
            return this._footerClass;
        	    }
        ValueBinding vb = getValueBinding("footerClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for captionStyle
	 * @param captionStyle - new value
	 */
	 public void setCaptionStyle( String  __captionStyle ){
		this._captionStyle = __captionStyle;
	 	 }


	/*
	 * 
	 * Getter for captionStyle
	 * @return captionStyle value from local variable or value bindings
	 */
	 public String getCaptionStyle(  ){
	         if (null != this._captionStyle)
        {
            return this._captionStyle;
        	    }
        ValueBinding vb = getValueBinding("captionStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Alternate textual description of the element rendered by this component
	 * Setter for dir
	 * @param dir - new value
	 */
	 public void setDir( String  __dir ){
		this._dir = __dir;
	 	 }


	/*
	 * Alternate textual description of the element rendered by this component
	 * Getter for dir
	 * @return dir value from local variable or value bindings
	 */
	 public String getDir(  ){
	         if (null != this._dir)
        {
            return this._dir;
        	    }
        ValueBinding vb = getValueBinding("dir");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for captionClass
	 * @param captionClass - new value
	 */
	 public void setCaptionClass( String  __captionClass ){
		this._captionClass = __captionClass;
	 	 }


	/*
	 * 
	 * Getter for captionClass
	 * @return captionClass value from local variable or value bindings
	 */
	 public String getCaptionClass(  ){
	         if (null != this._captionClass)
        {
            return this._captionClass;
        	    }
        ValueBinding vb = getValueBinding("captionClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * left|center|right [CI]
            Deprecated. This attribute specifies the position of the table with respect to the document. Permitted values:
            
            * left: The table is to the left of the document.
            * center: The table is to the center of the document.
            * right: The table is to the right of the document.
	 * Setter for align
	 * @param align - new value
	 */
	 public void setAlign( String  __align ){
		this._align = __align;
	 	 }


	/*
	 * left|center|right [CI]
            Deprecated. This attribute specifies the position of the table with respect to the document. Permitted values:
            
            * left: The table is to the left of the document.
            * center: The table is to the center of the document.
            * right: The table is to the right of the document.
	 * Getter for align
	 * @return align value from local variable or value bindings
	 */
	 public String getAlign(  ){
	         if (null != this._align)
        {
            return this._align;
        	    }
        ValueBinding vb = getValueBinding("align");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for border
	 * @param border - new value
	 */
	 public void setBorder( String  __border ){
		this._border = __border;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for border
	 * @return border value from local variable or value bindings
	 */
	 public String getBorder(  ){
	         if (null != this._border)
        {
            return this._border;
        	    }
        ValueBinding vb = getValueBinding("border");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "0";
        }
	 	 }
	   	/*
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 * Setter for bgcolor
	 * @param bgcolor - new value
	 */
	 public void setBgcolor( String  __bgcolor ){
		this._bgcolor = __bgcolor;
	 	 }


	/*
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 * Getter for bgcolor
	 * @return bgcolor value from local variable or value bindings
	 */
	 public String getBgcolor(  ){
	         if (null != this._bgcolor)
        {
            return this._bgcolor;
        	    }
        ValueBinding vb = getValueBinding("bgcolor");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * 
	 * Setter for onRowMouseOver
	 * @param onRowMouseOver - new value
	 */
	 public void setOnRowMouseOver( String  __onRowMouseOver ){
		this._onRowMouseOver = __onRowMouseOver;
	 	 }


	/*
	 * 
	 * Getter for onRowMouseOver
	 * @return onRowMouseOver value from local variable or value bindings
	 */
	 public String getOnRowMouseOver(  ){
	         if (null != this._onRowMouseOver)
        {
            return this._onRowMouseOver;
        	    }
        ValueBinding vb = getValueBinding("onRowMouseOver");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 * Setter for summary
	 * @param summary - new value
	 */
	 public void setSummary( String  __summary ){
		this._summary = __summary;
	 	 }


	/*
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 * Getter for summary
	 * @return summary value from local variable or value bindings
	 */
	 public String getSummary(  ){
	         if (null != this._summary)
        {
            return this._summary;
        	    }
        ValueBinding vb = getValueBinding("summary");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	      	/*
	 * 
	 * Setter for onRowMouseUp
	 * @param onRowMouseUp - new value
	 */
	 public void setOnRowMouseUp( String  __onRowMouseUp ){
		this._onRowMouseUp = __onRowMouseUp;
	 	 }


	/*
	 * 
	 * Getter for onRowMouseUp
	 * @return onRowMouseUp value from local variable or value bindings
	 */
	 public String getOnRowMouseUp(  ){
	         if (null != this._onRowMouseUp)
        {
            return this._onRowMouseUp;
        	    }
        ValueBinding vb = getValueBinding("onRowMouseUp");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Code describing the language used in the generated markup for this component
	 * Setter for lang
	 * @param lang - new value
	 */
	 public void setLang( String  __lang ){
		this._lang = __lang;
	 	 }


	/*
	 * Code describing the language used in the generated markup for this component
	 * Getter for lang
	 * @return lang value from local variable or value bindings
	 */
	 public String getLang(  ){
	         if (null != this._lang)
        {
            return this._lang;
        	    }
        ValueBinding vb = getValueBinding("lang");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Comma-delimited list of CSS style classes that are be applied to the columns of this table. A space separated list of classes may also be specified for any individual column. If the number of elements in this list is less than the number of columns specified in the "columns" attribute, no "class" attribute is output for each column greater than the number of elements in the list. If the number of elements in the list is greater than the number of columns specified in the "columns" attribute, the elements at the posisiton in the list after the value of the "columns" attribute are ignored.
	 * Setter for columnClasses
	 * @param columnClasses - new value
	 */
	 public void setColumnClasses( String  __columnClasses ){
		this._columnClasses = __columnClasses;
	 	 }


	/*
	 * Comma-delimited list of CSS style classes that are be applied to the columns of this table. A space separated list of classes may also be specified for any individual column. If the number of elements in this list is less than the number of columns specified in the "columns" attribute, no "class" attribute is output for each column greater than the number of elements in the list. If the number of elements in the list is greater than the number of columns specified in the "columns" attribute, the elements at the posisiton in the list after the value of the "columns" attribute are ignored.
	 * Getter for columnClasses
	 * @return columnClasses value from local variable or value bindings
	 */
	 public String getColumnClasses(  ){
	         if (null != this._columnClasses)
        {
            return this._columnClasses;
        	    }
        ValueBinding vb = getValueBinding("columnClasses");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for cellspacing
	 * @param cellspacing - new value
	 */
	 public void setCellspacing( String  __cellspacing ){
		this._cellspacing = __cellspacing;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for cellspacing
	 * @return cellspacing value from local variable or value bindings
	 */
	 public String getCellspacing(  ){
	         if (null != this._cellspacing)
        {
            return this._cellspacing;
        	    }
        ValueBinding vb = getValueBinding("cellspacing");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "0";
        }
	 	 }
	   	/*
	 * 
	 * Setter for headerClass
	 * @param headerClass - new value
	 */
	 public void setHeaderClass( String  __headerClass ){
		this._headerClass = __headerClass;
	 	 }


	/*
	 * 
	 * Getter for headerClass
	 * @return headerClass value from local variable or value bindings
	 */
	 public String getHeaderClass(  ){
	         if (null != this._headerClass)
        {
            return this._headerClass;
        	    }
        ValueBinding vb = getValueBinding("headerClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for onRowMouseMove
	 * @param onRowMouseMove - new value
	 */
	 public void setOnRowMouseMove( String  __onRowMouseMove ){
		this._onRowMouseMove = __onRowMouseMove;
	 	 }


	/*
	 * 
	 * Getter for onRowMouseMove
	 * @return onRowMouseMove value from local variable or value bindings
	 */
	 public String getOnRowMouseMove(  ){
	         if (null != this._onRowMouseMove)
        {
            return this._onRowMouseMove;
        	    }
        ValueBinding vb = getValueBinding("onRowMouseMove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 * Setter for frame
	 * @param frame - new value
	 */
	 public void setFrame( String  __frame ){
		this._frame = __frame;
	 	 }


	/*
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 * Getter for frame
	 * @return frame value from local variable or value bindings
	 */
	 public String getFrame(  ){
	         if (null != this._frame)
        {
            return this._frame;
        	    }
        ValueBinding vb = getValueBinding("frame");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for onRowMouseOut
	 * @param onRowMouseOut - new value
	 */
	 public void setOnRowMouseOut( String  __onRowMouseOut ){
		this._onRowMouseOut = __onRowMouseOut;
	 	 }


	/*
	 * 
	 * Getter for onRowMouseOut
	 * @return onRowMouseOut value from local variable or value bindings
	 */
	 public String getOnRowMouseOut(  ){
	         if (null != this._onRowMouseOut)
        {
            return this._onRowMouseOut;
        	    }
        ValueBinding vb = getValueBinding("onRowMouseOut");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Comma-separated list of width attribute for every column.
			Specifies a default width for each column in the table. 
			In addition to the standard pixel, percentage, and relative values, 
			this attribute allows the special form "0*" (zero asterisk) which 
			means that the width of the each column in the group should be the minimum width necessary 
			to hold the column's contents. This implies that a column's entire contents must be known before its width may be correctly computed. Authors should be aware that specifying "0*" will prevent visual user agents from rendering a table incrementally.
	 * Setter for columnsWidth
	 * @param columnsWidth - new value
	 */
	 public void setColumnsWidth( String  __columnsWidth ){
		this._columnsWidth = __columnsWidth;
	 	 }


	/*
	 * Comma-separated list of width attribute for every column.
			Specifies a default width for each column in the table. 
			In addition to the standard pixel, percentage, and relative values, 
			this attribute allows the special form "0*" (zero asterisk) which 
			means that the width of the each column in the group should be the minimum width necessary 
			to hold the column's contents. This implies that a column's entire contents must be known before its width may be correctly computed. Authors should be aware that specifying "0*" will prevent visual user agents from rendering a table incrementally.
	 * Getter for columnsWidth
	 * @return columnsWidth value from local variable or value bindings
	 */
	 public String getColumnsWidth(  ){
	         if (null != this._columnsWidth)
        {
            return this._columnsWidth;
        	    }
        ValueBinding vb = getValueBinding("columnsWidth");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.DataTable";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[31];
        values[0] = super.saveState(context);
  	 	          values[1] = _cellpadding;
	   	 	
  	 	          values[2] = _width;
	   	 	
   	 	          values[3] = _rowClasses;
	   	 	
  	 	          values[4] = _title;
	   	 	
  	 	          values[5] = _rules;
	   	 	
   	 	          values[6] = _onRowClick;
	   	 	
  	 	          values[7] = _onRowDblClick;
	   	 	
  	 	          values[8] = _onRowMouseDown;
	   	 	
  	        values[9] = new Integer(_columns);
	   	   values[10] = Boolean.valueOf(_columnsSet);	
	   	 	
   	 	          values[11] = _footerClass;
	   	 	
  	 	          values[12] = _captionStyle;
	   	 	
  	 	          values[13] = _dir;
	   	 	
    	 	          values[14] = _styleClass;
	   	 	
   	 	          values[15] = _captionClass;
	   	 	
   	 	          values[16] = _align;
	   	 	
  	 	          values[17] = _style;
	   	 	
  	 	          values[18] = _border;
	   	 	
  	 	          values[19] = _bgcolor;
	   	 	
   	 	          values[20] = _onRowMouseOver;
	   	 	
   	 	          values[21] = _summary;
	   	 	
     	 	          values[22] = _onRowMouseUp;
	   	 	
  	 	          values[23] = _lang;
	   	 	
  	 	          values[24] = _columnClasses;
	   	 	
    	 	          values[25] = _cellspacing;
	   	 	
  	 	          values[26] = _headerClass;
	   	 	
  	 	          values[27] = _onRowMouseMove;
	   	 	
  	 	          values[28] = _frame;
	   	 	
  	 	          values[29] = _onRowMouseOut;
	   	 	
  	 	          values[30] = _columnsWidth;
	   	 	
   	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _cellpadding = (String)values[1] ;
	   	 	
  	 	          _width = (String)values[2] ;
	   	 	
   	 	          _rowClasses = (String)values[3] ;
	   	 	
  	 	          _title = (String)values[4] ;
	   	 	
  	 	          _rules = (String)values[5] ;
	   	 	
   	 	          _onRowClick = (String)values[6] ;
	   	 	
  	 	          _onRowDblClick = (String)values[7] ;
	   	 	
  	 	          _onRowMouseDown = (String)values[8] ;
	   	 	
  	        _columns = ((Integer)values[9]).intValue();
	   	   _columnsSet = ((Boolean)values[10]).booleanValue();	
	   	 	
   	 	          _footerClass = (String)values[11] ;
	   	 	
  	 	          _captionStyle = (String)values[12] ;
	   	 	
  	 	          _dir = (String)values[13] ;
	   	 	
    	 	          _styleClass = (String)values[14] ;
	   	 	
   	 	          _captionClass = (String)values[15] ;
	   	 	
   	 	          _align = (String)values[16] ;
	   	 	
  	 	          _style = (String)values[17] ;
	   	 	
  	 	          _border = (String)values[18] ;
	   	 	
  	 	          _bgcolor = (String)values[19] ;
	   	 	
   	 	          _onRowMouseOver = (String)values[20] ;
	   	 	
   	 	          _summary = (String)values[21] ;
	   	 	
     	 	          _onRowMouseUp = (String)values[22] ;
	   	 	
  	 	          _lang = (String)values[23] ;
	   	 	
  	 	          _columnClasses = (String)values[24] ;
	   	 	
    	 	          _cellspacing = (String)values[25] ;
	   	 	
  	 	          _headerClass = (String)values[26] ;
	   	 	
  	 	          _onRowMouseMove = (String)values[27] ;
	   	 	
  	 	          _frame = (String)values[28] ;
	   	 	
  	 	          _onRowMouseOut = (String)values[29] ;
	   	 	
  	 	          _columnsWidth = (String)values[30] ;
	   	 	
   	
		
	}	
// Utilites

}