/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIDragIndicator ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.DragIndicator
 * Component-Family org.richfaces.DragIndicator
  	 * Renderer-Type org.richfaces.DragIndicatorRenderer
  	 * It's a component appearing under a mouse cursor during Drag'n'Drop operation and containing information on dragged element and elements.
 */
 public class HtmlDragIndicator extends org.richfaces.component.UIDragIndicator {

  public static final String COMPONENT_TYPE = "org.richfaces.DragIndicator";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlDragIndicator (){
  	  	setRendererType("org.richfaces.DragIndicatorRenderer");
  	  }

// Component properties fields
 	/**
	 * acceptClass
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is accepted
	 */
	 	 private String  _acceptClass = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * rejectClass
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is rejected
	 */
	 	 private String  _rejectClass = null; /* Default is null*/
	 	    
// Getters-setters
 	/*
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is accepted
	 * Setter for acceptClass
	 * @param acceptClass - new value
	 */
	 public void setAcceptClass( String  __acceptClass ){
		this._acceptClass = __acceptClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is accepted
	 * Getter for acceptClass
	 * @return acceptClass value from local variable or value bindings
	 */
	 public String getAcceptClass(  ){
	         if (null != this._acceptClass)
        {
            return this._acceptClass;
        	    }
        ValueBinding vb = getValueBinding("acceptClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is rejected
	 * Setter for rejectClass
	 * @param rejectClass - new value
	 */
	 public void setRejectClass( String  __rejectClass ){
		this._rejectClass = __rejectClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute and added to an indicator when a drop is rejected
	 * Getter for rejectClass
	 * @return rejectClass value from local variable or value bindings
	 */
	 public String getRejectClass(  ){
	         if (null != this._rejectClass)
        {
            return this._rejectClass;
        	    }
        ValueBinding vb = getValueBinding("rejectClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.DragIndicator";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[4];
        values[0] = super.saveState(context);
 	 	          values[1] = _acceptClass;
	   	 	
  	 	          values[2] = _styleClass;
	   	 	
  	 	          values[3] = _rejectClass;
	   	 	
    	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _acceptClass = (String)values[1] ;
	   	 	
  	 	          _styleClass = (String)values[2] ;
	   	 	
  	 	          _rejectClass = (String)values[3] ;
	   	 	
    	
		
	}	
// Utilites

}