/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIInputNumberSlider ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.inputNumberSlider
 * Component-Family org.richfaces.inputNumberSlider
  	 * Renderer-Type org.richfaces.InputNumberSliderRenderer
  	 * A component that lets selecting a number from a numeric region. It is a horizontal
    		aligned scroll-like control with its own input field (optional) present. The keyboard input in a
		    field is possible (optional. Also it is possible to see the current value in the tool tip above a
		    dragged handle control.
 */
 public class HtmlInputNumberSlider extends org.richfaces.component.UIInputNumberSlider {

  public static final String COMPONENT_TYPE = "org.richfaces.inputNumberSlider";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlInputNumberSlider (){
  	  	setRendererType("org.richfaces.InputNumberSliderRenderer");
  	  }

// Component properties fields
  	/**
	 * width
	 * The width of a slider control.
	 */
	 	 private String  _width = null; /* Default is "200px"*/
	 	    	/**
	 * onchange
	 * HTML: script expression; the element value was changed
	 */
	 	 private String  _onchange = null; /* Default is null*/
	 	  	/**
	 * showToolTip
	 * If the current value will be shown in the tooltip when a handle control in a
	    	"dragged" state.Default=true.
	 */
	 	 private boolean  _showToolTip = true;		
	/**
	 * Flag indicated what showToolTip is set.
	 */
	 private boolean _showToolTipSet = false;	
	 	  	/**
	 * inputStyle
	 * Style attribute for text field.
	 */
	 	 private String  _inputStyle = null; /* Default is ""*/
	 	  	/**
	 * style
	 * Styles for main div element of the slider control.
	 */
	 	 private String  _style = null; /* Default is ""*/
	 	  	/**
	 * size
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private int  _size = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what size is set.
	 */
	 private boolean _sizeSet = false;	
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	  	/**
	 * tabindex
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 */
	 	 private String  _tabindex = null; /* Default is null*/
	 	  	/**
	 * maxlength
	 * When the type attribute has the value "text" or "password", this attribute specifies the maximum number of characters the user may enter. This number may exceed the specified size, in which case the user agent should offer a scrolling mechanism. The default value for this attribute is an unlimited number
	 */
	 	 private int  _maxlength = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what maxlength is set.
	 */
	 private boolean _maxlengthSet = false;	
	 	   	/**
	 * disabled
	 * When set for a form control, this boolean attribute disables the control for user input.
	 */
	 	 private boolean  _disabled = false;		
	/**
	 * Flag indicated what disabled is set.
	 */
	 private boolean _disabledSet = false;	
	 	   	/**
	 * alt
	 * For user agents that cannot display images, forms, or applets, this attribute specifies an alternate text. Language of an alternate text is specified by the lang attribute.
	 */
	 	 private String  _alt = null; /* Default is null*/
	 	  	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	   	/**
	 * showInput
	 * False value for this attribute makes text a field invisible.
	 */
	 	 private boolean  _showInput = true;		
	/**
	 * Flag indicated what showInput is set.
	 */
	 private boolean _showInputSet = false;	
	 	   	/**
	 * onselect
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 */
	 	 private String  _onselect = null; /* Default is null*/
	 	  	/**
	 * handleStyle
	 * A style for control handle element.
	 */
	 	 private String  _handleStyle = null; /* Default is ""*/
	 	  	/**
	 * barClass
	 * A name of CSS class
	 */
	 	 private String  _barClass = null; /* Default is ""*/
	 	  	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	   	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	  	/**
	 * enableManualInput
	 * False value for this attribute makes a text field "read-only", so the value can be
	    	changed only from a handle.
	 */
	 	 private boolean  _enableManualInput = true;		
	/**
	 * Flag indicated what enableManualInput is set.
	 */
	 private boolean _enableManualInputSet = false;	
	 	  	/**
	 * onerror
	 * This error is called when a non-number value or a number value that is out of the range is input.
	 */
	 	 private String  _onerror = null; /* Default is ""*/
	 	   	/**
	 * handleClass
	 * A name of CSS class
	 */
	 	 private String  _handleClass = null; /* Default is ""*/
	 	  	/**
	 * inputClass
	 * Style Class attribute for a text field.
	 */
	 	 private String  _inputClass = null; /* Default is ""*/
	 	   	/**
	 * styleClass
	 * Name of a CSS class
	 */
	 	 private String  _styleClass = null; /* Default is ""*/
	 	  	/**
	 * height
	 * The height of a slider control.
	 */
	 	 private String  _height = null; /* Default is "20px"*/
	 	  	/**
	 * accesskey
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 */
	 	 private String  _accesskey = null; /* Default is null*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * showBoundaryValues
	 * If the min/max values are shown on the right/left borders of a control.
	    	Default=true;
	 */
	 	 private boolean  _showBoundaryValues = true;		
	/**
	 * Flag indicated what showBoundaryValues is set.
	 */
	 private boolean _showBoundaryValuesSet = false;	
	 	  	/**
	 * align
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private String  _align = null; /* Default is null*/
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * tipClass
	 * A name of CSS class
	 */
	 	 private String  _tipClass = null; /* Default is ""*/
	 	  	/**
	 * onblur
	 * HTML: script expression; the element lost the focus
	 */
	 	 private String  _onblur = null; /* Default is null*/
	 	   	/**
	 * inputSize
	 * Similar to the "Size" attribute of h:inputText.
	 */
	 	 private int  _inputSize = 3;		
	/**
	 * Flag indicated what inputSize is set.
	 */
	 private boolean _inputSizeSet = false;	
	 	  	/**
	 * maxValue
	 * Attribute to set an "end" value
	 */
	 	 private String  _maxValue = null; /* Default is "100"*/
	 	   	/**
	 * tipStyle
	 * A style for the tool tip element.
	 */
	 	 private String  _tipStyle = null; /* Default is ""*/
	 	  	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	   	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * minValue
	 * Attribute to set a "start" value
	 */
	 	 private String  _minValue = null; /* Default is "0"*/
	 	   	/**
	 * onfocus
	 * HTML: script expression; the element got the focus
	 */
	 	 private String  _onfocus = null; /* Default is null*/
	 	  	/**
	 * step
	 * Parameter that determines a step betwen the nearest values while using a handle
	 */
	 	 private String  _step = null; /* Default is "1"*/
	 	  	/**
	 * barStyle
	 * Style for a slider control line.
	 */
	 	 private String  _barStyle = null; /* Default is ""*/
	 	 
// Getters-setters
  	/*
	 * The width of a slider control.
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * The width of a slider control.
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "200px";
        }
	 	 }
	     	/*
	 * HTML: script expression; the element value was changed
	 * Setter for onchange
	 * @param onchange - new value
	 */
	 public void setOnchange( String  __onchange ){
		this._onchange = __onchange;
	 	 }


	/*
	 * HTML: script expression; the element value was changed
	 * Getter for onchange
	 * @return onchange value from local variable or value bindings
	 */
	 public String getOnchange(  ){
	         if (null != this._onchange)
        {
            return this._onchange;
        	    }
        ValueBinding vb = getValueBinding("onchange");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If the current value will be shown in the tooltip when a handle control in a
	    	"dragged" state.Default=true.
	 * Setter for showToolTip
	 * @param showToolTip - new value
	 */
	 public void setShowToolTip( boolean  __showToolTip ){
		this._showToolTip = __showToolTip;
	 		this._showToolTipSet = true;
	 	 }


	/*
	 * If the current value will be shown in the tooltip when a handle control in a
	    	"dragged" state.Default=true.
	 * Getter for showToolTip
	 * @return showToolTip value from local variable or value bindings
	 */
	 public boolean isShowToolTip(  ){
	 		 if(this._showToolTipSet){
			return this._showToolTip;
		 }
    	ValueBinding vb = getValueBinding("showToolTip");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._showToolTip;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._showToolTip);
    	}
	 	 }
	   	/*
	 * Style attribute for text field.
	 * Setter for inputStyle
	 * @param inputStyle - new value
	 */
	 public void setInputStyle( String  __inputStyle ){
		this._inputStyle = __inputStyle;
	 	 }


	/*
	 * Style attribute for text field.
	 * Getter for inputStyle
	 * @return inputStyle value from local variable or value bindings
	 */
	 public String getInputStyle(  ){
	         if (null != this._inputStyle)
        {
            return this._inputStyle;
        	    }
        ValueBinding vb = getValueBinding("inputStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * Styles for main div element of the slider control.
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * Styles for main div element of the slider control.
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for size
	 * @param size - new value
	 */
	 public void setSize( int  __size ){
		this._size = __size;
	 		this._sizeSet = true;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for size
	 * @return size value from local variable or value bindings
	 */
	 public int getSize(  ){
	 		 if(this._sizeSet){
			return this._size;
		 }
    	ValueBinding vb = getValueBinding("size");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._size;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._size);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 * Setter for tabindex
	 * @param tabindex - new value
	 */
	 public void setTabindex( String  __tabindex ){
		this._tabindex = __tabindex;
	 	 }


	/*
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 * Getter for tabindex
	 * @return tabindex value from local variable or value bindings
	 */
	 public String getTabindex(  ){
	         if (null != this._tabindex)
        {
            return this._tabindex;
        	    }
        ValueBinding vb = getValueBinding("tabindex");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * When the type attribute has the value "text" or "password", this attribute specifies the maximum number of characters the user may enter. This number may exceed the specified size, in which case the user agent should offer a scrolling mechanism. The default value for this attribute is an unlimited number
	 * Setter for maxlength
	 * @param maxlength - new value
	 */
	 public void setMaxlength( int  __maxlength ){
		this._maxlength = __maxlength;
	 		this._maxlengthSet = true;
	 	 }


	/*
	 * When the type attribute has the value "text" or "password", this attribute specifies the maximum number of characters the user may enter. This number may exceed the specified size, in which case the user agent should offer a scrolling mechanism. The default value for this attribute is an unlimited number
	 * Getter for maxlength
	 * @return maxlength value from local variable or value bindings
	 */
	 public int getMaxlength(  ){
	 		 if(this._maxlengthSet){
			return this._maxlength;
		 }
    	ValueBinding vb = getValueBinding("maxlength");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._maxlength;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._maxlength);
    	}
	 	 }
	    	/*
	 * When set for a form control, this boolean attribute disables the control for user input.
	 * Setter for disabled
	 * @param disabled - new value
	 */
	 public void setDisabled( boolean  __disabled ){
		this._disabled = __disabled;
	 		this._disabledSet = true;
	 	 }


	/*
	 * When set for a form control, this boolean attribute disables the control for user input.
	 * Getter for disabled
	 * @return disabled value from local variable or value bindings
	 */
	 public boolean isDisabled(  ){
	 		 if(this._disabledSet){
			return this._disabled;
		 }
    	ValueBinding vb = getValueBinding("disabled");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._disabled;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._disabled);
    	}
	 	 }
	    	/*
	 * For user agents that cannot display images, forms, or applets, this attribute specifies an alternate text. Language of an alternate text is specified by the lang attribute.
	 * Setter for alt
	 * @param alt - new value
	 */
	 public void setAlt( String  __alt ){
		this._alt = __alt;
	 	 }


	/*
	 * For user agents that cannot display images, forms, or applets, this attribute specifies an alternate text. Language of an alternate text is specified by the lang attribute.
	 * Getter for alt
	 * @return alt value from local variable or value bindings
	 */
	 public String getAlt(  ){
	         if (null != this._alt)
        {
            return this._alt;
        	    }
        ValueBinding vb = getValueBinding("alt");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * False value for this attribute makes text a field invisible.
	 * Setter for showInput
	 * @param showInput - new value
	 */
	 public void setShowInput( boolean  __showInput ){
		this._showInput = __showInput;
	 		this._showInputSet = true;
	 	 }


	/*
	 * False value for this attribute makes text a field invisible.
	 * Getter for showInput
	 * @return showInput value from local variable or value bindings
	 */
	 public boolean isShowInput(  ){
	 		 if(this._showInputSet){
			return this._showInput;
		 }
    	ValueBinding vb = getValueBinding("showInput");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._showInput;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._showInput);
    	}
	 	 }
	    	/*
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 * Setter for onselect
	 * @param onselect - new value
	 */
	 public void setOnselect( String  __onselect ){
		this._onselect = __onselect;
	 	 }


	/*
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 * Getter for onselect
	 * @return onselect value from local variable or value bindings
	 */
	 public String getOnselect(  ){
	         if (null != this._onselect)
        {
            return this._onselect;
        	    }
        ValueBinding vb = getValueBinding("onselect");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A style for control handle element.
	 * Setter for handleStyle
	 * @param handleStyle - new value
	 */
	 public void setHandleStyle( String  __handleStyle ){
		this._handleStyle = __handleStyle;
	 	 }


	/*
	 * A style for control handle element.
	 * Getter for handleStyle
	 * @return handleStyle value from local variable or value bindings
	 */
	 public String getHandleStyle(  ){
	         if (null != this._handleStyle)
        {
            return this._handleStyle;
        	    }
        ValueBinding vb = getValueBinding("handleStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * A name of CSS class
	 * Setter for barClass
	 * @param barClass - new value
	 */
	 public void setBarClass( String  __barClass ){
		this._barClass = __barClass;
	 	 }


	/*
	 * A name of CSS class
	 * Getter for barClass
	 * @return barClass value from local variable or value bindings
	 */
	 public String getBarClass(  ){
	         if (null != this._barClass)
        {
            return this._barClass;
        	    }
        ValueBinding vb = getValueBinding("barClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * False value for this attribute makes a text field "read-only", so the value can be
	    	changed only from a handle.
	 * Setter for enableManualInput
	 * @param enableManualInput - new value
	 */
	 public void setEnableManualInput( boolean  __enableManualInput ){
		this._enableManualInput = __enableManualInput;
	 		this._enableManualInputSet = true;
	 	 }


	/*
	 * False value for this attribute makes a text field "read-only", so the value can be
	    	changed only from a handle.
	 * Getter for enableManualInput
	 * @return enableManualInput value from local variable or value bindings
	 */
	 public boolean isEnableManualInput(  ){
	 		 if(this._enableManualInputSet){
			return this._enableManualInput;
		 }
    	ValueBinding vb = getValueBinding("enableManualInput");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._enableManualInput;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._enableManualInput);
    	}
	 	 }
	   	/*
	 * This error is called when a non-number value or a number value that is out of the range is input.
	 * Setter for onerror
	 * @param onerror - new value
	 */
	 public void setOnerror( String  __onerror ){
		this._onerror = __onerror;
	 	 }


	/*
	 * This error is called when a non-number value or a number value that is out of the range is input.
	 * Getter for onerror
	 * @return onerror value from local variable or value bindings
	 */
	 public String getOnerror(  ){
	         if (null != this._onerror)
        {
            return this._onerror;
        	    }
        ValueBinding vb = getValueBinding("onerror");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	    	/*
	 * A name of CSS class
	 * Setter for handleClass
	 * @param handleClass - new value
	 */
	 public void setHandleClass( String  __handleClass ){
		this._handleClass = __handleClass;
	 	 }


	/*
	 * A name of CSS class
	 * Getter for handleClass
	 * @return handleClass value from local variable or value bindings
	 */
	 public String getHandleClass(  ){
	         if (null != this._handleClass)
        {
            return this._handleClass;
        	    }
        ValueBinding vb = getValueBinding("handleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * Style Class attribute for a text field.
	 * Setter for inputClass
	 * @param inputClass - new value
	 */
	 public void setInputClass( String  __inputClass ){
		this._inputClass = __inputClass;
	 	 }


	/*
	 * Style Class attribute for a text field.
	 * Getter for inputClass
	 * @return inputClass value from local variable or value bindings
	 */
	 public String getInputClass(  ){
	         if (null != this._inputClass)
        {
            return this._inputClass;
        	    }
        ValueBinding vb = getValueBinding("inputClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	    	/*
	 * Name of a CSS class
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Name of a CSS class
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * The height of a slider control.
	 * Setter for height
	 * @param height - new value
	 */
	 public void setHeight( String  __height ){
		this._height = __height;
	 	 }


	/*
	 * The height of a slider control.
	 * Getter for height
	 * @return height value from local variable or value bindings
	 */
	 public String getHeight(  ){
	         if (null != this._height)
        {
            return this._height;
        	    }
        ValueBinding vb = getValueBinding("height");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "20px";
        }
	 	 }
	   	/*
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 * Setter for accesskey
	 * @param accesskey - new value
	 */
	 public void setAccesskey( String  __accesskey ){
		this._accesskey = __accesskey;
	 	 }


	/*
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 * Getter for accesskey
	 * @return accesskey value from local variable or value bindings
	 */
	 public String getAccesskey(  ){
	         if (null != this._accesskey)
        {
            return this._accesskey;
        	    }
        ValueBinding vb = getValueBinding("accesskey");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If the min/max values are shown on the right/left borders of a control.
	    	Default=true;
	 * Setter for showBoundaryValues
	 * @param showBoundaryValues - new value
	 */
	 public void setShowBoundaryValues( boolean  __showBoundaryValues ){
		this._showBoundaryValues = __showBoundaryValues;
	 		this._showBoundaryValuesSet = true;
	 	 }


	/*
	 * If the min/max values are shown on the right/left borders of a control.
	    	Default=true;
	 * Getter for showBoundaryValues
	 * @return showBoundaryValues value from local variable or value bindings
	 */
	 public boolean isShowBoundaryValues(  ){
	 		 if(this._showBoundaryValuesSet){
			return this._showBoundaryValues;
		 }
    	ValueBinding vb = getValueBinding("showBoundaryValues");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._showBoundaryValues;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._showBoundaryValues);
    	}
	 	 }
	   	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for align
	 * @param align - new value
	 */
	 public void setAlign( String  __align ){
		this._align = __align;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for align
	 * @return align value from local variable or value bindings
	 */
	 public String getAlign(  ){
	         if (null != this._align)
        {
            return this._align;
        	    }
        ValueBinding vb = getValueBinding("align");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A name of CSS class
	 * Setter for tipClass
	 * @param tipClass - new value
	 */
	 public void setTipClass( String  __tipClass ){
		this._tipClass = __tipClass;
	 	 }


	/*
	 * A name of CSS class
	 * Getter for tipClass
	 * @return tipClass value from local variable or value bindings
	 */
	 public String getTipClass(  ){
	         if (null != this._tipClass)
        {
            return this._tipClass;
        	    }
        ValueBinding vb = getValueBinding("tipClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * HTML: script expression; the element lost the focus
	 * Setter for onblur
	 * @param onblur - new value
	 */
	 public void setOnblur( String  __onblur ){
		this._onblur = __onblur;
	 	 }


	/*
	 * HTML: script expression; the element lost the focus
	 * Getter for onblur
	 * @return onblur value from local variable or value bindings
	 */
	 public String getOnblur(  ){
	         if (null != this._onblur)
        {
            return this._onblur;
        	    }
        ValueBinding vb = getValueBinding("onblur");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Similar to the "Size" attribute of h:inputText.
	 * Setter for inputSize
	 * @param inputSize - new value
	 */
	 public void setInputSize( int  __inputSize ){
		this._inputSize = __inputSize;
	 		this._inputSizeSet = true;
	 	 }


	/*
	 * Similar to the "Size" attribute of h:inputText.
	 * Getter for inputSize
	 * @return inputSize value from local variable or value bindings
	 */
	 public int getInputSize(  ){
	 		 if(this._inputSizeSet){
			return this._inputSize;
		 }
    	ValueBinding vb = getValueBinding("inputSize");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._inputSize;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._inputSize);
    	}
	 	 }
	   	/*
	 * Attribute to set an "end" value
	 * Setter for maxValue
	 * @param maxValue - new value
	 */
	 public void setMaxValue( String  __maxValue ){
		this._maxValue = __maxValue;
	 	 }


	/*
	 * Attribute to set an "end" value
	 * Getter for maxValue
	 * @return maxValue value from local variable or value bindings
	 */
	 public String getMaxValue(  ){
	         if (null != this._maxValue)
        {
            return this._maxValue;
        	    }
        ValueBinding vb = getValueBinding("maxValue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "100";
        }
	 	 }
	    	/*
	 * A style for the tool tip element.
	 * Setter for tipStyle
	 * @param tipStyle - new value
	 */
	 public void setTipStyle( String  __tipStyle ){
		this._tipStyle = __tipStyle;
	 	 }


	/*
	 * A style for the tool tip element.
	 * Getter for tipStyle
	 * @return tipStyle value from local variable or value bindings
	 */
	 public String getTipStyle(  ){
	         if (null != this._tipStyle)
        {
            return this._tipStyle;
        	    }
        ValueBinding vb = getValueBinding("tipStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Attribute to set a "start" value
	 * Setter for minValue
	 * @param minValue - new value
	 */
	 public void setMinValue( String  __minValue ){
		this._minValue = __minValue;
	 	 }


	/*
	 * Attribute to set a "start" value
	 * Getter for minValue
	 * @return minValue value from local variable or value bindings
	 */
	 public String getMinValue(  ){
	         if (null != this._minValue)
        {
            return this._minValue;
        	    }
        ValueBinding vb = getValueBinding("minValue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "0";
        }
	 	 }
	    	/*
	 * HTML: script expression; the element got the focus
	 * Setter for onfocus
	 * @param onfocus - new value
	 */
	 public void setOnfocus( String  __onfocus ){
		this._onfocus = __onfocus;
	 	 }


	/*
	 * HTML: script expression; the element got the focus
	 * Getter for onfocus
	 * @return onfocus value from local variable or value bindings
	 */
	 public String getOnfocus(  ){
	         if (null != this._onfocus)
        {
            return this._onfocus;
        	    }
        ValueBinding vb = getValueBinding("onfocus");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Parameter that determines a step betwen the nearest values while using a handle
	 * Setter for step
	 * @param step - new value
	 */
	 public void setStep( String  __step ){
		this._step = __step;
	 	 }


	/*
	 * Parameter that determines a step betwen the nearest values while using a handle
	 * Getter for step
	 * @return step value from local variable or value bindings
	 */
	 public String getStep(  ){
	         if (null != this._step)
        {
            return this._step;
        	    }
        ValueBinding vb = getValueBinding("step");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "1";
        }
	 	 }
	   	/*
	 * Style for a slider control line.
	 * Setter for barStyle
	 * @param barStyle - new value
	 */
	 public void setBarStyle( String  __barStyle ){
		this._barStyle = __barStyle;
	 	 }


	/*
	 * Style for a slider control line.
	 * Getter for barStyle
	 * @return barStyle value from local variable or value bindings
	 */
	 public String getBarStyle(  ){
	         if (null != this._barStyle)
        {
            return this._barStyle;
        	    }
        ValueBinding vb = getValueBinding("barStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.inputNumberSlider";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[51];
        values[0] = super.saveState(context);
  	 	          values[1] = _width;
	   	 	
    	 	          values[2] = _onchange;
	   	 	
  	        values[3] = new Boolean(_showToolTip);
	   	   values[4] = Boolean.valueOf(_showToolTipSet);	
	   	 	
  	 	          values[5] = _inputStyle;
	   	 	
  	 	          values[6] = _style;
	   	 	
  	        values[7] = new Integer(_size);
	   	   values[8] = Boolean.valueOf(_sizeSet);	
	   	 	
  	 	          values[9] = _onmouseover;
	   	 	
  	 	          values[10] = _onkeyup;
	   	 	
  	 	          values[11] = _tabindex;
	   	 	
  	        values[12] = new Integer(_maxlength);
	   	   values[13] = Boolean.valueOf(_maxlengthSet);	
	   	 	
   	        values[14] = new Boolean(_disabled);
	   	   values[15] = Boolean.valueOf(_disabledSet);	
	   	 	
   	 	          values[16] = _alt;
	   	 	
  	 	          values[17] = _onmouseout;
	   	 	
   	        values[18] = new Boolean(_showInput);
	   	   values[19] = Boolean.valueOf(_showInputSet);	
	   	 	
   	 	          values[20] = _onselect;
	   	 	
  	 	          values[21] = _handleStyle;
	   	 	
  	 	          values[22] = _barClass;
	   	 	
  	 	          values[23] = _onmouseup;
	   	 	
   	 	          values[24] = _onmousemove;
	   	 	
  	        values[25] = new Boolean(_enableManualInput);
	   	   values[26] = Boolean.valueOf(_enableManualInputSet);	
	   	 	
  	 	          values[27] = _onerror;
	   	 	
   	 	          values[28] = _handleClass;
	   	 	
  	 	          values[29] = _inputClass;
	   	 	
   	 	          values[30] = _styleClass;
	   	 	
  	 	          values[31] = _height;
	   	 	
  	 	          values[32] = _accesskey;
	   	 	
  	 	          values[33] = _onkeypress;
	   	 	
  	        values[34] = new Boolean(_showBoundaryValues);
	   	   values[35] = Boolean.valueOf(_showBoundaryValuesSet);	
	   	 	
  	 	          values[36] = _align;
	   	 	
  	 	          values[37] = _ondblclick;
	   	 	
  	 	          values[38] = _tipClass;
	   	 	
  	 	          values[39] = _onblur;
	   	 	
   	        values[40] = new Integer(_inputSize);
	   	   values[41] = Boolean.valueOf(_inputSizeSet);	
	   	 	
  	 	          values[42] = _maxValue;
	   	 	
   	 	          values[43] = _tipStyle;
	   	 	
  	 	          values[44] = _onclick;
	   	 	
   	 	          values[45] = _onkeydown;
	   	 	
  	 	          values[46] = _onmousedown;
	   	 	
  	 	          values[47] = _minValue;
	   	 	
   	 	          values[48] = _onfocus;
	   	 	
  	 	          values[49] = _step;
	   	 	
  	 	          values[50] = _barStyle;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _width = (String)values[1] ;
	   	 	
    	 	          _onchange = (String)values[2] ;
	   	 	
  	        _showToolTip = ((Boolean)values[3]).booleanValue();
	   	   _showToolTipSet = ((Boolean)values[4]).booleanValue();	
	   	 	
  	 	          _inputStyle = (String)values[5] ;
	   	 	
  	 	          _style = (String)values[6] ;
	   	 	
  	        _size = ((Integer)values[7]).intValue();
	   	   _sizeSet = ((Boolean)values[8]).booleanValue();	
	   	 	
  	 	          _onmouseover = (String)values[9] ;
	   	 	
  	 	          _onkeyup = (String)values[10] ;
	   	 	
  	 	          _tabindex = (String)values[11] ;
	   	 	
  	        _maxlength = ((Integer)values[12]).intValue();
	   	   _maxlengthSet = ((Boolean)values[13]).booleanValue();	
	   	 	
   	        _disabled = ((Boolean)values[14]).booleanValue();
	   	   _disabledSet = ((Boolean)values[15]).booleanValue();	
	   	 	
   	 	          _alt = (String)values[16] ;
	   	 	
  	 	          _onmouseout = (String)values[17] ;
	   	 	
   	        _showInput = ((Boolean)values[18]).booleanValue();
	   	   _showInputSet = ((Boolean)values[19]).booleanValue();	
	   	 	
   	 	          _onselect = (String)values[20] ;
	   	 	
  	 	          _handleStyle = (String)values[21] ;
	   	 	
  	 	          _barClass = (String)values[22] ;
	   	 	
  	 	          _onmouseup = (String)values[23] ;
	   	 	
   	 	          _onmousemove = (String)values[24] ;
	   	 	
  	        _enableManualInput = ((Boolean)values[25]).booleanValue();
	   	   _enableManualInputSet = ((Boolean)values[26]).booleanValue();	
	   	 	
  	 	          _onerror = (String)values[27] ;
	   	 	
   	 	          _handleClass = (String)values[28] ;
	   	 	
  	 	          _inputClass = (String)values[29] ;
	   	 	
   	 	          _styleClass = (String)values[30] ;
	   	 	
  	 	          _height = (String)values[31] ;
	   	 	
  	 	          _accesskey = (String)values[32] ;
	   	 	
  	 	          _onkeypress = (String)values[33] ;
	   	 	
  	        _showBoundaryValues = ((Boolean)values[34]).booleanValue();
	   	   _showBoundaryValuesSet = ((Boolean)values[35]).booleanValue();	
	   	 	
  	 	          _align = (String)values[36] ;
	   	 	
  	 	          _ondblclick = (String)values[37] ;
	   	 	
  	 	          _tipClass = (String)values[38] ;
	   	 	
  	 	          _onblur = (String)values[39] ;
	   	 	
   	        _inputSize = ((Integer)values[40]).intValue();
	   	   _inputSizeSet = ((Boolean)values[41]).booleanValue();	
	   	 	
  	 	          _maxValue = (String)values[42] ;
	   	 	
   	 	          _tipStyle = (String)values[43] ;
	   	 	
  	 	          _onclick = (String)values[44] ;
	   	 	
   	 	          _onkeydown = (String)values[45] ;
	   	 	
  	 	          _onmousedown = (String)values[46] ;
	   	 	
  	 	          _minValue = (String)values[47] ;
	   	 	
   	 	          _onfocus = (String)values[48] ;
	   	 	
  	 	          _step = (String)values[49] ;
	   	 	
  	 	          _barStyle = (String)values[50] ;
	   	 	
 	
		
	}	
// Utilites

}