/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIInputNumberSpinner ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.inputNumberSpinner
 * Component-Family org.richfaces.inputNumberSpinner
  	 * Renderer-Type org.richfaces.InputNumberSpinnerRenderer
  	 * Spinner component - A single line input field that lets the user select a number using the controls near the
			text field. User can change value using Up/Down keyboard keys. The keyboard Input in field if it isn't 
			locked by manualInput attribute is possible. After arrow controls pressed - cursor can be
			moved in any way without loosing draged state.
 */
 public class HtmlInputNumberSpinner extends org.richfaces.component.UIInputNumberSpinner {

  public static final String COMPONENT_TYPE = "org.richfaces.inputNumberSpinner";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlInputNumberSpinner (){
  	  	setRendererType("org.richfaces.InputNumberSpinnerRenderer");
  	  }

// Component properties fields
  	/**
	 * onerror
	 * Error event
	 */
	 	 private String  _onerror = null; /* Default is ""*/
	 	    	/**
	 * inputClass
	 * Class attribute for text field.
	 */
	 	 private String  _inputClass = null; /* Default is ""*/
	 	   	/**
	 * onchange
	 * HTML: script expression; the element value was changed
	 */
	 	 private String  _onchange = null; /* Default is null*/
	 	   	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * inputStyle
	 * Style attribute for text field.
	 */
	 	 private String  _inputStyle = null; /* Default is ""*/
	 	  	/**
	 * accesskey
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 */
	 	 private String  _accesskey = null; /* Default is null*/
	 	  	/**
	 * onupclick
	 * Up click event
	 */
	 	 private String  _onupclick = null; /* Default is ""*/
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * size
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private int  _size = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what size is set.
	 */
	 private boolean _sizeSet = false;	
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * onblur
	 * HTML: script expression; the element lost the focus
	 */
	 	 private String  _onblur = null; /* Default is null*/
	 	  	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	   	/**
	 * inputSize
	 * Attribute specifies the intial length of input in characters. Default value is 10
	 */
	 	 private int  _inputSize = 10;		
	/**
	 * Flag indicated what inputSize is set.
	 */
	 private boolean _inputSizeSet = false;	
	 	  	/**
	 * cycled
	 * If "true" after the current value reaches the border value it is reversed to another border value
	    		after next increasing/decreasing. In other case possibilities of next increasing (or decreasing) will be locked
	 */
	 	 private boolean  _cycled = true;		
	/**
	 * Flag indicated what cycled is set.
	 */
	 private boolean _cycledSet = false;	
	 	  	/**
	 * tabindex
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 */
	 	 private String  _tabindex = null; /* Default is null*/
	 	   	/**
	 * maxlength
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private int  _maxlength = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what maxlength is set.
	 */
	 private boolean _maxlengthSet = false;	
	 	   	/**
	 * maxValue
	 * Maximum value.
	 */
	 	 private String  _maxValue = null; /* Default is "100"*/
	 	  	/**
	 * disabled
	 * When set for a form control, this boolean attribute disables the control for user input.
	 */
	 	 private boolean  _disabled = false;		
	/**
	 * Flag indicated what disabled is set.
	 */
	 private boolean _disabledSet = false;	
	 	   	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * ondownclick
	 * Down click event
	 */
	 	 private String  _ondownclick = null; /* Default is ""*/
	 	   	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * alt
	 * For user agents that cannot display images, forms, or applets, this attribute specifies alternate text. The language of the alternate text is specified by the lang attribute
	 */
	 	 private String  _alt = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	   	/**
	 * minValue
	 * Minimum value.
	 */
	 	 private String  _minValue = null; /* Default is "0"*/
	 	    	/**
	 * onselect
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 */
	 	 private String  _onselect = null; /* Default is null*/
	 	  	/**
	 * onfocus
	 * HTML: script expression; the element got the focus
	 */
	 	 private String  _onfocus = null; /* Default is null*/
	 	  	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	  	/**
	 * step
	 * Parameter that determines the step betwen nearest values while using handler
	 */
	 	 private String  _step = null; /* Default is "1"*/
	 	   	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	  	/**
	 * enableManualInput
	 * if "false" user's input to the text field using keyboard will be locked
	 */
	 	 private boolean  _enableManualInput = true;		
	/**
	 * Flag indicated what enableManualInput is set.
	 */
	 private boolean _enableManualInputSet = false;	
	 	 
// Getters-setters
  	/*
	 * Error event
	 * Setter for onerror
	 * @param onerror - new value
	 */
	 public void setOnerror( String  __onerror ){
		this._onerror = __onerror;
	 	 }


	/*
	 * Error event
	 * Getter for onerror
	 * @return onerror value from local variable or value bindings
	 */
	 public String getOnerror(  ){
	         if (null != this._onerror)
        {
            return this._onerror;
        	    }
        ValueBinding vb = getValueBinding("onerror");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	     	/*
	 * Class attribute for text field.
	 * Setter for inputClass
	 * @param inputClass - new value
	 */
	 public void setInputClass( String  __inputClass ){
		this._inputClass = __inputClass;
	 	 }


	/*
	 * Class attribute for text field.
	 * Getter for inputClass
	 * @return inputClass value from local variable or value bindings
	 */
	 public String getInputClass(  ){
	         if (null != this._inputClass)
        {
            return this._inputClass;
        	    }
        ValueBinding vb = getValueBinding("inputClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	    	/*
	 * HTML: script expression; the element value was changed
	 * Setter for onchange
	 * @param onchange - new value
	 */
	 public void setOnchange( String  __onchange ){
		this._onchange = __onchange;
	 	 }


	/*
	 * HTML: script expression; the element value was changed
	 * Getter for onchange
	 * @return onchange value from local variable or value bindings
	 */
	 public String getOnchange(  ){
	         if (null != this._onchange)
        {
            return this._onchange;
        	    }
        ValueBinding vb = getValueBinding("onchange");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Style attribute for text field.
	 * Setter for inputStyle
	 * @param inputStyle - new value
	 */
	 public void setInputStyle( String  __inputStyle ){
		this._inputStyle = __inputStyle;
	 	 }


	/*
	 * Style attribute for text field.
	 * Getter for inputStyle
	 * @return inputStyle value from local variable or value bindings
	 */
	 public String getInputStyle(  ){
	         if (null != this._inputStyle)
        {
            return this._inputStyle;
        	    }
        ValueBinding vb = getValueBinding("inputStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 * Setter for accesskey
	 * @param accesskey - new value
	 */
	 public void setAccesskey( String  __accesskey ){
		this._accesskey = __accesskey;
	 	 }


	/*
	 * This attribute assigns an access key to an element. An access key is a single character from the document character set. Note: Authors should consider the input method of the expected reader when specifying an accesskey
	 * Getter for accesskey
	 * @return accesskey value from local variable or value bindings
	 */
	 public String getAccesskey(  ){
	         if (null != this._accesskey)
        {
            return this._accesskey;
        	    }
        ValueBinding vb = getValueBinding("accesskey");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Up click event
	 * Setter for onupclick
	 * @param onupclick - new value
	 */
	 public void setOnupclick( String  __onupclick ){
		this._onupclick = __onupclick;
	 	 }


	/*
	 * Up click event
	 * Getter for onupclick
	 * @return onupclick value from local variable or value bindings
	 */
	 public String getOnupclick(  ){
	         if (null != this._onupclick)
        {
            return this._onupclick;
        	    }
        ValueBinding vb = getValueBinding("onupclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for size
	 * @param size - new value
	 */
	 public void setSize( int  __size ){
		this._size = __size;
	 		this._sizeSet = true;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for size
	 * @return size value from local variable or value bindings
	 */
	 public int getSize(  ){
	 		 if(this._sizeSet){
			return this._size;
		 }
    	ValueBinding vb = getValueBinding("size");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._size;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._size);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; the element lost the focus
	 * Setter for onblur
	 * @param onblur - new value
	 */
	 public void setOnblur( String  __onblur ){
		this._onblur = __onblur;
	 	 }


	/*
	 * HTML: script expression; the element lost the focus
	 * Getter for onblur
	 * @return onblur value from local variable or value bindings
	 */
	 public String getOnblur(  ){
	         if (null != this._onblur)
        {
            return this._onblur;
        	    }
        ValueBinding vb = getValueBinding("onblur");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Attribute specifies the intial length of input in characters. Default value is 10
	 * Setter for inputSize
	 * @param inputSize - new value
	 */
	 public void setInputSize( int  __inputSize ){
		this._inputSize = __inputSize;
	 		this._inputSizeSet = true;
	 	 }


	/*
	 * Attribute specifies the intial length of input in characters. Default value is 10
	 * Getter for inputSize
	 * @return inputSize value from local variable or value bindings
	 */
	 public int getInputSize(  ){
	 		 if(this._inputSizeSet){
			return this._inputSize;
		 }
    	ValueBinding vb = getValueBinding("inputSize");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._inputSize;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._inputSize);
    	}
	 	 }
	   	/*
	 * If "true" after the current value reaches the border value it is reversed to another border value
	    		after next increasing/decreasing. In other case possibilities of next increasing (or decreasing) will be locked
	 * Setter for cycled
	 * @param cycled - new value
	 */
	 public void setCycled( boolean  __cycled ){
		this._cycled = __cycled;
	 		this._cycledSet = true;
	 	 }


	/*
	 * If "true" after the current value reaches the border value it is reversed to another border value
	    		after next increasing/decreasing. In other case possibilities of next increasing (or decreasing) will be locked
	 * Getter for cycled
	 * @return cycled value from local variable or value bindings
	 */
	 public boolean isCycled(  ){
	 		 if(this._cycledSet){
			return this._cycled;
		 }
    	ValueBinding vb = getValueBinding("cycled");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._cycled;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._cycled);
    	}
	 	 }
	   	/*
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 * Setter for tabindex
	 * @param tabindex - new value
	 */
	 public void setTabindex( String  __tabindex ){
		this._tabindex = __tabindex;
	 	 }


	/*
	 * This attribute specifies the position of the current element in the tabbing order for the current document. This value must be a number between 0 and 32767. User agents should ignore leading zeros
	 * Getter for tabindex
	 * @return tabindex value from local variable or value bindings
	 */
	 public String getTabindex(  ){
	         if (null != this._tabindex)
        {
            return this._tabindex;
        	    }
        ValueBinding vb = getValueBinding("tabindex");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for maxlength
	 * @param maxlength - new value
	 */
	 public void setMaxlength( int  __maxlength ){
		this._maxlength = __maxlength;
	 		this._maxlengthSet = true;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for maxlength
	 * @return maxlength value from local variable or value bindings
	 */
	 public int getMaxlength(  ){
	 		 if(this._maxlengthSet){
			return this._maxlength;
		 }
    	ValueBinding vb = getValueBinding("maxlength");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._maxlength;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._maxlength);
    	}
	 	 }
	    	/*
	 * Maximum value.
	 * Setter for maxValue
	 * @param maxValue - new value
	 */
	 public void setMaxValue( String  __maxValue ){
		this._maxValue = __maxValue;
	 	 }


	/*
	 * Maximum value.
	 * Getter for maxValue
	 * @return maxValue value from local variable or value bindings
	 */
	 public String getMaxValue(  ){
	         if (null != this._maxValue)
        {
            return this._maxValue;
        	    }
        ValueBinding vb = getValueBinding("maxValue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "100";
        }
	 	 }
	   	/*
	 * When set for a form control, this boolean attribute disables the control for user input.
	 * Setter for disabled
	 * @param disabled - new value
	 */
	 public void setDisabled( boolean  __disabled ){
		this._disabled = __disabled;
	 		this._disabledSet = true;
	 	 }


	/*
	 * When set for a form control, this boolean attribute disables the control for user input.
	 * Getter for disabled
	 * @return disabled value from local variable or value bindings
	 */
	 public boolean isDisabled(  ){
	 		 if(this._disabledSet){
			return this._disabled;
		 }
    	ValueBinding vb = getValueBinding("disabled");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._disabled;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._disabled);
    	}
	 	 }
	    	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Down click event
	 * Setter for ondownclick
	 * @param ondownclick - new value
	 */
	 public void setOndownclick( String  __ondownclick ){
		this._ondownclick = __ondownclick;
	 	 }


	/*
	 * Down click event
	 * Getter for ondownclick
	 * @return ondownclick value from local variable or value bindings
	 */
	 public String getOndownclick(  ){
	         if (null != this._ondownclick)
        {
            return this._ondownclick;
        	    }
        ValueBinding vb = getValueBinding("ondownclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "";
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * For user agents that cannot display images, forms, or applets, this attribute specifies alternate text. The language of the alternate text is specified by the lang attribute
	 * Setter for alt
	 * @param alt - new value
	 */
	 public void setAlt( String  __alt ){
		this._alt = __alt;
	 	 }


	/*
	 * For user agents that cannot display images, forms, or applets, this attribute specifies alternate text. The language of the alternate text is specified by the lang attribute
	 * Getter for alt
	 * @return alt value from local variable or value bindings
	 */
	 public String getAlt(  ){
	         if (null != this._alt)
        {
            return this._alt;
        	    }
        ValueBinding vb = getValueBinding("alt");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Minimum value.
	 * Setter for minValue
	 * @param minValue - new value
	 */
	 public void setMinValue( String  __minValue ){
		this._minValue = __minValue;
	 	 }


	/*
	 * Minimum value.
	 * Getter for minValue
	 * @return minValue value from local variable or value bindings
	 */
	 public String getMinValue(  ){
	         if (null != this._minValue)
        {
            return this._minValue;
        	    }
        ValueBinding vb = getValueBinding("minValue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "0";
        }
	 	 }
	     	/*
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 * Setter for onselect
	 * @param onselect - new value
	 */
	 public void setOnselect( String  __onselect ){
		this._onselect = __onselect;
	 	 }


	/*
	 * HTML: script expression; The onselect event occurs when a user selects some text in a text field. This attribute may be used with the INPUT and TEXTAREA elements
	 * Getter for onselect
	 * @return onselect value from local variable or value bindings
	 */
	 public String getOnselect(  ){
	         if (null != this._onselect)
        {
            return this._onselect;
        	    }
        ValueBinding vb = getValueBinding("onselect");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; the element got the focus
	 * Setter for onfocus
	 * @param onfocus - new value
	 */
	 public void setOnfocus( String  __onfocus ){
		this._onfocus = __onfocus;
	 	 }


	/*
	 * HTML: script expression; the element got the focus
	 * Getter for onfocus
	 * @return onfocus value from local variable or value bindings
	 */
	 public String getOnfocus(  ){
	         if (null != this._onfocus)
        {
            return this._onfocus;
        	    }
        ValueBinding vb = getValueBinding("onfocus");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Parameter that determines the step betwen nearest values while using handler
	 * Setter for step
	 * @param step - new value
	 */
	 public void setStep( String  __step ){
		this._step = __step;
	 	 }


	/*
	 * Parameter that determines the step betwen nearest values while using handler
	 * Getter for step
	 * @return step value from local variable or value bindings
	 */
	 public String getStep(  ){
	         if (null != this._step)
        {
            return this._step;
        	    }
        ValueBinding vb = getValueBinding("step");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "1";
        }
	 	 }
	    	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * if "false" user's input to the text field using keyboard will be locked
	 * Setter for enableManualInput
	 * @param enableManualInput - new value
	 */
	 public void setEnableManualInput( boolean  __enableManualInput ){
		this._enableManualInput = __enableManualInput;
	 		this._enableManualInputSet = true;
	 	 }


	/*
	 * if "false" user's input to the text field using keyboard will be locked
	 * Getter for enableManualInput
	 * @return enableManualInput value from local variable or value bindings
	 */
	 public boolean isEnableManualInput(  ){
	 		 if(this._enableManualInputSet){
			return this._enableManualInput;
		 }
    	ValueBinding vb = getValueBinding("enableManualInput");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._enableManualInput;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._enableManualInput);
    	}
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.inputNumberSpinner";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[40];
        values[0] = super.saveState(context);
  	 	          values[1] = _onerror;
	   	 	
    	 	          values[2] = _inputClass;
	   	 	
   	 	          values[3] = _onchange;
	   	 	
   	 	          values[4] = _styleClass;
	   	 	
  	 	          values[5] = _inputStyle;
	   	 	
  	 	          values[6] = _accesskey;
	   	 	
  	 	          values[7] = _onupclick;
	   	 	
  	 	          values[8] = _onkeypress;
	   	 	
  	 	          values[9] = _ondblclick;
	   	 	
  	 	          values[10] = _style;
	   	 	
  	        values[11] = new Integer(_size);
	   	   values[12] = Boolean.valueOf(_sizeSet);	
	   	 	
  	 	          values[13] = _onmouseover;
	   	 	
  	 	          values[14] = _onblur;
	   	 	
  	 	          values[15] = _onkeyup;
	   	 	
   	        values[16] = new Integer(_inputSize);
	   	   values[17] = Boolean.valueOf(_inputSizeSet);	
	   	 	
  	        values[18] = new Boolean(_cycled);
	   	   values[19] = Boolean.valueOf(_cycledSet);	
	   	 	
  	 	          values[20] = _tabindex;
	   	 	
   	        values[21] = new Integer(_maxlength);
	   	   values[22] = Boolean.valueOf(_maxlengthSet);	
	   	 	
   	 	          values[23] = _maxValue;
	   	 	
  	        values[24] = new Boolean(_disabled);
	   	   values[25] = Boolean.valueOf(_disabledSet);	
	   	 	
   	 	          values[26] = _onclick;
	   	 	
  	 	          values[27] = _ondownclick;
	   	 	
   	 	          values[28] = _onmouseout;
	   	 	
  	 	          values[29] = _alt;
	   	 	
  	 	          values[30] = _onkeydown;
	   	 	
  	 	          values[31] = _onmousedown;
	   	 	
   	 	          values[32] = _minValue;
	   	 	
    	 	          values[33] = _onselect;
	   	 	
  	 	          values[34] = _onfocus;
	   	 	
  	 	          values[35] = _onmouseup;
	   	 	
  	 	          values[36] = _step;
	   	 	
   	 	          values[37] = _onmousemove;
	   	 	
  	        values[38] = new Boolean(_enableManualInput);
	   	   values[39] = Boolean.valueOf(_enableManualInputSet);	
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _onerror = (String)values[1] ;
	   	 	
    	 	          _inputClass = (String)values[2] ;
	   	 	
   	 	          _onchange = (String)values[3] ;
	   	 	
   	 	          _styleClass = (String)values[4] ;
	   	 	
  	 	          _inputStyle = (String)values[5] ;
	   	 	
  	 	          _accesskey = (String)values[6] ;
	   	 	
  	 	          _onupclick = (String)values[7] ;
	   	 	
  	 	          _onkeypress = (String)values[8] ;
	   	 	
  	 	          _ondblclick = (String)values[9] ;
	   	 	
  	 	          _style = (String)values[10] ;
	   	 	
  	        _size = ((Integer)values[11]).intValue();
	   	   _sizeSet = ((Boolean)values[12]).booleanValue();	
	   	 	
  	 	          _onmouseover = (String)values[13] ;
	   	 	
  	 	          _onblur = (String)values[14] ;
	   	 	
  	 	          _onkeyup = (String)values[15] ;
	   	 	
   	        _inputSize = ((Integer)values[16]).intValue();
	   	   _inputSizeSet = ((Boolean)values[17]).booleanValue();	
	   	 	
  	        _cycled = ((Boolean)values[18]).booleanValue();
	   	   _cycledSet = ((Boolean)values[19]).booleanValue();	
	   	 	
  	 	          _tabindex = (String)values[20] ;
	   	 	
   	        _maxlength = ((Integer)values[21]).intValue();
	   	   _maxlengthSet = ((Boolean)values[22]).booleanValue();	
	   	 	
   	 	          _maxValue = (String)values[23] ;
	   	 	
  	        _disabled = ((Boolean)values[24]).booleanValue();
	   	   _disabledSet = ((Boolean)values[25]).booleanValue();	
	   	 	
   	 	          _onclick = (String)values[26] ;
	   	 	
  	 	          _ondownclick = (String)values[27] ;
	   	 	
   	 	          _onmouseout = (String)values[28] ;
	   	 	
  	 	          _alt = (String)values[29] ;
	   	 	
  	 	          _onkeydown = (String)values[30] ;
	   	 	
  	 	          _onmousedown = (String)values[31] ;
	   	 	
   	 	          _minValue = (String)values[32] ;
	   	 	
    	 	          _onselect = (String)values[33] ;
	   	 	
  	 	          _onfocus = (String)values[34] ;
	   	 	
  	 	          _onmouseup = (String)values[35] ;
	   	 	
  	 	          _step = (String)values[36] ;
	   	 	
   	 	          _onmousemove = (String)values[37] ;
	   	 	
  	        _enableManualInput = ((Boolean)values[38]).booleanValue();
	   	   _enableManualInputSet = ((Boolean)values[39]).booleanValue();	
	   	 	
 	
		
	}	
// Utilites

}