/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import javax.faces.convert.Converter ;
import java.lang.Object ;
import javax.faces.el.MethodBinding ;
import org.richfaces.component.UISuggestionBox ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.SuggestionBox
 * Component-Family org.richfaces.SuggestionBox
  	 * Renderer-Type org.richfaces.SuggestionBox
  	 * This element adds "on-keypress" suggestions capabilites to any input text component (like &amp;lt;h:inputText&amp;gt;).
        It creates a pop-up window for a input field component pointed to by the "for" attribute.
        For an ordinary request, render a hidden HTML &amp;lt;div&amp;gt; element and the necessary JavaScript code.
        When input to the target field exceeds the "minChars" property (default is 1), perform an AJAX request with
        the value current entered. If the AJAX request is detected and the request parameters map contains the client ID of this component,
        call a method defined by suggestionAction, and use it to return a value as data for render table, same as &amp;lt;h:dataTable&amp;gt;.
        In this case, the component then works the same as an ordinary dataTable. The rendered table is inserted in the pop-up area and is used for suggestion prompts
        for input element. If a user clicks on such a table row, its text (or value defined by fetchValue) is inserted as the value of the input field.
 */
 public class HtmlSuggestionBox extends org.richfaces.component.UISuggestionBox {

  public static final String COMPONENT_TYPE = "org.richfaces.SuggestionBox";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlSuggestionBox (){
  	  	setRendererType("org.richfaces.SuggestionBox");
  	  }

// Component properties fields
  	/**
	 * width
	 * Width of the pop-up window in pixels
	 */
	 	 private String  _width = null; /* Default is null*/
	 	   	/**
	 * dir
	 * Alternate textual description of the element rendered by this component
	 */
	 	 private String  _dir = null; /* Default is null*/
	 	  	/**
	 * bypassUpdates
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 */
	 	 private boolean  _bypassUpdates = false;		
	/**
	 * Flag indicated what bypassUpdates is set.
	 */
	 private boolean _bypassUpdatesSet = false;	
	 	  	/**
	 * popupClass
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 */
	 	 private String  _popupClass = null; /* Default is null*/
	 	   	/**
	 * limitToList
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 */
	 	 private boolean  _limitToList = false;		
	/**
	 * Flag indicated what limitToList is set.
	 */
	 private boolean _limitToListSet = false;	
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * shadowOpacity
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 */
	 	 private String  _shadowOpacity = null; /* Default is null*/
	 	  	/**
	 * for
	 * id (or full path of id's) of target components, for which this element must provide support.
		If a target component inside of the same &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; (UIForm, UIData in base implementstions), can be simple value of the "id" attribute.
		For other cases must include id's of &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; components, separated by ':'. For search from the root of components, must be started with ':'.
	 */
	 	 private String  _for = null; /* Default is null*/
	 	   	/**
	 * summary
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 */
	 	 private String  _summary = null; /* Default is null*/
	 	  	/**
	 * timeout
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 */
	 	 private int  _timeout = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what timeout is set.
	 */
	 private boolean _timeoutSet = false;	
	 	   	/**
	 * converter
	 * Id of Converter to be used or reference to a Converter
	 */
	 	 private Converter  _converter = null; /* Default is null*/
	 	  	/**
	 * lang
	 * Code describing the language used in the generated markup for this component
	 */
	 	 private String  _lang = null; /* Default is null*/
	 	    	/**
	 * cellspacing
	 * This attribute specifies how much space the user agent
                should leave between the table and the column on all
                four sides. The attribute also specifies the amount of
                space to leave between cells
	 */
	 	 private String  _cellspacing = null; /* Default is null*/
	 	  	/**
	 * shadowDepth
	 * Pop-up shadow depth for suggestion content
	 */
	 	 private String  _shadowDepth = null; /* Default is null*/
	 	  	/**
	 * fetchValue
	 * A value to set in the target input element on a choice
                suggestion that isn't shown in the suggestion table. It
                can be used for descriptive output comments for
                suggestions. If not set, all text in the suggestion row
                is set as a value
	 */
	 	 private Object  _fetchValue = null; /* Default is null*/
	 	  	/**
	 * entryClass
	 * Name of the CSS class for a suggestion entry element
                (table row)
	 */
	 	 private String  _entryClass = null; /* Default is "richfaces_suggestionEntry"*/
	 	  	/**
	 * onselect
	 * JavaScript code for call on select suggestion, after
                update value of target element
	 */
	 	 private String  _onselect = null; /* Default is null*/
	 	    	/**
	 * selfRendered
	 * If true, forces active Ajax region render response
                directly from stored components tree, bypasses page
                processing. Can be used for increase performance. Also,
                must be set to 'true' inside iteration components, such
                as dataTable
	 */
	 	 private boolean  _selfRendered = false;		
	/**
	 * Flag indicated what selfRendered is set.
	 */
	 private boolean _selfRenderedSet = false;	
	 	  	/**
	 * cellpadding
	 * This attribute specifies the amount of space between the
                border of the cell and its contents. If the value of
                this attribute is a pixel length, all four margins
                should be this distance from the contents. If the value
                of the attribute is percentage length, the top and
                bottom margins should be equally separated from the
                content based on percentage of the available vertical
                space, and the left and right margins should be equally
                separated from the content based on percentage of the
                available horizontal space
	 */
	 	 private String  _cellpadding = null; /* Default is null*/
	 	   	/**
	 * rowClasses
	 * rowClasses
	 */
	 	 private String  _rowClasses = null; /* Default is null*/
	 	  	/**
	 * title
	 * Advisory title information about markup elements generated for this component
	 */
	 	 private String  _title = null; /* Default is null*/
	 	  	/**
	 * oncomplete
	 * JavaScript code for call after request completed on client side
	 */
	 	 private String  _oncomplete = null; /* Default is null*/
	 	  	/**
	 * rules
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 */
	 	 private String  _rules = null; /* Default is null*/
	 	  	/**
	 * popupStyle
	 * HTML CSS style attribute of element for pop-up
                suggestion content
	 */
	 	 private String  _popupStyle = null; /* Default is null*/
	 	  	/**
	 * suggestionAction
	 * Method call expression to get a collection of suggestion data on request. It must have one parameter with a type of Object vith content of input component and must return any type allowed for &amp;lt;h:datatable&amp;gt;
	 */
	 	 private MethodBinding  _suggestionAction = null; /* Default is null*/
	 	   	/**
	 * reRender
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * height
	 * Height of the pop-up window in pixels
	 */
	 	 private String  _height = null; /* Default is null*/
	 	  	/**
	 * ajaxSingle
	 * if true, submit ONLY one field/link, instead of all
                form controls
	 */
	 	 private boolean  _ajaxSingle = true;		
	/**
	 * Flag indicated what ajaxSingle is set.
	 */
	 private boolean _ajaxSingleSet = false;	
	 	  	/**
	 * align
	 * align
	 */
	 	 private String  _align = null; /* Default is null*/
	 	  	/**
	 * selectedClass
	 * Name of the CSS class for a selected suggestion entry
                element (table row)
	 */
	 	 private String  _selectedClass = null; /* Default is null*/
	 	  	/**
	 * border
	 * This attributes specifies the width (in pixels only) of the frame around a table
	 */
	 	 private String  _border = null; /* Default is null*/
	 	  	/**
	 * bgcolor
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 */
	 	 private String  _bgcolor = null; /* Default is null*/
	 	   	/**
	 * selectValueClass
	 * Name of the CSS class for a hidden suggestion entry
                element (table cell)
	 */
	 	 private String  _selectValueClass = null; /* Default is "richfaces_suggestionSelectValue"*/
	 	   	/**
	 * frequency
	 * Delay (in seconds) before activating the suggestion
                pop-up
	 */
	 	 private double  _frequency = Double.MIN_VALUE;		
	/**
	 * Flag indicated what frequency is set.
	 */
	 private boolean _frequencySet = false;	
	 	  	/**
	 * tokens
	 * The list (or single value) of symbols which can be used
                for division chosen of suggestion pop-up values in a
                target element. After input of a symbol from the list
                suggestion pop-up it is caused again
	 */
	 	 private Object  _tokens = null; /* Default is null*/
	 	  	/**
	 * status
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 */
	 	 private String  _status = null; /* Default is null*/
	 	  	/**
	 * requestDelay
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 */
	 	 private int  _requestDelay = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what requestDelay is set.
	 */
	 private boolean _requestDelaySet = false;	
	 	  	/**
	 * eventsQueue
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 */
	 	 private String  _eventsQueue = null; /* Default is null*/
	 	  	/**
	 * frame
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 */
	 	 private String  _frame = null; /* Default is null*/
	 	  	/**
	 * immediate
	 * immediate
	 */
	 	 private boolean  _immediate = false;		
	/**
	 * Flag indicated what immediate is set.
	 */
	 private boolean _immediateSet = false;	
	 	  	/**
	 * data
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 */
	 	 private Object  _data = null; /* Default is null*/
	 	   	/**
	 * param
	 * Name the HTTP request parameter with the value of input
                element token. If not set, it be will sent as an input
                element name. In this case, input will perform
                validation and update the value
	 */
	 	 private String  _param = null; /* Default is "inputvalue"*/
	 	  	/**
	 * minChars
	 * Minimal number of chars in input to activate suggestion
                pop-up
	 */
	 	 private String  _minChars = null; /* Default is null*/
	 	  	/**
	 * ignoreDupResponses
	 * If true, unfinished request will be aborted on new event
	 */
	 	 private boolean  _ignoreDupResponses = false;		
	/**
	 * Flag indicated what ignoreDupResponses is set.
	 */
	 private boolean _ignoreDupResponsesSet = false;	
	 	 
// Getters-setters
  	/*
	 * Width of the pop-up window in pixels
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * Width of the pop-up window in pixels
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Alternate textual description of the element rendered by this component
	 * Setter for dir
	 * @param dir - new value
	 */
	 public void setDir( String  __dir ){
		this._dir = __dir;
	 	 }


	/*
	 * Alternate textual description of the element rendered by this component
	 * Getter for dir
	 * @return dir value from local variable or value bindings
	 */
	 public String getDir(  ){
	         if (null != this._dir)
        {
            return this._dir;
        	    }
        ValueBinding vb = getValueBinding("dir");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Setter for bypassUpdates
	 * @param bypassUpdates - new value
	 */
	 public void setBypassUpdates( boolean  __bypassUpdates ){
		this._bypassUpdates = __bypassUpdates;
	 		this._bypassUpdatesSet = true;
	 	 }


	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Getter for bypassUpdates
	 * @return bypassUpdates value from local variable or value bindings
	 */
	 public boolean isBypassUpdates(  ){
	 		 if(this._bypassUpdatesSet){
			return this._bypassUpdates;
		 }
    	ValueBinding vb = getValueBinding("bypassUpdates");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._bypassUpdates;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._bypassUpdates);
    	}
	 	 }
	   	/*
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 * Setter for popupClass
	 * @param popupClass - new value
	 */
	 public void setPopupClass( String  __popupClass ){
		this._popupClass = __popupClass;
	 	 }


	/*
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 * Getter for popupClass
	 * @return popupClass value from local variable or value bindings
	 */
	 public String getPopupClass(  ){
	         if (null != this._popupClass)
        {
            return this._popupClass;
        	    }
        ValueBinding vb = getValueBinding("popupClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Setter for limitToList
	 * @param limitToList - new value
	 */
	 public void setLimitToList( boolean  __limitToList ){
		this._limitToList = __limitToList;
	 		this._limitToListSet = true;
	 	 }


	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Getter for limitToList
	 * @return limitToList value from local variable or value bindings
	 */
	 public boolean isLimitToList(  ){
	 		 if(this._limitToListSet){
			return this._limitToList;
		 }
    	ValueBinding vb = getValueBinding("limitToList");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._limitToList;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._limitToList);
    	}
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 * Setter for shadowOpacity
	 * @param shadowOpacity - new value
	 */
	 public void setShadowOpacity( String  __shadowOpacity ){
		this._shadowOpacity = __shadowOpacity;
	 	 }


	/*
	 * HTML CSS class attribute of element for pop-up
                suggestion content
	 * Getter for shadowOpacity
	 * @return shadowOpacity value from local variable or value bindings
	 */
	 public String getShadowOpacity(  ){
	         if (null != this._shadowOpacity)
        {
            return this._shadowOpacity;
        	    }
        ValueBinding vb = getValueBinding("shadowOpacity");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * id (or full path of id's) of target components, for which this element must provide support.
		If a target component inside of the same &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; (UIForm, UIData in base implementstions), can be simple value of the "id" attribute.
		For other cases must include id's of &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; components, separated by ':'. For search from the root of components, must be started with ':'.
	 * Setter for for
	 * @param for - new value
	 */
	 public void setFor( String  __for ){
		this._for = __for;
	 	 }


	/*
	 * id (or full path of id's) of target components, for which this element must provide support.
		If a target component inside of the same &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; (UIForm, UIData in base implementstions), can be simple value of the "id" attribute.
		For other cases must include id's of &amp;lt;code&amp;gt;NamingContainer&amp;lt;/code&amp;gt; components, separated by ':'. For search from the root of components, must be started with ':'.
	 * Getter for for
	 * @return for value from local variable or value bindings
	 */
	 public String getFor(  ){
	         if (null != this._for)
        {
            return this._for;
        	    }
        ValueBinding vb = getValueBinding("for");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 * Setter for summary
	 * @param summary - new value
	 */
	 public void setSummary( String  __summary ){
		this._summary = __summary;
	 	 }


	/*
	 * This attribute provides a summary of the table's purpose and structure for user agents rendering to non-visual media such as speech and Braille
	 * Getter for summary
	 * @return summary value from local variable or value bindings
	 */
	 public String getSummary(  ){
	         if (null != this._summary)
        {
            return this._summary;
        	    }
        ValueBinding vb = getValueBinding("summary");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Setter for timeout
	 * @param timeout - new value
	 */
	 public void setTimeout( int  __timeout ){
		this._timeout = __timeout;
	 		this._timeoutSet = true;
	 	 }


	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Getter for timeout
	 * @return timeout value from local variable or value bindings
	 */
	 public int getTimeout(  ){
	 		 if(this._timeoutSet){
			return this._timeout;
		 }
    	ValueBinding vb = getValueBinding("timeout");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._timeout;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._timeout);
    	}
	 	 }
	    	/*
	 * Id of Converter to be used or reference to a Converter
	 * Setter for converter
	 * @param converter - new value
	 */
	 public void setConverter( Converter  __converter ){
		this._converter = __converter;
	 	 }


	/*
	 * Id of Converter to be used or reference to a Converter
	 * Getter for converter
	 * @return converter value from local variable or value bindings
	 */
	 public Converter getConverter(  ){
	         if (null != this._converter)
        {
            return this._converter;
        	    }
        ValueBinding vb = getValueBinding("converter");
        if (null != vb){
            return (Converter)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Code describing the language used in the generated markup for this component
	 * Setter for lang
	 * @param lang - new value
	 */
	 public void setLang( String  __lang ){
		this._lang = __lang;
	 	 }


	/*
	 * Code describing the language used in the generated markup for this component
	 * Getter for lang
	 * @return lang value from local variable or value bindings
	 */
	 public String getLang(  ){
	         if (null != this._lang)
        {
            return this._lang;
        	    }
        ValueBinding vb = getValueBinding("lang");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * This attribute specifies how much space the user agent
                should leave between the table and the column on all
                four sides. The attribute also specifies the amount of
                space to leave between cells
	 * Setter for cellspacing
	 * @param cellspacing - new value
	 */
	 public void setCellspacing( String  __cellspacing ){
		this._cellspacing = __cellspacing;
	 	 }


	/*
	 * This attribute specifies how much space the user agent
                should leave between the table and the column on all
                four sides. The attribute also specifies the amount of
                space to leave between cells
	 * Getter for cellspacing
	 * @return cellspacing value from local variable or value bindings
	 */
	 public String getCellspacing(  ){
	         if (null != this._cellspacing)
        {
            return this._cellspacing;
        	    }
        ValueBinding vb = getValueBinding("cellspacing");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Pop-up shadow depth for suggestion content
	 * Setter for shadowDepth
	 * @param shadowDepth - new value
	 */
	 public void setShadowDepth( String  __shadowDepth ){
		this._shadowDepth = __shadowDepth;
	 	 }


	/*
	 * Pop-up shadow depth for suggestion content
	 * Getter for shadowDepth
	 * @return shadowDepth value from local variable or value bindings
	 */
	 public String getShadowDepth(  ){
	         if (null != this._shadowDepth)
        {
            return this._shadowDepth;
        	    }
        ValueBinding vb = getValueBinding("shadowDepth");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A value to set in the target input element on a choice
                suggestion that isn't shown in the suggestion table. It
                can be used for descriptive output comments for
                suggestions. If not set, all text in the suggestion row
                is set as a value
	 * Setter for fetchValue
	 * @param fetchValue - new value
	 */
	 public void setFetchValue( Object  __fetchValue ){
		this._fetchValue = __fetchValue;
	 	 }


	/*
	 * A value to set in the target input element on a choice
                suggestion that isn't shown in the suggestion table. It
                can be used for descriptive output comments for
                suggestions. If not set, all text in the suggestion row
                is set as a value
	 * Getter for fetchValue
	 * @return fetchValue value from local variable or value bindings
	 */
	 public Object getFetchValue(  ){
	         if (null != this._fetchValue)
        {
            return this._fetchValue;
        	    }
        ValueBinding vb = getValueBinding("fetchValue");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Name of the CSS class for a suggestion entry element
                (table row)
	 * Setter for entryClass
	 * @param entryClass - new value
	 */
	 public void setEntryClass( String  __entryClass ){
		this._entryClass = __entryClass;
	 	 }


	/*
	 * Name of the CSS class for a suggestion entry element
                (table row)
	 * Getter for entryClass
	 * @return entryClass value from local variable or value bindings
	 */
	 public String getEntryClass(  ){
	         if (null != this._entryClass)
        {
            return this._entryClass;
        	    }
        ValueBinding vb = getValueBinding("entryClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "richfaces_suggestionEntry";
        }
	 	 }
	   	/*
	 * JavaScript code for call on select suggestion, after
                update value of target element
	 * Setter for onselect
	 * @param onselect - new value
	 */
	 public void setOnselect( String  __onselect ){
		this._onselect = __onselect;
	 	 }


	/*
	 * JavaScript code for call on select suggestion, after
                update value of target element
	 * Getter for onselect
	 * @return onselect value from local variable or value bindings
	 */
	 public String getOnselect(  ){
	         if (null != this._onselect)
        {
            return this._onselect;
        	    }
        ValueBinding vb = getValueBinding("onselect");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * If true, forces active Ajax region render response
                directly from stored components tree, bypasses page
                processing. Can be used for increase performance. Also,
                must be set to 'true' inside iteration components, such
                as dataTable
	 * Setter for selfRendered
	 * @param selfRendered - new value
	 */
	 public void setSelfRendered( boolean  __selfRendered ){
		this._selfRendered = __selfRendered;
	 		this._selfRenderedSet = true;
	 	 }


	/*
	 * If true, forces active Ajax region render response
                directly from stored components tree, bypasses page
                processing. Can be used for increase performance. Also,
                must be set to 'true' inside iteration components, such
                as dataTable
	 * Getter for selfRendered
	 * @return selfRendered value from local variable or value bindings
	 */
	 public boolean isSelfRendered(  ){
	 		 if(this._selfRenderedSet){
			return this._selfRendered;
		 }
    	ValueBinding vb = getValueBinding("selfRendered");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._selfRendered;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._selfRendered);
    	}
	 	 }
	   	/*
	 * This attribute specifies the amount of space between the
                border of the cell and its contents. If the value of
                this attribute is a pixel length, all four margins
                should be this distance from the contents. If the value
                of the attribute is percentage length, the top and
                bottom margins should be equally separated from the
                content based on percentage of the available vertical
                space, and the left and right margins should be equally
                separated from the content based on percentage of the
                available horizontal space
	 * Setter for cellpadding
	 * @param cellpadding - new value
	 */
	 public void setCellpadding( String  __cellpadding ){
		this._cellpadding = __cellpadding;
	 	 }


	/*
	 * This attribute specifies the amount of space between the
                border of the cell and its contents. If the value of
                this attribute is a pixel length, all four margins
                should be this distance from the contents. If the value
                of the attribute is percentage length, the top and
                bottom margins should be equally separated from the
                content based on percentage of the available vertical
                space, and the left and right margins should be equally
                separated from the content based on percentage of the
                available horizontal space
	 * Getter for cellpadding
	 * @return cellpadding value from local variable or value bindings
	 */
	 public String getCellpadding(  ){
	         if (null != this._cellpadding)
        {
            return this._cellpadding;
        	    }
        ValueBinding vb = getValueBinding("cellpadding");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * rowClasses
	 * Setter for rowClasses
	 * @param rowClasses - new value
	 */
	 public void setRowClasses( String  __rowClasses ){
		this._rowClasses = __rowClasses;
	 	 }


	/*
	 * rowClasses
	 * Getter for rowClasses
	 * @return rowClasses value from local variable or value bindings
	 */
	 public String getRowClasses(  ){
	         if (null != this._rowClasses)
        {
            return this._rowClasses;
        	    }
        ValueBinding vb = getValueBinding("rowClasses");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Advisory title information about markup elements generated for this component
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * Advisory title information about markup elements generated for this component
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code for call after request completed on client side
	 * Setter for oncomplete
	 * @param oncomplete - new value
	 */
	 public void setOncomplete( String  __oncomplete ){
		this._oncomplete = __oncomplete;
	 	 }


	/*
	 * JavaScript code for call after request completed on client side
	 * Getter for oncomplete
	 * @return oncomplete value from local variable or value bindings
	 */
	 public String getOncomplete(  ){
	         if (null != this._oncomplete)
        {
            return this._oncomplete;
        	    }
        ValueBinding vb = getValueBinding("oncomplete");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 * Setter for rules
	 * @param rules - new value
	 */
	 public void setRules( String  __rules ){
		this._rules = __rules;
	 	 }


	/*
	 * This attribute specifies which rules will appear between cells within a table. The rendering of rules is user agent dependent. Possible values:
            
            * none: No rules. This is the default value.
            * groups: Rules will appear between row groups (see THEAD, TFOOT, and TBODY) and column groups (see COLGROUP and COL) only.
            * rows: Rules will appear between rows only.
            * cols: Rules will appear between columns only.
            * all: Rules will appear between all rows and columns.
	 * Getter for rules
	 * @return rules value from local variable or value bindings
	 */
	 public String getRules(  ){
	         if (null != this._rules)
        {
            return this._rules;
        	    }
        ValueBinding vb = getValueBinding("rules");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML CSS style attribute of element for pop-up
                suggestion content
	 * Setter for popupStyle
	 * @param popupStyle - new value
	 */
	 public void setPopupStyle( String  __popupStyle ){
		this._popupStyle = __popupStyle;
	 	 }


	/*
	 * HTML CSS style attribute of element for pop-up
                suggestion content
	 * Getter for popupStyle
	 * @return popupStyle value from local variable or value bindings
	 */
	 public String getPopupStyle(  ){
	         if (null != this._popupStyle)
        {
            return this._popupStyle;
        	    }
        ValueBinding vb = getValueBinding("popupStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Method call expression to get a collection of suggestion data on request. It must have one parameter with a type of Object vith content of input component and must return any type allowed for &amp;lt;h:datatable&amp;gt;
	 * Setter for suggestionAction
	 * @param suggestionAction - new value
	 */
	 public void setSuggestionAction( MethodBinding  __suggestionAction ){
		this._suggestionAction = __suggestionAction;
	 	 }


	/*
	 * Method call expression to get a collection of suggestion data on request. It must have one parameter with a type of Object vith content of input component and must return any type allowed for &amp;lt;h:datatable&amp;gt;
	 * Getter for suggestionAction
	 * @return suggestionAction value from local variable or value bindings
	 */
	 public MethodBinding getSuggestionAction(  ){
	         if (null != this._suggestionAction)
        {
            return this._suggestionAction;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Height of the pop-up window in pixels
	 * Setter for height
	 * @param height - new value
	 */
	 public void setHeight( String  __height ){
		this._height = __height;
	 	 }


	/*
	 * Height of the pop-up window in pixels
	 * Getter for height
	 * @return height value from local variable or value bindings
	 */
	 public String getHeight(  ){
	         if (null != this._height)
        {
            return this._height;
        	    }
        ValueBinding vb = getValueBinding("height");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * if true, submit ONLY one field/link, instead of all
                form controls
	 * Setter for ajaxSingle
	 * @param ajaxSingle - new value
	 */
	 public void setAjaxSingle( boolean  __ajaxSingle ){
		this._ajaxSingle = __ajaxSingle;
	 		this._ajaxSingleSet = true;
	 	 }


	/*
	 * if true, submit ONLY one field/link, instead of all
                form controls
	 * Getter for ajaxSingle
	 * @return ajaxSingle value from local variable or value bindings
	 */
	 public boolean isAjaxSingle(  ){
	 		 if(this._ajaxSingleSet){
			return this._ajaxSingle;
		 }
    	ValueBinding vb = getValueBinding("ajaxSingle");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSingle;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSingle);
    	}
	 	 }
	   	/*
	 * align
	 * Setter for align
	 * @param align - new value
	 */
	 public void setAlign( String  __align ){
		this._align = __align;
	 	 }


	/*
	 * align
	 * Getter for align
	 * @return align value from local variable or value bindings
	 */
	 public String getAlign(  ){
	         if (null != this._align)
        {
            return this._align;
        	    }
        ValueBinding vb = getValueBinding("align");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Name of the CSS class for a selected suggestion entry
                element (table row)
	 * Setter for selectedClass
	 * @param selectedClass - new value
	 */
	 public void setSelectedClass( String  __selectedClass ){
		this._selectedClass = __selectedClass;
	 	 }


	/*
	 * Name of the CSS class for a selected suggestion entry
                element (table row)
	 * Getter for selectedClass
	 * @return selectedClass value from local variable or value bindings
	 */
	 public String getSelectedClass(  ){
	         if (null != this._selectedClass)
        {
            return this._selectedClass;
        	    }
        ValueBinding vb = getValueBinding("selectedClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * This attributes specifies the width (in pixels only) of the frame around a table
	 * Setter for border
	 * @param border - new value
	 */
	 public void setBorder( String  __border ){
		this._border = __border;
	 	 }


	/*
	 * This attributes specifies the width (in pixels only) of the frame around a table
	 * Getter for border
	 * @return border value from local variable or value bindings
	 */
	 public String getBorder(  ){
	         if (null != this._border)
        {
            return this._border;
        	    }
        ValueBinding vb = getValueBinding("border");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 * Setter for bgcolor
	 * @param bgcolor - new value
	 */
	 public void setBgcolor( String  __bgcolor ){
		this._bgcolor = __bgcolor;
	 	 }


	/*
	 * Deprecated. This attribute sets the background color for the document body or table cells.
            
            This attribute sets the background color of the canvas for the document body (the BODY element) or for tables (the TABLE, TR, TH, and TD elements). Additional attributes for specifying text color can be used with the BODY element.
            
            This attribute has been deprecated in favor of style sheets for specifying background color information
	 * Getter for bgcolor
	 * @return bgcolor value from local variable or value bindings
	 */
	 public String getBgcolor(  ){
	         if (null != this._bgcolor)
        {
            return this._bgcolor;
        	    }
        ValueBinding vb = getValueBinding("bgcolor");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Name of the CSS class for a hidden suggestion entry
                element (table cell)
	 * Setter for selectValueClass
	 * @param selectValueClass - new value
	 */
	 public void setSelectValueClass( String  __selectValueClass ){
		this._selectValueClass = __selectValueClass;
	 	 }


	/*
	 * Name of the CSS class for a hidden suggestion entry
                element (table cell)
	 * Getter for selectValueClass
	 * @return selectValueClass value from local variable or value bindings
	 */
	 public String getSelectValueClass(  ){
	         if (null != this._selectValueClass)
        {
            return this._selectValueClass;
        	    }
        ValueBinding vb = getValueBinding("selectValueClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "richfaces_suggestionSelectValue";
        }
	 	 }
	    	/*
	 * Delay (in seconds) before activating the suggestion
                pop-up
	 * Setter for frequency
	 * @param frequency - new value
	 */
	 public void setFrequency( double  __frequency ){
		this._frequency = __frequency;
	 		this._frequencySet = true;
	 	 }


	/*
	 * Delay (in seconds) before activating the suggestion
                pop-up
	 * Getter for frequency
	 * @return frequency value from local variable or value bindings
	 */
	 public double getFrequency(  ){
	 		 if(this._frequencySet){
			return this._frequency;
		 }
    	ValueBinding vb = getValueBinding("frequency");
    	if (vb != null) {
    	    Double value = (Double) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._frequency;
    	    }
    	    return (value.doubleValue());
    	} else {
    	    return (this._frequency);
    	}
	 	 }
	   	/*
	 * The list (or single value) of symbols which can be used
                for division chosen of suggestion pop-up values in a
                target element. After input of a symbol from the list
                suggestion pop-up it is caused again
	 * Setter for tokens
	 * @param tokens - new value
	 */
	 public void setTokens( Object  __tokens ){
		this._tokens = __tokens;
	 	 }


	/*
	 * The list (or single value) of symbols which can be used
                for division chosen of suggestion pop-up values in a
                target element. After input of a symbol from the list
                suggestion pop-up it is caused again
	 * Getter for tokens
	 * @return tokens value from local variable or value bindings
	 */
	 public Object getTokens(  ){
	         if (null != this._tokens)
        {
            return this._tokens;
        	    }
        ValueBinding vb = getValueBinding("tokens");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Setter for status
	 * @param status - new value
	 */
	 public void setStatus( String  __status ){
		this._status = __status;
	 	 }


	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Getter for status
	 * @return status value from local variable or value bindings
	 */
	 public String getStatus(  ){
	         if (null != this._status)
        {
            return this._status;
        	    }
        ValueBinding vb = getValueBinding("status");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Setter for requestDelay
	 * @param requestDelay - new value
	 */
	 public void setRequestDelay( int  __requestDelay ){
		this._requestDelay = __requestDelay;
	 		this._requestDelaySet = true;
	 	 }


	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Getter for requestDelay
	 * @return requestDelay value from local variable or value bindings
	 */
	 public int getRequestDelay(  ){
	 		 if(this._requestDelaySet){
			return this._requestDelay;
		 }
    	ValueBinding vb = getValueBinding("requestDelay");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._requestDelay;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._requestDelay);
    	}
	 	 }
	   	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Setter for eventsQueue
	 * @param eventsQueue - new value
	 */
	 public void setEventsQueue( String  __eventsQueue ){
		this._eventsQueue = __eventsQueue;
	 	 }


	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Getter for eventsQueue
	 * @return eventsQueue value from local variable or value bindings
	 */
	 public String getEventsQueue(  ){
	         if (null != this._eventsQueue)
        {
            return this._eventsQueue;
        	    }
        ValueBinding vb = getValueBinding("eventsQueue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 * Setter for frame
	 * @param frame - new value
	 */
	 public void setFrame( String  __frame ){
		this._frame = __frame;
	 	 }


	/*
	 * void|above|below|hsides|lhs|rhs|vsides|box|border [CI]
            This attribute specifies which sides of the frame surrounding a table will be visible. Possible values:
            
            * void: No sides. This is the default value.
            * above: The top side only.
            * below: The bottom side only.
            * hsides: The top and bottom sides only.
            * vsides: The right and left sides only.
            * lhs: The left-hand side only.
            * rhs: The right-hand side only.
            * box: All four sides.
            * border: All four sides.
	 * Getter for frame
	 * @return frame value from local variable or value bindings
	 */
	 public String getFrame(  ){
	         if (null != this._frame)
        {
            return this._frame;
        	    }
        ValueBinding vb = getValueBinding("frame");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * immediate
	 * Setter for immediate
	 * @param immediate - new value
	 */
	 public void setImmediate( boolean  __immediate ){
		this._immediate = __immediate;
	 		this._immediateSet = true;
	 	 }


	/*
	 * immediate
	 * Getter for immediate
	 * @return immediate value from local variable or value bindings
	 */
	 public boolean isImmediate(  ){
	 		 if(this._immediateSet){
			return this._immediate;
		 }
    	ValueBinding vb = getValueBinding("immediate");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._immediate;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._immediate);
    	}
	 	 }
	   	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Setter for data
	 * @param data - new value
	 */
	 public void setData( Object  __data ){
		this._data = __data;
	 	 }


	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Getter for data
	 * @return data value from local variable or value bindings
	 */
	 public Object getData(  ){
	         if (null != this._data)
        {
            return this._data;
        	    }
        ValueBinding vb = getValueBinding("data");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Name the HTTP request parameter with the value of input
                element token. If not set, it be will sent as an input
                element name. In this case, input will perform
                validation and update the value
	 * Setter for param
	 * @param param - new value
	 */
	 public void setParam( String  __param ){
		this._param = __param;
	 	 }


	/*
	 * Name the HTTP request parameter with the value of input
                element token. If not set, it be will sent as an input
                element name. In this case, input will perform
                validation and update the value
	 * Getter for param
	 * @return param value from local variable or value bindings
	 */
	 public String getParam(  ){
	         if (null != this._param)
        {
            return this._param;
        	    }
        ValueBinding vb = getValueBinding("param");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "inputvalue";
        }
	 	 }
	   	/*
	 * Minimal number of chars in input to activate suggestion
                pop-up
	 * Setter for minChars
	 * @param minChars - new value
	 */
	 public void setMinChars( String  __minChars ){
		this._minChars = __minChars;
	 	 }


	/*
	 * Minimal number of chars in input to activate suggestion
                pop-up
	 * Getter for minChars
	 * @return minChars value from local variable or value bindings
	 */
	 public String getMinChars(  ){
	         if (null != this._minChars)
        {
            return this._minChars;
        	    }
        ValueBinding vb = getValueBinding("minChars");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If true, unfinished request will be aborted on new event
	 * Setter for ignoreDupResponses
	 * @param ignoreDupResponses - new value
	 */
	 public void setIgnoreDupResponses( boolean  __ignoreDupResponses ){
		this._ignoreDupResponses = __ignoreDupResponses;
	 		this._ignoreDupResponsesSet = true;
	 	 }


	/*
	 * If true, unfinished request will be aborted on new event
	 * Getter for ignoreDupResponses
	 * @return ignoreDupResponses value from local variable or value bindings
	 */
	 public boolean isIgnoreDupResponses(  ){
	 		 if(this._ignoreDupResponsesSet){
			return this._ignoreDupResponses;
		 }
    	ValueBinding vb = getValueBinding("ignoreDupResponses");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ignoreDupResponses;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ignoreDupResponses);
    	}
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.SuggestionBox";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[55];
        values[0] = super.saveState(context);
  	 	          values[1] = _width;
	   	 	
   	 	          values[2] = _dir;
	   	 	
  	        values[3] = new Boolean(_bypassUpdates);
	   	   values[4] = Boolean.valueOf(_bypassUpdatesSet);	
	   	 	
  	 	          values[5] = _popupClass;
	   	 	
   	        values[6] = new Boolean(_limitToList);
	   	   values[7] = Boolean.valueOf(_limitToListSet);	
	   	 	
  	 	          values[8] = _style;
	   	 	
  	 	          values[9] = _shadowOpacity;
	   	 	
  	 	          values[10] = _for;
	   	 	
   	 	          values[11] = _summary;
	   	 	
  	        values[12] = new Integer(_timeout);
	   	   values[13] = Boolean.valueOf(_timeoutSet);	
	   	 	
   	 	          values[14] = saveAttachedState(context, _converter );		
	   	 	
  	 	          values[15] = _lang;
	   	 	
    	 	          values[16] = _cellspacing;
	   	 	
  	 	          values[17] = _shadowDepth;
	   	 	
  	 	          values[18] = _fetchValue;
	   	 	
  	 	          values[19] = _entryClass;
	   	 	
  	 	          values[20] = _onselect;
	   	 	
    	        values[21] = new Boolean(_selfRendered);
	   	   values[22] = Boolean.valueOf(_selfRenderedSet);	
	   	 	
  	 	          values[23] = _cellpadding;
	   	 	
   	 	          values[24] = _rowClasses;
	   	 	
  	 	          values[25] = _title;
	   	 	
  	 	          values[26] = _oncomplete;
	   	 	
  	 	          values[27] = _rules;
	   	 	
  	 	          values[28] = _popupStyle;
	   	 	
  	 	          values[29] = saveAttachedState(context, _suggestionAction );		
	   	 	
   	 	          values[30] = _reRender;
	   	 	
  	 	          values[31] = _styleClass;
	   	 	
  	 	          values[32] = _height;
	   	 	
  	        values[33] = new Boolean(_ajaxSingle);
	   	   values[34] = Boolean.valueOf(_ajaxSingleSet);	
	   	 	
  	 	          values[35] = _align;
	   	 	
  	 	          values[36] = _selectedClass;
	   	 	
  	 	          values[37] = _border;
	   	 	
  	 	          values[38] = _bgcolor;
	   	 	
   	 	          values[39] = _selectValueClass;
	   	 	
   	        values[40] = new Double(_frequency);
	   	   values[41] = Boolean.valueOf(_frequencySet);	
	   	 	
  	 	          values[42] = _tokens;
	   	 	
  	 	          values[43] = _status;
	   	 	
  	        values[44] = new Integer(_requestDelay);
	   	   values[45] = Boolean.valueOf(_requestDelaySet);	
	   	 	
  	 	          values[46] = _eventsQueue;
	   	 	
  	 	          values[47] = _frame;
	   	 	
  	        values[48] = new Boolean(_immediate);
	   	   values[49] = Boolean.valueOf(_immediateSet);	
	   	 	
  	 	          values[50] = _data;
	   	 	
   	 	          values[51] = _param;
	   	 	
  	 	          values[52] = _minChars;
	   	 	
  	        values[53] = new Boolean(_ignoreDupResponses);
	   	   values[54] = Boolean.valueOf(_ignoreDupResponsesSet);	
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _width = (String)values[1] ;
	   	 	
   	 	          _dir = (String)values[2] ;
	   	 	
  	        _bypassUpdates = ((Boolean)values[3]).booleanValue();
	   	   _bypassUpdatesSet = ((Boolean)values[4]).booleanValue();	
	   	 	
  	 	          _popupClass = (String)values[5] ;
	   	 	
   	        _limitToList = ((Boolean)values[6]).booleanValue();
	   	   _limitToListSet = ((Boolean)values[7]).booleanValue();	
	   	 	
  	 	          _style = (String)values[8] ;
	   	 	
  	 	          _shadowOpacity = (String)values[9] ;
	   	 	
  	 	          _for = (String)values[10] ;
	   	 	
   	 	          _summary = (String)values[11] ;
	   	 	
  	        _timeout = ((Integer)values[12]).intValue();
	   	   _timeoutSet = ((Boolean)values[13]).booleanValue();	
	   	 	
   	 	          _converter = (Converter)restoreAttachedState(context,values[14] );		
	   	 	
  	 	          _lang = (String)values[15] ;
	   	 	
    	 	          _cellspacing = (String)values[16] ;
	   	 	
  	 	          _shadowDepth = (String)values[17] ;
	   	 	
  	 	          _fetchValue = (Object)values[18] ;
	   	 	
  	 	          _entryClass = (String)values[19] ;
	   	 	
  	 	          _onselect = (String)values[20] ;
	   	 	
    	        _selfRendered = ((Boolean)values[21]).booleanValue();
	   	   _selfRenderedSet = ((Boolean)values[22]).booleanValue();	
	   	 	
  	 	          _cellpadding = (String)values[23] ;
	   	 	
   	 	          _rowClasses = (String)values[24] ;
	   	 	
  	 	          _title = (String)values[25] ;
	   	 	
  	 	          _oncomplete = (String)values[26] ;
	   	 	
  	 	          _rules = (String)values[27] ;
	   	 	
  	 	          _popupStyle = (String)values[28] ;
	   	 	
  	 	          _suggestionAction = (MethodBinding)restoreAttachedState(context,values[29] );		
	   	 	
   	 	          _reRender = (Object)values[30] ;
	   	 	
  	 	          _styleClass = (String)values[31] ;
	   	 	
  	 	          _height = (String)values[32] ;
	   	 	
  	        _ajaxSingle = ((Boolean)values[33]).booleanValue();
	   	   _ajaxSingleSet = ((Boolean)values[34]).booleanValue();	
	   	 	
  	 	          _align = (String)values[35] ;
	   	 	
  	 	          _selectedClass = (String)values[36] ;
	   	 	
  	 	          _border = (String)values[37] ;
	   	 	
  	 	          _bgcolor = (String)values[38] ;
	   	 	
   	 	          _selectValueClass = (String)values[39] ;
	   	 	
   	        _frequency = ((Double)values[40]).doubleValue();
	   	   _frequencySet = ((Boolean)values[41]).booleanValue();	
	   	 	
  	 	          _tokens = (Object)values[42] ;
	   	 	
  	 	          _status = (String)values[43] ;
	   	 	
  	        _requestDelay = ((Integer)values[44]).intValue();
	   	   _requestDelaySet = ((Boolean)values[45]).booleanValue();	
	   	 	
  	 	          _eventsQueue = (String)values[46] ;
	   	 	
  	 	          _frame = (String)values[47] ;
	   	 	
  	        _immediate = ((Boolean)values[48]).booleanValue();
	   	   _immediateSet = ((Boolean)values[49]).booleanValue();	
	   	 	
  	 	          _data = (Object)values[50] ;
	   	 	
   	 	          _param = (String)values[51] ;
	   	 	
  	 	          _minChars = (String)values[52] ;
	   	 	
  	        _ignoreDupResponses = ((Boolean)values[53]).booleanValue();
	   	   _ignoreDupResponsesSet = ((Boolean)values[54]).booleanValue();	
	   	 	
 	
		
	}	
// Utilites

}