/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UITab ;
import java.lang.Object ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.Tab
 * Component-Family org.richfaces.Tab
  	 * Renderer-Type org.richfaces.TabRenderer
  	 * A tab section within a tab panel
 */
 public class HtmlTab extends org.richfaces.component.UITab {

  public static final String COMPONENT_TYPE = "org.richfaces.Tab";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlTab (){
  	  	setRendererType("org.richfaces.TabRenderer");
  	  }

// Component properties fields
   	/**
	 * title
	 * title
	 */
	 	 private String  _title = null; /* Default is null*/
	 	  	/**
	 * oncomplete
	 * JavaScript code for call after request completed on client side
	 */
	 	 private String  _oncomplete = null; /* Default is null*/
	 	   	/**
	 * reRender
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	   	/**
	 * bypassUpdates
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 */
	 	 private boolean  _bypassUpdates = false;		
	/**
	 * Flag indicated what bypassUpdates is set.
	 */
	 private boolean _bypassUpdatesSet = false;	
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	   	/**
	 * limitToList
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 */
	 	 private boolean  _limitToList = false;		
	/**
	 * Flag indicated what limitToList is set.
	 */
	 private boolean _limitToListSet = false;	
	 	  	/**
	 * onkeypress
	 * HTML: a script expression; a key is pressed and released
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ajaxSingle
	 * if true , submits ONLY one field/link, instead of all form controls.
	 */
	 	 private boolean  _ajaxSingle = false;		
	/**
	 * Flag indicated what ajaxSingle is set.
	 */
	 private boolean _ajaxSingleSet = false;	
	 	  	/**
	 * ondblclick
	 * HTML: a script expression; a pointer button is double-clicked
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * name
	 * name
	 */
	 	 private Object  _name = null; /* Default is getId()*/
	 	  	/**
	 * onmouseover
	 * HTML: a script expression; a pointer is moved onto
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	   	/**
	 * value
	 * value
	 */
	 	 private Object  _value = null; /* Default is null*/
	 	   	/**
	 * onkeyup
	 * HTML: a script expression; a key is released
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	  	/**
	 * timeout
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 */
	 	 private int  _timeout = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what timeout is set.
	 */
	 private boolean _timeoutSet = false;	
	 	   	/**
	 * disabled
	 * Disables a tab in a tab panel
	 */
	 	 private boolean  _disabled = false;		
	/**
	 * Flag indicated what disabled is set.
	 */
	 private boolean _disabledSet = false;	
	 	  	/**
	 * onclick
	 * HTML: a script expression; a pointer button is clicked
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * status
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 */
	 	 private String  _status = null; /* Default is null*/
	 	  	/**
	 * onmouseout
	 * HTML: a script expression; a pointer is moved away
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * HTML: a script expression; a key is pressed down
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * HTML: script expression; a pointer button is pressed down
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * requestDelay
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 */
	 	 private int  _requestDelay = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what requestDelay is set.
	 */
	 private boolean _requestDelaySet = false;	
	 	   	/**
	 * eventsQueue
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 */
	 	 private String  _eventsQueue = null; /* Default is null*/
	 	  	/**
	 * labelWidth
	 * Length for the actual "tab" in a tab section defined in pixels. If it is not defined, the
	    	length is calculated basing on a tab label text length
	 */
	 	 private String  _labelWidth = null; /* Default is null*/
	 	  	/**
	 * label
	 * Text for the actual "tab" in a tab section.
	 */
	 	 private String  _label = null; /* Default is null*/
	 	   	/**
	 * data
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 */
	 	 private Object  _data = null; /* Default is null*/
	 	  	/**
	 * onmouseup
	 * HTML: script expression; a pointer button is released
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	   	/**
	 * ignoreDupResponses
	 * If true, unfinished request will be aborted on new event
	 */
	 	 private boolean  _ignoreDupResponses = false;		
	/**
	 * Flag indicated what ignoreDupResponses is set.
	 */
	 private boolean _ignoreDupResponsesSet = false;	
	 	  	/**
	 * onmousemove
	 * HTML: a script expression; a pointer is moved within
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	 
// Getters-setters
   	/*
	 * title
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * title
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code for call after request completed on client side
	 * Setter for oncomplete
	 * @param oncomplete - new value
	 */
	 public void setOncomplete( String  __oncomplete ){
		this._oncomplete = __oncomplete;
	 	 }


	/*
	 * JavaScript code for call after request completed on client side
	 * Getter for oncomplete
	 * @return oncomplete value from local variable or value bindings
	 */
	 public String getOncomplete(  ){
	         if (null != this._oncomplete)
        {
            return this._oncomplete;
        	    }
        ValueBinding vb = getValueBinding("oncomplete");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id['s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Id's, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Setter for bypassUpdates
	 * @param bypassUpdates - new value
	 */
	 public void setBypassUpdates( boolean  __bypassUpdates ){
		this._bypassUpdates = __bypassUpdates;
	 		this._bypassUpdatesSet = true;
	 	 }


	/*
	 * If true, after process validations phase it skips updates of model beans on a force render response. It can be used for validating components input
	 * Getter for bypassUpdates
	 * @return bypassUpdates value from local variable or value bindings
	 */
	 public boolean isBypassUpdates(  ){
	 		 if(this._bypassUpdatesSet){
			return this._bypassUpdates;
		 }
    	ValueBinding vb = getValueBinding("bypassUpdates");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._bypassUpdates;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._bypassUpdates);
    	}
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Setter for limitToList
	 * @param limitToList - new value
	 */
	 public void setLimitToList( boolean  __limitToList ){
		this._limitToList = __limitToList;
	 		this._limitToListSet = true;
	 	 }


	/*
	 * If "true", updates on client side ONLY elements from this 'reRender' property. If "false" (default) updates all rendered by ajax region components.
	 * Getter for limitToList
	 * @return limitToList value from local variable or value bindings
	 */
	 public boolean isLimitToList(  ){
	 		 if(this._limitToListSet){
			return this._limitToList;
		 }
    	ValueBinding vb = getValueBinding("limitToList");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._limitToList;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._limitToList);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed and released
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed and released
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * if true , submits ONLY one field/link, instead of all form controls.
	 * Setter for ajaxSingle
	 * @param ajaxSingle - new value
	 */
	 public void setAjaxSingle( boolean  __ajaxSingle ){
		this._ajaxSingle = __ajaxSingle;
	 		this._ajaxSingleSet = true;
	 	 }


	/*
	 * if true , submits ONLY one field/link, instead of all form controls.
	 * Getter for ajaxSingle
	 * @return ajaxSingle value from local variable or value bindings
	 */
	 public boolean isAjaxSingle(  ){
	 		 if(this._ajaxSingleSet){
			return this._ajaxSingle;
		 }
    	ValueBinding vb = getValueBinding("ajaxSingle");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSingle;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSingle);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is double-clicked
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * name
	 * Setter for name
	 * @param name - new value
	 */
	 public void setName( Object  __name ){
		this._name = __name;
	 	 }


	/*
	 * name
	 * Getter for name
	 * @return name value from local variable or value bindings
	 */
	 public Object getName(  ){
	         if (null != this._name)
        {
            return this._name;
        	    }
        ValueBinding vb = getValueBinding("name");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return getId();
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved onto
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * value
	 * Setter for value
	 * @param value - new value
	 */
	 public void setValue( Object  __value ){
		this._value = __value;
	 	 }


	/*
	 * value
	 * Getter for value
	 * @return value value from local variable or value bindings
	 */
	 public Object getValue(  ){
	         if (null != this._value)
        {
            return this._value;
        	    }
        ValueBinding vb = getValueBinding("value");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * HTML: a script expression; a key is released
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * HTML: a script expression; a key is released
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Setter for timeout
	 * @param timeout - new value
	 */
	 public void setTimeout( int  __timeout ){
		this._timeout = __timeout;
	 		this._timeoutSet = true;
	 	 }


	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Getter for timeout
	 * @return timeout value from local variable or value bindings
	 */
	 public int getTimeout(  ){
	 		 if(this._timeoutSet){
			return this._timeout;
		 }
    	ValueBinding vb = getValueBinding("timeout");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._timeout;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._timeout);
    	}
	 	 }
	    	/*
	 * Disables a tab in a tab panel
	 * Setter for disabled
	 * @param disabled - new value
	 */
	 public void setDisabled( boolean  __disabled ){
		this._disabled = __disabled;
	 		this._disabledSet = true;
	 	 }


	/*
	 * Disables a tab in a tab panel
	 * Getter for disabled
	 * @return disabled value from local variable or value bindings
	 */
	 public boolean isDisabled(  ){
	 		 if(this._disabledSet){
			return this._disabled;
		 }
    	ValueBinding vb = getValueBinding("disabled");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._disabled;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._disabled);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * HTML: a script expression; a pointer button is clicked
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Setter for status
	 * @param status - new value
	 */
	 public void setStatus( String  __status ){
		this._status = __status;
	 	 }


	/*
	 * ID (in format of call UIComopnent.findComponent()) of Request status component.
	 * Getter for status
	 * @return status value from local variable or value bindings
	 */
	 public String getStatus(  ){
	         if (null != this._status)
        {
            return this._status;
        	    }
        ValueBinding vb = getValueBinding("status");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved away
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved away
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: a script expression; a key is pressed down
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * HTML: a script expression; a key is pressed down
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * HTML: script expression; a pointer button is pressed down
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Setter for requestDelay
	 * @param requestDelay - new value
	 */
	 public void setRequestDelay( int  __requestDelay ){
		this._requestDelay = __requestDelay;
	 		this._requestDelaySet = true;
	 	 }


	/*
	 * Delay (in ms.) for send ajax request on JavaScript event. In conjunction with events queue can reduce number of requests on keyboard or mouse move events.
	 * Getter for requestDelay
	 * @return requestDelay value from local variable or value bindings
	 */
	 public int getRequestDelay(  ){
	 		 if(this._requestDelaySet){
			return this._requestDelay;
		 }
    	ValueBinding vb = getValueBinding("requestDelay");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._requestDelay;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._requestDelay);
    	}
	 	 }
	    	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Setter for eventsQueue
	 * @param eventsQueue - new value
	 */
	 public void setEventsQueue( String  __eventsQueue ){
		this._eventsQueue = __eventsQueue;
	 	 }


	/*
	 * Name of requests queue to avoid send next request before complete other from same event. Can be used to reduce number of requests of frequently events (key press, mouse move etc.).
	 * Getter for eventsQueue
	 * @return eventsQueue value from local variable or value bindings
	 */
	 public String getEventsQueue(  ){
	         if (null != this._eventsQueue)
        {
            return this._eventsQueue;
        	    }
        ValueBinding vb = getValueBinding("eventsQueue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Length for the actual "tab" in a tab section defined in pixels. If it is not defined, the
	    	length is calculated basing on a tab label text length
	 * Setter for labelWidth
	 * @param labelWidth - new value
	 */
	 public void setLabelWidth( String  __labelWidth ){
		this._labelWidth = __labelWidth;
	 	 }


	/*
	 * Length for the actual "tab" in a tab section defined in pixels. If it is not defined, the
	    	length is calculated basing on a tab label text length
	 * Getter for labelWidth
	 * @return labelWidth value from local variable or value bindings
	 */
	 public String getLabelWidth(  ){
	         if (null != this._labelWidth)
        {
            return this._labelWidth;
        	    }
        ValueBinding vb = getValueBinding("labelWidth");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Text for the actual "tab" in a tab section.
	 * Setter for label
	 * @param label - new value
	 */
	 public void setLabel( String  __label ){
		this._label = __label;
	 	 }


	/*
	 * Text for the actual "tab" in a tab section.
	 * Getter for label
	 * @return label value from local variable or value bindings
	 */
	 public String getLabel(  ){
	         if (null != this._label)
        {
            return this._label;
        	    }
        ValueBinding vb = getValueBinding("label");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Setter for data
	 * @param data - new value
	 */
	 public void setData( Object  __data ){
		this._data = __data;
	 	 }


	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Getter for data
	 * @return data value from local variable or value bindings
	 */
	 public Object getData(  ){
	         if (null != this._data)
        {
            return this._data;
        	    }
        ValueBinding vb = getValueBinding("data");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * HTML: script expression; a pointer button is released
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * HTML: script expression; a pointer button is released
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If true, unfinished request will be aborted on new event
	 * Setter for ignoreDupResponses
	 * @param ignoreDupResponses - new value
	 */
	 public void setIgnoreDupResponses( boolean  __ignoreDupResponses ){
		this._ignoreDupResponses = __ignoreDupResponses;
	 		this._ignoreDupResponsesSet = true;
	 	 }


	/*
	 * If true, unfinished request will be aborted on new event
	 * Getter for ignoreDupResponses
	 * @return ignoreDupResponses value from local variable or value bindings
	 */
	 public boolean isIgnoreDupResponses(  ){
	 		 if(this._ignoreDupResponsesSet){
			return this._ignoreDupResponses;
		 }
    	ValueBinding vb = getValueBinding("ignoreDupResponses");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ignoreDupResponses;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ignoreDupResponses);
    	}
	 	 }
	   	/*
	 * HTML: a script expression; a pointer is moved within
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * HTML: a script expression; a pointer is moved within
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.Tab";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[37];
        values[0] = super.saveState(context);
   	 	          values[1] = _title;
	   	 	
  	 	          values[2] = _oncomplete;
	   	 	
   	 	          values[3] = _reRender;
	   	 	
   	        values[4] = new Boolean(_bypassUpdates);
	   	   values[5] = Boolean.valueOf(_bypassUpdatesSet);	
	   	 	
  	 	          values[6] = _styleClass;
	   	 	
   	        values[7] = new Boolean(_limitToList);
	   	   values[8] = Boolean.valueOf(_limitToListSet);	
	   	 	
  	 	          values[9] = _onkeypress;
	   	 	
  	        values[10] = new Boolean(_ajaxSingle);
	   	   values[11] = Boolean.valueOf(_ajaxSingleSet);	
	   	 	
  	 	          values[12] = _ondblclick;
	   	 	
  	 	          values[13] = _style;
	   	 	
  	 	          values[14] = _name;
	   	 	
  	 	          values[15] = _onmouseover;
	   	 	
   	 	          values[16] = _value;
	   	 	
   	 	          values[17] = _onkeyup;
	   	 	
  	        values[18] = new Integer(_timeout);
	   	   values[19] = Boolean.valueOf(_timeoutSet);	
	   	 	
   	        values[20] = new Boolean(_disabled);
	   	   values[21] = Boolean.valueOf(_disabledSet);	
	   	 	
  	 	          values[22] = _onclick;
	   	 	
  	 	          values[23] = _status;
	   	 	
  	 	          values[24] = _onmouseout;
	   	 	
  	 	          values[25] = _onkeydown;
	   	 	
  	 	          values[26] = _onmousedown;
	   	 	
  	        values[27] = new Integer(_requestDelay);
	   	   values[28] = Boolean.valueOf(_requestDelaySet);	
	   	 	
   	 	          values[29] = _eventsQueue;
	   	 	
  	 	          values[30] = _labelWidth;
	   	 	
  	 	          values[31] = _label;
	   	 	
   	 	          values[32] = _data;
	   	 	
  	 	          values[33] = _onmouseup;
	   	 	
   	        values[34] = new Boolean(_ignoreDupResponses);
	   	   values[35] = Boolean.valueOf(_ignoreDupResponsesSet);	
	   	 	
  	 	          values[36] = _onmousemove;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
   	 	          _title = (String)values[1] ;
	   	 	
  	 	          _oncomplete = (String)values[2] ;
	   	 	
   	 	          _reRender = (Object)values[3] ;
	   	 	
   	        _bypassUpdates = ((Boolean)values[4]).booleanValue();
	   	   _bypassUpdatesSet = ((Boolean)values[5]).booleanValue();	
	   	 	
  	 	          _styleClass = (String)values[6] ;
	   	 	
   	        _limitToList = ((Boolean)values[7]).booleanValue();
	   	   _limitToListSet = ((Boolean)values[8]).booleanValue();	
	   	 	
  	 	          _onkeypress = (String)values[9] ;
	   	 	
  	        _ajaxSingle = ((Boolean)values[10]).booleanValue();
	   	   _ajaxSingleSet = ((Boolean)values[11]).booleanValue();	
	   	 	
  	 	          _ondblclick = (String)values[12] ;
	   	 	
  	 	          _style = (String)values[13] ;
	   	 	
  	 	          _name = (Object)values[14] ;
	   	 	
  	 	          _onmouseover = (String)values[15] ;
	   	 	
   	 	          _value = (Object)values[16] ;
	   	 	
   	 	          _onkeyup = (String)values[17] ;
	   	 	
  	        _timeout = ((Integer)values[18]).intValue();
	   	   _timeoutSet = ((Boolean)values[19]).booleanValue();	
	   	 	
   	        _disabled = ((Boolean)values[20]).booleanValue();
	   	   _disabledSet = ((Boolean)values[21]).booleanValue();	
	   	 	
  	 	          _onclick = (String)values[22] ;
	   	 	
  	 	          _status = (String)values[23] ;
	   	 	
  	 	          _onmouseout = (String)values[24] ;
	   	 	
  	 	          _onkeydown = (String)values[25] ;
	   	 	
  	 	          _onmousedown = (String)values[26] ;
	   	 	
  	        _requestDelay = ((Integer)values[27]).intValue();
	   	   _requestDelaySet = ((Boolean)values[28]).booleanValue();	
	   	 	
   	 	          _eventsQueue = (String)values[29] ;
	   	 	
  	 	          _labelWidth = (String)values[30] ;
	   	 	
  	 	          _label = (String)values[31] ;
	   	 	
   	 	          _data = (Object)values[32] ;
	   	 	
  	 	          _onmouseup = (String)values[33] ;
	   	 	
   	        _ignoreDupResponses = ((Boolean)values[34]).booleanValue();
	   	   _ignoreDupResponsesSet = ((Boolean)values[35]).booleanValue();	
	   	 	
  	 	          _onmousemove = (String)values[36] ;
	   	 	
 	
		
	}	
// Utilites

}