/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import java.lang.Object ;
import org.richfaces.component.UIToggleControl ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.ToggleControl
 * Component-Family javax.faces.command
  	 * Renderer-Type org.richfaces.ToggleControlRenderer
  	 * Toggle Control
 */
 public class HtmlToggleControl extends org.richfaces.component.UIToggleControl {

  public static final String COMPONENT_TYPE = "org.richfaces.ToggleControl";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlToggleControl (){
  	  	setRendererType("org.richfaces.ToggleControlRenderer");
  	  }

// Component properties fields
   	/**
	 * title
	 * Advisory title information about markup elements
				generated for this component
	 */
	 	 private String  _title = null; /* Default is null*/
	 	  	/**
	 * localValueSet
	 * ${prop.xmlEncodedDescription}
	 */
	 	 private boolean  _localValueSet = false;		
	/**
	 * Flag indicated what localValueSet is set.
	 */
	 private boolean _localValueSetSet = false;	
	 	  	/**
	 * oncomplete
	 * JavaScript code for call after request completed on
				client side
	 */
	 	 private String  _oncomplete = null; /* Default is null*/
	 	    	/**
	 * dir
	 * Direction indication for text that does not inherit
				directionality. Valid values are "LTR" (left-to-right)
				and "RTL" (right-to-left)
	 */
	 	 private String  _dir = null; /* Default is null*/
	 	   	/**
	 * bypassUpdates
	 * If "true", after process validations phase skip updates
				of model beans an force render response. Can be used for
				validate components input
	 */
	 	 private boolean  _bypassUpdates = false;		
	/**
	 * Flag indicated what bypassUpdates is set.
	 */
	 private boolean _bypassUpdatesSet = false;	
	 	  	/**
	 * styleClass
	 * Space-separated list of CSS style class(es) to be
				applied when this element is rendered. This value must
				be passed through as the "class" attribute on generated
				markup
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * accesskey
	 * Access key that, when pressed, transfers focus to this
				element
	 */
	 	 private String  _accesskey = null; /* Default is null*/
	 	  	/**
	 * switchToState
	 * Contains one of the facets names where target togglePanel is switched to
	 */
	 	 private String  _switchToState = null; /* Default is null*/
	 	  	/**
	 * limitToList
	 * If "true", updates on client side ONLY elements from this
				'reRender' property. if "false" (default) updates all
				rendered by ajax region components
	 */
	 	 private boolean  _limitToList = false;		
	/**
	 * Flag indicated what limitToList is set.
	 */
	 private boolean _limitToListSet = false;	
	 	  	/**
	 * onkeypress
	 * JavaScript code executed when a key is pressed and
				released over this element
	 */
	 	 private String  _onkeypress = null; /* Default is null*/
	 	  	/**
	 * ajaxSingle
	 * if true, submit ONLY one field/link, instead of all
				form controls
	 */
	 	 private boolean  _ajaxSingle = false;		
	/**
	 * Flag indicated what ajaxSingle is set.
	 */
	 private boolean _ajaxSingleSet = false;	
	 	  	/**
	 * ondblclick
	 * Javascript code executed when a pointer button is double
				clicked over this element
	 */
	 	 private String  _ondblclick = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) to be applied when this component is
				rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * panelId
	 * 
	 */
	 	 private String  _panelId = null; /* Default is null*/
	 	  	/**
	 * onblur
	 * Javascript code executed when this element loses focus
	 */
	 	 private String  _onblur = null; /* Default is null*/
	 	  	/**
	 * onmouseover
	 * JavaScript code executed when a pointer button is moved
				onto this element
	 */
	 	 private String  _onmouseover = null; /* Default is null*/
	 	  	/**
	 * for
	 * String containing comma separated ids (in the format of a UIComponent.findComponent()
					 call) of the target components.
	 */
	 	 private String  _for = null; /* Default is null*/
	 	    	/**
	 * onkeyup
	 * JavaScript code executed when a key is released over
				this element
	 */
	 	 private String  _onkeyup = null; /* Default is null*/
	 	  	/**
	 * tabindex
	 * Position of this element in the tabbing order for the
				current document. This value must be an integer between
				0 and 32767
	 */
	 	 private String  _tabindex = null; /* Default is null*/
	 	  	/**
	 * timeout
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 */
	 	 private int  _timeout = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what timeout is set.
	 */
	 private boolean _timeoutSet = false;	
	 	   	/**
	 * lang
	 * Code describing the language used in the generated
				markup for this component
	 */
	 	 private String  _lang = null; /* Default is null*/
	 	  	/**
	 * onclick
	 * Javascript code executed when a pointer button is
				clicked over this element
	 */
	 	 private String  _onclick = null; /* Default is null*/
	 	  	/**
	 * status
	 * ID (in format of call UIComopnent.findComponent()) of
				Request status component
	 */
	 	 private String  _status = null; /* Default is null*/
	 	  	/**
	 * onmouseout
	 * JavaScript code executed when a pointer button is moved
				away from this element
	 */
	 	 private String  _onmouseout = null; /* Default is null*/
	 	  	/**
	 * onkeydown
	 * JavaScript code executed when a key is pressed down over
				this element
	 */
	 	 private String  _onkeydown = null; /* Default is null*/
	 	  	/**
	 * onmousedown
	 * JavaScript code executed when a pointer button is
				pressed down over this element
	 */
	 	 private String  _onmousedown = null; /* Default is null*/
	 	  	/**
	 * requestDelay
	 * Delay (in ms.) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events
	 */
	 	 private int  _requestDelay = Integer.MIN_VALUE;		
	/**
	 * Flag indicated what requestDelay is set.
	 */
	 private boolean _requestDelaySet = false;	
	 	  	/**
	 * eventsQueue
	 * Name of requests queue to avoid send next request before
				complete other from same event. Can be used to reduce
				number of requests of frequently events (key press,
				mouse move, etc.)
	 */
	 	 private String  _eventsQueue = null; /* Default is null*/
	 	   	/**
	 * data
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 */
	 	 private Object  _data = null; /* Default is null*/
	 	  	/**
	 * onfocus
	 * JavaScript code executed when this element receives
				focus
	 */
	 	 private String  _onfocus = null; /* Default is null*/
	 	  	/**
	 * onmouseup
	 * JavaScript code executed when a pointer button is
				released over this element
	 */
	 	 private String  _onmouseup = null; /* Default is null*/
	 	   	/**
	 * ignoreDupResponses
	 * If true, unfinished request will be aborted on new event
	 */
	 	 private boolean  _ignoreDupResponses = false;		
	/**
	 * Flag indicated what ignoreDupResponses is set.
	 */
	 private boolean _ignoreDupResponsesSet = false;	
	 	  	/**
	 * onmousemove
	 * JavaScript code executed when a pointer button is moved
				within this element
	 */
	 	 private String  _onmousemove = null; /* Default is null*/
	 	  
// Getters-setters
   	/*
	 * Advisory title information about markup elements
				generated for this component
	 * Setter for title
	 * @param title - new value
	 */
	 public void setTitle( String  __title ){
		this._title = __title;
	 	 }


	/*
	 * Advisory title information about markup elements
				generated for this component
	 * Getter for title
	 * @return title value from local variable or value bindings
	 */
	 public String getTitle(  ){
	         if (null != this._title)
        {
            return this._title;
        	    }
        ValueBinding vb = getValueBinding("title");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ${prop.xmlEncodedDescription}
	 * Setter for localValueSet
	 * @param localValueSet - new value
	 */
	 public void setLocalValueSet( boolean  __localValueSet ){
		this._localValueSet = __localValueSet;
	 		this._localValueSetSet = true;
	 	 }


	/*
	 * ${prop.xmlEncodedDescription}
	 * Getter for localValueSet
	 * @return localValueSet value from local variable or value bindings
	 */
	 public boolean isLocalValueSet(  ){
	 		 if(this._localValueSetSet){
			return this._localValueSet;
		 }
    	ValueBinding vb = getValueBinding("localValueSet");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._localValueSet;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._localValueSet);
    	}
	 	 }
	   	/*
	 * JavaScript code for call after request completed on
				client side
	 * Setter for oncomplete
	 * @param oncomplete - new value
	 */
	 public void setOncomplete( String  __oncomplete ){
		this._oncomplete = __oncomplete;
	 	 }


	/*
	 * JavaScript code for call after request completed on
				client side
	 * Getter for oncomplete
	 * @return oncomplete value from local variable or value bindings
	 */
	 public String getOncomplete(  ){
	         if (null != this._oncomplete)
        {
            return this._oncomplete;
        	    }
        ValueBinding vb = getValueBinding("oncomplete");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * Direction indication for text that does not inherit
				directionality. Valid values are "LTR" (left-to-right)
				and "RTL" (right-to-left)
	 * Setter for dir
	 * @param dir - new value
	 */
	 public void setDir( String  __dir ){
		this._dir = __dir;
	 	 }


	/*
	 * Direction indication for text that does not inherit
				directionality. Valid values are "LTR" (left-to-right)
				and "RTL" (right-to-left)
	 * Getter for dir
	 * @return dir value from local variable or value bindings
	 */
	 public String getDir(  ){
	         if (null != this._dir)
        {
            return this._dir;
        	    }
        ValueBinding vb = getValueBinding("dir");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If "true", after process validations phase skip updates
				of model beans an force render response. Can be used for
				validate components input
	 * Setter for bypassUpdates
	 * @param bypassUpdates - new value
	 */
	 public void setBypassUpdates( boolean  __bypassUpdates ){
		this._bypassUpdates = __bypassUpdates;
	 		this._bypassUpdatesSet = true;
	 	 }


	/*
	 * If "true", after process validations phase skip updates
				of model beans an force render response. Can be used for
				validate components input
	 * Getter for bypassUpdates
	 * @return bypassUpdates value from local variable or value bindings
	 */
	 public boolean isBypassUpdates(  ){
	 		 if(this._bypassUpdatesSet){
			return this._bypassUpdates;
		 }
    	ValueBinding vb = getValueBinding("bypassUpdates");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._bypassUpdates;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._bypassUpdates);
    	}
	 	 }
	   	/*
	 * Space-separated list of CSS style class(es) to be
				applied when this element is rendered. This value must
				be passed through as the "class" attribute on generated
				markup
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Space-separated list of CSS style class(es) to be
				applied when this element is rendered. This value must
				be passed through as the "class" attribute on generated
				markup
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Access key that, when pressed, transfers focus to this
				element
	 * Setter for accesskey
	 * @param accesskey - new value
	 */
	 public void setAccesskey( String  __accesskey ){
		this._accesskey = __accesskey;
	 	 }


	/*
	 * Access key that, when pressed, transfers focus to this
				element
	 * Getter for accesskey
	 * @return accesskey value from local variable or value bindings
	 */
	 public String getAccesskey(  ){
	         if (null != this._accesskey)
        {
            return this._accesskey;
        	    }
        ValueBinding vb = getValueBinding("accesskey");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Contains one of the facets names where target togglePanel is switched to
	 * Setter for switchToState
	 * @param switchToState - new value
	 */
	 public void setSwitchToState( String  __switchToState ){
		this._switchToState = __switchToState;
	 	 }


	/*
	 * Contains one of the facets names where target togglePanel is switched to
	 * Getter for switchToState
	 * @return switchToState value from local variable or value bindings
	 */
	 public String getSwitchToState(  ){
	         if (null != this._switchToState)
        {
            return this._switchToState;
        	    }
        ValueBinding vb = getValueBinding("switchToState");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * If "true", updates on client side ONLY elements from this
				'reRender' property. if "false" (default) updates all
				rendered by ajax region components
	 * Setter for limitToList
	 * @param limitToList - new value
	 */
	 public void setLimitToList( boolean  __limitToList ){
		this._limitToList = __limitToList;
	 		this._limitToListSet = true;
	 	 }


	/*
	 * If "true", updates on client side ONLY elements from this
				'reRender' property. if "false" (default) updates all
				rendered by ajax region components
	 * Getter for limitToList
	 * @return limitToList value from local variable or value bindings
	 */
	 public boolean isLimitToList(  ){
	 		 if(this._limitToListSet){
			return this._limitToList;
		 }
    	ValueBinding vb = getValueBinding("limitToList");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._limitToList;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._limitToList);
    	}
	 	 }
	   	/*
	 * JavaScript code executed when a key is pressed and
				released over this element
	 * Setter for onkeypress
	 * @param onkeypress - new value
	 */
	 public void setOnkeypress( String  __onkeypress ){
		this._onkeypress = __onkeypress;
	 	 }


	/*
	 * JavaScript code executed when a key is pressed and
				released over this element
	 * Getter for onkeypress
	 * @return onkeypress value from local variable or value bindings
	 */
	 public String getOnkeypress(  ){
	         if (null != this._onkeypress)
        {
            return this._onkeypress;
        	    }
        ValueBinding vb = getValueBinding("onkeypress");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * if true, submit ONLY one field/link, instead of all
				form controls
	 * Setter for ajaxSingle
	 * @param ajaxSingle - new value
	 */
	 public void setAjaxSingle( boolean  __ajaxSingle ){
		this._ajaxSingle = __ajaxSingle;
	 		this._ajaxSingleSet = true;
	 	 }


	/*
	 * if true, submit ONLY one field/link, instead of all
				form controls
	 * Getter for ajaxSingle
	 * @return ajaxSingle value from local variable or value bindings
	 */
	 public boolean isAjaxSingle(  ){
	 		 if(this._ajaxSingleSet){
			return this._ajaxSingle;
		 }
    	ValueBinding vb = getValueBinding("ajaxSingle");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSingle;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSingle);
    	}
	 	 }
	   	/*
	 * Javascript code executed when a pointer button is double
				clicked over this element
	 * Setter for ondblclick
	 * @param ondblclick - new value
	 */
	 public void setOndblclick( String  __ondblclick ){
		this._ondblclick = __ondblclick;
	 	 }


	/*
	 * Javascript code executed when a pointer button is double
				clicked over this element
	 * Getter for ondblclick
	 * @return ondblclick value from local variable or value bindings
	 */
	 public String getOndblclick(  ){
	         if (null != this._ondblclick)
        {
            return this._ondblclick;
        	    }
        ValueBinding vb = getValueBinding("ondblclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) to be applied when this component is
				rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) to be applied when this component is
				rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * 
	 * Setter for panelId
	 * @param panelId - new value
	 */
	 public void setPanelId( String  __panelId ){
		this._panelId = __panelId;
	 	 }


	/*
	 * 
	 * Getter for panelId
	 * @return panelId value from local variable or value bindings
	 */
	 public String getPanelId(  ){
	         if (null != this._panelId)
        {
            return this._panelId;
        	    }
        ValueBinding vb = getValueBinding("panelId");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Javascript code executed when this element loses focus
	 * Setter for onblur
	 * @param onblur - new value
	 */
	 public void setOnblur( String  __onblur ){
		this._onblur = __onblur;
	 	 }


	/*
	 * Javascript code executed when this element loses focus
	 * Getter for onblur
	 * @return onblur value from local variable or value bindings
	 */
	 public String getOnblur(  ){
	         if (null != this._onblur)
        {
            return this._onblur;
        	    }
        ValueBinding vb = getValueBinding("onblur");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when a pointer button is moved
				onto this element
	 * Setter for onmouseover
	 * @param onmouseover - new value
	 */
	 public void setOnmouseover( String  __onmouseover ){
		this._onmouseover = __onmouseover;
	 	 }


	/*
	 * JavaScript code executed when a pointer button is moved
				onto this element
	 * Getter for onmouseover
	 * @return onmouseover value from local variable or value bindings
	 */
	 public String getOnmouseover(  ){
	         if (null != this._onmouseover)
        {
            return this._onmouseover;
        	    }
        ValueBinding vb = getValueBinding("onmouseover");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * String containing comma separated ids (in the format of a UIComponent.findComponent()
					 call) of the target components.
	 * Setter for for
	 * @param for - new value
	 */
	 public void setFor( String  __for ){
		this._for = __for;
	 	 }


	/*
	 * String containing comma separated ids (in the format of a UIComponent.findComponent()
					 call) of the target components.
	 * Getter for for
	 * @return for value from local variable or value bindings
	 */
	 public String getFor(  ){
	         if (null != this._for)
        {
            return this._for;
        	    }
        ValueBinding vb = getValueBinding("for");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * JavaScript code executed when a key is released over
				this element
	 * Setter for onkeyup
	 * @param onkeyup - new value
	 */
	 public void setOnkeyup( String  __onkeyup ){
		this._onkeyup = __onkeyup;
	 	 }


	/*
	 * JavaScript code executed when a key is released over
				this element
	 * Getter for onkeyup
	 * @return onkeyup value from local variable or value bindings
	 */
	 public String getOnkeyup(  ){
	         if (null != this._onkeyup)
        {
            return this._onkeyup;
        	    }
        ValueBinding vb = getValueBinding("onkeyup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Position of this element in the tabbing order for the
				current document. This value must be an integer between
				0 and 32767
	 * Setter for tabindex
	 * @param tabindex - new value
	 */
	 public void setTabindex( String  __tabindex ){
		this._tabindex = __tabindex;
	 	 }


	/*
	 * Position of this element in the tabbing order for the
				current document. This value must be an integer between
				0 and 32767
	 * Getter for tabindex
	 * @return tabindex value from local variable or value bindings
	 */
	 public String getTabindex(  ){
	         if (null != this._tabindex)
        {
            return this._tabindex;
        	    }
        ValueBinding vb = getValueBinding("tabindex");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Setter for timeout
	 * @param timeout - new value
	 */
	 public void setTimeout( int  __timeout ){
		this._timeout = __timeout;
	 		this._timeoutSet = true;
	 	 }


	/*
	 * response waiting time on a particular request. If a response is not received during this time, the request is aborted
	 * Getter for timeout
	 * @return timeout value from local variable or value bindings
	 */
	 public int getTimeout(  ){
	 		 if(this._timeoutSet){
			return this._timeout;
		 }
    	ValueBinding vb = getValueBinding("timeout");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._timeout;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._timeout);
    	}
	 	 }
	    	/*
	 * Code describing the language used in the generated
				markup for this component
	 * Setter for lang
	 * @param lang - new value
	 */
	 public void setLang( String  __lang ){
		this._lang = __lang;
	 	 }


	/*
	 * Code describing the language used in the generated
				markup for this component
	 * Getter for lang
	 * @return lang value from local variable or value bindings
	 */
	 public String getLang(  ){
	         if (null != this._lang)
        {
            return this._lang;
        	    }
        ValueBinding vb = getValueBinding("lang");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Javascript code executed when a pointer button is
				clicked over this element
	 * Setter for onclick
	 * @param onclick - new value
	 */
	 public void setOnclick( String  __onclick ){
		this._onclick = __onclick;
	 	 }


	/*
	 * Javascript code executed when a pointer button is
				clicked over this element
	 * Getter for onclick
	 * @return onclick value from local variable or value bindings
	 */
	 public String getOnclick(  ){
	         if (null != this._onclick)
        {
            return this._onclick;
        	    }
        ValueBinding vb = getValueBinding("onclick");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * ID (in format of call UIComopnent.findComponent()) of
				Request status component
	 * Setter for status
	 * @param status - new value
	 */
	 public void setStatus( String  __status ){
		this._status = __status;
	 	 }


	/*
	 * ID (in format of call UIComopnent.findComponent()) of
				Request status component
	 * Getter for status
	 * @return status value from local variable or value bindings
	 */
	 public String getStatus(  ){
	         if (null != this._status)
        {
            return this._status;
        	    }
        ValueBinding vb = getValueBinding("status");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when a pointer button is moved
				away from this element
	 * Setter for onmouseout
	 * @param onmouseout - new value
	 */
	 public void setOnmouseout( String  __onmouseout ){
		this._onmouseout = __onmouseout;
	 	 }


	/*
	 * JavaScript code executed when a pointer button is moved
				away from this element
	 * Getter for onmouseout
	 * @return onmouseout value from local variable or value bindings
	 */
	 public String getOnmouseout(  ){
	         if (null != this._onmouseout)
        {
            return this._onmouseout;
        	    }
        ValueBinding vb = getValueBinding("onmouseout");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when a key is pressed down over
				this element
	 * Setter for onkeydown
	 * @param onkeydown - new value
	 */
	 public void setOnkeydown( String  __onkeydown ){
		this._onkeydown = __onkeydown;
	 	 }


	/*
	 * JavaScript code executed when a key is pressed down over
				this element
	 * Getter for onkeydown
	 * @return onkeydown value from local variable or value bindings
	 */
	 public String getOnkeydown(  ){
	         if (null != this._onkeydown)
        {
            return this._onkeydown;
        	    }
        ValueBinding vb = getValueBinding("onkeydown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when a pointer button is
				pressed down over this element
	 * Setter for onmousedown
	 * @param onmousedown - new value
	 */
	 public void setOnmousedown( String  __onmousedown ){
		this._onmousedown = __onmousedown;
	 	 }


	/*
	 * JavaScript code executed when a pointer button is
				pressed down over this element
	 * Getter for onmousedown
	 * @return onmousedown value from local variable or value bindings
	 */
	 public String getOnmousedown(  ){
	         if (null != this._onmousedown)
        {
            return this._onmousedown;
        	    }
        ValueBinding vb = getValueBinding("onmousedown");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Delay (in ms.) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events
	 * Setter for requestDelay
	 * @param requestDelay - new value
	 */
	 public void setRequestDelay( int  __requestDelay ){
		this._requestDelay = __requestDelay;
	 		this._requestDelaySet = true;
	 	 }


	/*
	 * Delay (in ms.) for send ajax request on JavaScript
				event. In conjunction with events queue can reduce
				number of requests on keyboard or mouse move events
	 * Getter for requestDelay
	 * @return requestDelay value from local variable or value bindings
	 */
	 public int getRequestDelay(  ){
	 		 if(this._requestDelaySet){
			return this._requestDelay;
		 }
    	ValueBinding vb = getValueBinding("requestDelay");
    	if (vb != null) {
    	    Integer value = (Integer) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._requestDelay;
    	    }
    	    return (value.intValue());
    	} else {
    	    return (this._requestDelay);
    	}
	 	 }
	   	/*
	 * Name of requests queue to avoid send next request before
				complete other from same event. Can be used to reduce
				number of requests of frequently events (key press,
				mouse move, etc.)
	 * Setter for eventsQueue
	 * @param eventsQueue - new value
	 */
	 public void setEventsQueue( String  __eventsQueue ){
		this._eventsQueue = __eventsQueue;
	 	 }


	/*
	 * Name of requests queue to avoid send next request before
				complete other from same event. Can be used to reduce
				number of requests of frequently events (key press,
				mouse move, etc.)
	 * Getter for eventsQueue
	 * @return eventsQueue value from local variable or value bindings
	 */
	 public String getEventsQueue(  ){
	         if (null != this._eventsQueue)
        {
            return this._eventsQueue;
        	    }
        ValueBinding vb = getValueBinding("eventsQueue");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Setter for data
	 * @param data - new value
	 */
	 public void setData( Object  __data ){
		this._data = __data;
	 	 }


	/*
	 * Serialized (on default with JSON) data passed on the client by a developer on AJAX request. It's accessible via this.data
	 * Getter for data
	 * @return data value from local variable or value bindings
	 */
	 public Object getData(  ){
	         if (null != this._data)
        {
            return this._data;
        	    }
        ValueBinding vb = getValueBinding("data");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when this element receives
				focus
	 * Setter for onfocus
	 * @param onfocus - new value
	 */
	 public void setOnfocus( String  __onfocus ){
		this._onfocus = __onfocus;
	 	 }


	/*
	 * JavaScript code executed when this element receives
				focus
	 * Getter for onfocus
	 * @return onfocus value from local variable or value bindings
	 */
	 public String getOnfocus(  ){
	         if (null != this._onfocus)
        {
            return this._onfocus;
        	    }
        ValueBinding vb = getValueBinding("onfocus");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * JavaScript code executed when a pointer button is
				released over this element
	 * Setter for onmouseup
	 * @param onmouseup - new value
	 */
	 public void setOnmouseup( String  __onmouseup ){
		this._onmouseup = __onmouseup;
	 	 }


	/*
	 * JavaScript code executed when a pointer button is
				released over this element
	 * Getter for onmouseup
	 * @return onmouseup value from local variable or value bindings
	 */
	 public String getOnmouseup(  ){
	         if (null != this._onmouseup)
        {
            return this._onmouseup;
        	    }
        ValueBinding vb = getValueBinding("onmouseup");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If true, unfinished request will be aborted on new event
	 * Setter for ignoreDupResponses
	 * @param ignoreDupResponses - new value
	 */
	 public void setIgnoreDupResponses( boolean  __ignoreDupResponses ){
		this._ignoreDupResponses = __ignoreDupResponses;
	 		this._ignoreDupResponsesSet = true;
	 	 }


	/*
	 * If true, unfinished request will be aborted on new event
	 * Getter for ignoreDupResponses
	 * @return ignoreDupResponses value from local variable or value bindings
	 */
	 public boolean isIgnoreDupResponses(  ){
	 		 if(this._ignoreDupResponsesSet){
			return this._ignoreDupResponses;
		 }
    	ValueBinding vb = getValueBinding("ignoreDupResponses");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ignoreDupResponses;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ignoreDupResponses);
    	}
	 	 }
	   	/*
	 * JavaScript code executed when a pointer button is moved
				within this element
	 * Setter for onmousemove
	 * @param onmousemove - new value
	 */
	 public void setOnmousemove( String  __onmousemove ){
		this._onmousemove = __onmousemove;
	 	 }


	/*
	 * JavaScript code executed when a pointer button is moved
				within this element
	 * Getter for onmousemove
	 * @return onmousemove value from local variable or value bindings
	 */
	 public String getOnmousemove(  ){
	         if (null != this._onmousemove)
        {
            return this._onmousemove;
        	    }
        ValueBinding vb = getValueBinding("onmousemove");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   
// Component family.
	public static final String COMPONENT_FAMILY = "javax.faces.command";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[41];
        values[0] = super.saveState(context);
   	 	          values[1] = _title;
	   	 	
  	        values[2] = new Boolean(_localValueSet);
	   	   values[3] = Boolean.valueOf(_localValueSetSet);	
	   	 	
  	 	          values[4] = _oncomplete;
	   	 	
    	 	          values[5] = _dir;
	   	 	
   	        values[6] = new Boolean(_bypassUpdates);
	   	   values[7] = Boolean.valueOf(_bypassUpdatesSet);	
	   	 	
  	 	          values[8] = _styleClass;
	   	 	
  	 	          values[9] = _accesskey;
	   	 	
  	 	          values[10] = _switchToState;
	   	 	
  	        values[11] = new Boolean(_limitToList);
	   	   values[12] = Boolean.valueOf(_limitToListSet);	
	   	 	
  	 	          values[13] = _onkeypress;
	   	 	
  	        values[14] = new Boolean(_ajaxSingle);
	   	   values[15] = Boolean.valueOf(_ajaxSingleSet);	
	   	 	
  	 	          values[16] = _ondblclick;
	   	 	
  	 	          values[17] = _style;
	   	 	
  	 	          values[18] = _panelId;
	   	 	
  	 	          values[19] = _onblur;
	   	 	
  	 	          values[20] = _onmouseover;
	   	 	
  	 	          values[21] = _for;
	   	 	
    	 	          values[22] = _onkeyup;
	   	 	
  	 	          values[23] = _tabindex;
	   	 	
  	        values[24] = new Integer(_timeout);
	   	   values[25] = Boolean.valueOf(_timeoutSet);	
	   	 	
   	 	          values[26] = _lang;
	   	 	
  	 	          values[27] = _onclick;
	   	 	
  	 	          values[28] = _status;
	   	 	
  	 	          values[29] = _onmouseout;
	   	 	
  	 	          values[30] = _onkeydown;
	   	 	
  	 	          values[31] = _onmousedown;
	   	 	
  	        values[32] = new Integer(_requestDelay);
	   	   values[33] = Boolean.valueOf(_requestDelaySet);	
	   	 	
  	 	          values[34] = _eventsQueue;
	   	 	
   	 	          values[35] = _data;
	   	 	
  	 	          values[36] = _onfocus;
	   	 	
  	 	          values[37] = _onmouseup;
	   	 	
   	        values[38] = new Boolean(_ignoreDupResponses);
	   	   values[39] = Boolean.valueOf(_ignoreDupResponsesSet);	
	   	 	
  	 	          values[40] = _onmousemove;
	   	 	
  	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
   	 	          _title = (String)values[1] ;
	   	 	
  	        _localValueSet = ((Boolean)values[2]).booleanValue();
	   	   _localValueSetSet = ((Boolean)values[3]).booleanValue();	
	   	 	
  	 	          _oncomplete = (String)values[4] ;
	   	 	
    	 	          _dir = (String)values[5] ;
	   	 	
   	        _bypassUpdates = ((Boolean)values[6]).booleanValue();
	   	   _bypassUpdatesSet = ((Boolean)values[7]).booleanValue();	
	   	 	
  	 	          _styleClass = (String)values[8] ;
	   	 	
  	 	          _accesskey = (String)values[9] ;
	   	 	
  	 	          _switchToState = (String)values[10] ;
	   	 	
  	        _limitToList = ((Boolean)values[11]).booleanValue();
	   	   _limitToListSet = ((Boolean)values[12]).booleanValue();	
	   	 	
  	 	          _onkeypress = (String)values[13] ;
	   	 	
  	        _ajaxSingle = ((Boolean)values[14]).booleanValue();
	   	   _ajaxSingleSet = ((Boolean)values[15]).booleanValue();	
	   	 	
  	 	          _ondblclick = (String)values[16] ;
	   	 	
  	 	          _style = (String)values[17] ;
	   	 	
  	 	          _panelId = (String)values[18] ;
	   	 	
  	 	          _onblur = (String)values[19] ;
	   	 	
  	 	          _onmouseover = (String)values[20] ;
	   	 	
  	 	          _for = (String)values[21] ;
	   	 	
    	 	          _onkeyup = (String)values[22] ;
	   	 	
  	 	          _tabindex = (String)values[23] ;
	   	 	
  	        _timeout = ((Integer)values[24]).intValue();
	   	   _timeoutSet = ((Boolean)values[25]).booleanValue();	
	   	 	
   	 	          _lang = (String)values[26] ;
	   	 	
  	 	          _onclick = (String)values[27] ;
	   	 	
  	 	          _status = (String)values[28] ;
	   	 	
  	 	          _onmouseout = (String)values[29] ;
	   	 	
  	 	          _onkeydown = (String)values[30] ;
	   	 	
  	 	          _onmousedown = (String)values[31] ;
	   	 	
  	        _requestDelay = ((Integer)values[32]).intValue();
	   	   _requestDelaySet = ((Boolean)values[33]).booleanValue();	
	   	 	
  	 	          _eventsQueue = (String)values[34] ;
	   	 	
   	 	          _data = (Object)values[35] ;
	   	 	
  	 	          _onfocus = (String)values[36] ;
	   	 	
  	 	          _onmouseup = (String)values[37] ;
	   	 	
   	        _ignoreDupResponses = ((Boolean)values[38]).booleanValue();
	   	   _ignoreDupResponsesSet = ((Boolean)values[39]).booleanValue();	
	   	 	
  	 	          _onmousemove = (String)values[40] ;
	   	 	
  	
		
	}	
// Utilites

}