/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UITogglePanel ;
import java.lang.Object ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.TogglePanel
 * Component-Family org.richfaces.TogglePanel
  	 * Renderer-Type org.richfaces.TogglePanelRenderer
  	 * A collapsible panel, which content is shown/hidden after activating a header control.
 */
 public class HtmlTogglePanel extends org.richfaces.component.UITogglePanel {

  public static final String COMPONENT_TYPE = "org.richfaces.TogglePanel";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlTogglePanel (){
  	  	setRendererType("org.richfaces.TogglePanelRenderer");
  	  }

// Component properties fields
  	/**
	 * value
	 * The initial value to set when rendered for the first time.
				It contains information about an active facet
	 */
	 	 private Object  _value = null; /* Default is null*/
	 	  	/**
	 * stateOrder
	 * Names of the facets in the switching order. If
				ToggleControl doesn't contain information about a next facet to
				be shown it is switched corresponding to this
				attribute
	 */
	 	 private String  _stateOrder = null; /* Default is null*/
	 	          	/**
	 * initialState
	 * It contains a name of the first active facet
	 */
	 	 private String  _initialState = null; /* Default is null*/
	 	   	/**
	 * switchType
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 */
	 	 private String  _switchType = null; /* Default is DEFAULT_METHOD*/
	 	     
// Getters-setters
  	/*
	 * The initial value to set when rendered for the first time.
				It contains information about an active facet
	 * Setter for value
	 * @param value - new value
	 */
	 public void setValue( Object  __value ){
		this._value = __value;
	 	 }


	/*
	 * The initial value to set when rendered for the first time.
				It contains information about an active facet
	 * Getter for value
	 * @return value value from local variable or value bindings
	 */
	 public Object getValue(  ){
	         if (null != this._value)
        {
            return this._value;
        	    }
        ValueBinding vb = getValueBinding("value");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Names of the facets in the switching order. If
				ToggleControl doesn't contain information about a next facet to
				be shown it is switched corresponding to this
				attribute
	 * Setter for stateOrder
	 * @param stateOrder - new value
	 */
	 public void setStateOrder( String  __stateOrder ){
		this._stateOrder = __stateOrder;
	 	 }


	/*
	 * Names of the facets in the switching order. If
				ToggleControl doesn't contain information about a next facet to
				be shown it is switched corresponding to this
				attribute
	 * Getter for stateOrder
	 * @return stateOrder value from local variable or value bindings
	 */
	 public String getStateOrder(  ){
	         if (null != this._stateOrder)
        {
            return this._stateOrder;
        	    }
        ValueBinding vb = getValueBinding("stateOrder");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	           	/*
	 * It contains a name of the first active facet
	 * Setter for initialState
	 * @param initialState - new value
	 */
	 public void setInitialState( String  __initialState ){
		this._initialState = __initialState;
	 	 }


	/*
	 * It contains a name of the first active facet
	 * Getter for initialState
	 * @return initialState value from local variable or value bindings
	 */
	 public String getInitialState(  ){
	         if (null != this._initialState)
        {
            return this._initialState;
        	    }
        ValueBinding vb = getValueBinding("initialState");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 * Setter for switchType
	 * @param switchType - new value
	 */
	 public void setSwitchType( String  __switchType ){
		this._switchType = __switchType;
	 	 }


	/*
	 * Facets switch algorithm: "client", "server"(default), "ajax".
	 * Getter for switchType
	 * @return switchType value from local variable or value bindings
	 */
	 public String getSwitchType(  ){
	         if (null != this._switchType)
        {
            return this._switchType;
        	    }
        ValueBinding vb = getValueBinding("switchType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return DEFAULT_METHOD;
        }
	 	 }
	      
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.TogglePanel";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[5];
        values[0] = super.saveState(context);
  	 	          values[1] = _value;
	   	 	
  	 	          values[2] = _stateOrder;
	   	 	
          	 	          values[3] = _initialState;
	   	 	
   	 	          values[4] = _switchType;
	   	 	
     	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	 	          _value = (Object)values[1] ;
	   	 	
  	 	          _stateOrder = (String)values[2] ;
	   	 	
          	 	          _initialState = (String)values[3] ;
	   	 	
   	 	          _switchType = (String)values[4] ;
	   	 	
     	
		
	}	
// Utilites

}