/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIToolBar ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.ToolBar
 * Component-Family org.richfaces.ToolBar
  	 * Renderer-Type org.richfaces.ToolBarRenderer
  	 * A horizontal bar with Action items on it that accepts any JSF components as children.
 */
 public class HtmlToolBar extends org.richfaces.component.UIToolBar {

  public static final String COMPONENT_TYPE = "org.richfaces.ToolBar";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlToolBar (){
  	  	setRendererType("org.richfaces.ToolBarRenderer");
  	  }

// Component properties fields
 	/**
	 * contentClass
	 * A CSS style is to be applied to each element of tool bar content. 
    		Use this style, for example, to setup parameters of the font.
	 */
	 	 private String  _contentClass = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * width
	 * A width of a bar that can be defined in pixels or as percentage. The default value is 100%.
	 */
	 	 private String  _width = null; /* Default is "100%"*/
	 	  	/**
	 * height
	 * A height of a bar in pixels. If a height is not defined,
    		a bar height depends of the "headerFontSize" skin parameter.
	 */
	 	 private String  _height = null; /* Default is null*/
	 	  	/**
	 * contentStyle
	 * A CSS style is to be applied to each element of tool bar content.
	 */
	 	 private String  _contentStyle = null; /* Default is null*/
	 	  	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	   	/**
	 * separatorClass
	 * A CSS class to be applied to menu bar group separators.
    		Use this property, for example, to setup parameters of a font.
	 */
	 	 private String  _separatorClass = null; /* Default is null*/
	 	    	/**
	 * itemSeparator
	 * A separator between items on a bar. Possible values
    		are none, line, square, disc and grid.
	 */
	 	 private String  _itemSeparator = null; /* Default is "none"*/
	 	 
// Getters-setters
 	/*
	 * A CSS style is to be applied to each element of tool bar content. 
    		Use this style, for example, to setup parameters of the font.
	 * Setter for contentClass
	 * @param contentClass - new value
	 */
	 public void setContentClass( String  __contentClass ){
		this._contentClass = __contentClass;
	 	 }


	/*
	 * A CSS style is to be applied to each element of tool bar content. 
    		Use this style, for example, to setup parameters of the font.
	 * Getter for contentClass
	 * @return contentClass value from local variable or value bindings
	 */
	 public String getContentClass(  ){
	         if (null != this._contentClass)
        {
            return this._contentClass;
        	    }
        ValueBinding vb = getValueBinding("contentClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A width of a bar that can be defined in pixels or as percentage. The default value is 100%.
	 * Setter for width
	 * @param width - new value
	 */
	 public void setWidth( String  __width ){
		this._width = __width;
	 	 }


	/*
	 * A width of a bar that can be defined in pixels or as percentage. The default value is 100%.
	 * Getter for width
	 * @return width value from local variable or value bindings
	 */
	 public String getWidth(  ){
	         if (null != this._width)
        {
            return this._width;
        	    }
        ValueBinding vb = getValueBinding("width");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "100%";
        }
	 	 }
	   	/*
	 * A height of a bar in pixels. If a height is not defined,
    		a bar height depends of the "headerFontSize" skin parameter.
	 * Setter for height
	 * @param height - new value
	 */
	 public void setHeight( String  __height ){
		this._height = __height;
	 	 }


	/*
	 * A height of a bar in pixels. If a height is not defined,
    		a bar height depends of the "headerFontSize" skin parameter.
	 * Getter for height
	 * @return height value from local variable or value bindings
	 */
	 public String getHeight(  ){
	         if (null != this._height)
        {
            return this._height;
        	    }
        ValueBinding vb = getValueBinding("height");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A CSS style is to be applied to each element of tool bar content.
	 * Setter for contentStyle
	 * @param contentStyle - new value
	 */
	 public void setContentStyle( String  __contentStyle ){
		this._contentStyle = __contentStyle;
	 	 }


	/*
	 * A CSS style is to be applied to each element of tool bar content.
	 * Getter for contentStyle
	 * @return contentStyle value from local variable or value bindings
	 */
	 public String getContentStyle(  ){
	         if (null != this._contentStyle)
        {
            return this._contentStyle;
        	    }
        ValueBinding vb = getValueBinding("contentStyle");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A CSS class to be applied to menu bar group separators.
    		Use this property, for example, to setup parameters of a font.
	 * Setter for separatorClass
	 * @param separatorClass - new value
	 */
	 public void setSeparatorClass( String  __separatorClass ){
		this._separatorClass = __separatorClass;
	 	 }


	/*
	 * A CSS class to be applied to menu bar group separators.
    		Use this property, for example, to setup parameters of a font.
	 * Getter for separatorClass
	 * @return separatorClass value from local variable or value bindings
	 */
	 public String getSeparatorClass(  ){
	         if (null != this._separatorClass)
        {
            return this._separatorClass;
        	    }
        ValueBinding vb = getValueBinding("separatorClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * A separator between items on a bar. Possible values
    		are none, line, square, disc and grid.
	 * Setter for itemSeparator
	 * @param itemSeparator - new value
	 */
	 public void setItemSeparator( String  __itemSeparator ){
		this._itemSeparator = __itemSeparator;
	 	 }


	/*
	 * A separator between items on a bar. Possible values
    		are none, line, square, disc and grid.
	 * Getter for itemSeparator
	 * @return itemSeparator value from local variable or value bindings
	 */
	 public String getItemSeparator(  ){
	         if (null != this._itemSeparator)
        {
            return this._itemSeparator;
        	    }
        ValueBinding vb = getValueBinding("itemSeparator");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "none";
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.ToolBar";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[9];
        values[0] = super.saveState(context);
 	 	          values[1] = _contentClass;
	   	 	
  	 	          values[2] = _styleClass;
	   	 	
  	 	          values[3] = _width;
	   	 	
  	 	          values[4] = _height;
	   	 	
  	 	          values[5] = _contentStyle;
	   	 	
  	 	          values[6] = _style;
	   	 	
   	 	          values[7] = _separatorClass;
	   	 	
    	 	          values[8] = _itemSeparator;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _contentClass = (String)values[1] ;
	   	 	
  	 	          _styleClass = (String)values[2] ;
	   	 	
  	 	          _width = (String)values[3] ;
	   	 	
  	 	          _height = (String)values[4] ;
	   	 	
  	 	          _contentStyle = (String)values[5] ;
	   	 	
  	 	          _style = (String)values[6] ;
	   	 	
   	 	          _separatorClass = (String)values[7] ;
	   	 	
    	 	          _itemSeparator = (String)values[8] ;
	   	 	
 	
		
	}	
// Utilites

}