/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import org.richfaces.component.UIToolBarGroup ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.ToolBarGroup
 * Component-Family org.richfaces.ToolBar
  	 * Renderer-Type org.richfaces.ToolBarGroupRenderer
  	 * A group of items inside a tool bar. The group item
	    is separated basing on the "itemSeparator" attribute. Location of a group
	    on a tool bar is set up with the "location" attribute.
 */
 public class HtmlToolBarGroup extends org.richfaces.component.UIToolBarGroup {

  public static final String COMPONENT_TYPE = "org.richfaces.ToolBarGroup";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlToolBarGroup (){
  	  	setRendererType("org.richfaces.ToolBarGroupRenderer");
  	  }

// Component properties fields
 	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	   	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	   	/**
	 * separatorClass
	 * "A CSS class to be applied to menu bar group separators."
	 */
	 	 private String  _separatorClass = null; /* Default is null*/
	 	   	/**
	 * location
	 * "A location of a group on a menu bar. Possible values are "left" and "right"."
	 */
	 	 private String  _location = null; /* Default is "left"*/
	 	   	/**
	 * itemSeparator
	 * "A separator for the items in a group. Possible
	    	values are "none", "line", "square", "disc" and "grid"."
	 */
	 	 private String  _itemSeparator = null; /* Default is "none"*/
	 	 
// Getters-setters
 	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * "A CSS class to be applied to menu bar group separators."
	 * Setter for separatorClass
	 * @param separatorClass - new value
	 */
	 public void setSeparatorClass( String  __separatorClass ){
		this._separatorClass = __separatorClass;
	 	 }


	/*
	 * "A CSS class to be applied to menu bar group separators."
	 * Getter for separatorClass
	 * @return separatorClass value from local variable or value bindings
	 */
	 public String getSeparatorClass(  ){
	         if (null != this._separatorClass)
        {
            return this._separatorClass;
        	    }
        ValueBinding vb = getValueBinding("separatorClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * "A location of a group on a menu bar. Possible values are "left" and "right"."
	 * Setter for location
	 * @param location - new value
	 */
	 public void setLocation( String  __location ){
		this._location = __location;
	 	 }


	/*
	 * "A location of a group on a menu bar. Possible values are "left" and "right"."
	 * Getter for location
	 * @return location value from local variable or value bindings
	 */
	 public String getLocation(  ){
	         if (null != this._location)
        {
            return this._location;
        	    }
        ValueBinding vb = getValueBinding("location");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "left";
        }
	 	 }
	    	/*
	 * "A separator for the items in a group. Possible
	    	values are "none", "line", "square", "disc" and "grid"."
	 * Setter for itemSeparator
	 * @param itemSeparator - new value
	 */
	 public void setItemSeparator( String  __itemSeparator ){
		this._itemSeparator = __itemSeparator;
	 	 }


	/*
	 * "A separator for the items in a group. Possible
	    	values are "none", "line", "square", "disc" and "grid"."
	 * Getter for itemSeparator
	 * @return itemSeparator value from local variable or value bindings
	 */
	 public String getItemSeparator(  ){
	         if (null != this._itemSeparator)
        {
            return this._itemSeparator;
        	    }
        ValueBinding vb = getValueBinding("itemSeparator");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "none";
        }
	 	 }
	  
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.ToolBar";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[6];
        values[0] = super.saveState(context);
 	 	          values[1] = _styleClass;
	   	 	
   	 	          values[2] = _style;
	   	 	
   	 	          values[3] = _separatorClass;
	   	 	
   	 	          values[4] = _location;
	   	 	
   	 	          values[5] = _itemSeparator;
	   	 	
 	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
 	 	          _styleClass = (String)values[1] ;
	   	 	
   	 	          _style = (String)values[2] ;
	   	 	
   	 	          _separatorClass = (String)values[3] ;
	   	 	
   	 	          _location = (String)values[4] ;
	   	 	
   	 	          _itemSeparator = (String)values[5] ;
	   	 	
 	
		
	}	
// Utilites

}