/**
 * License Agreement.
 *
 * Ajax4jsf 1.1 - Natural Ajax for Java Server Faces (JSF)
 *
 * Copyright (C) 2007 Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.component.html;

import java.lang.String ;
import java.lang.Object ;
import org.richfaces.component.UITree ;
import javax.faces.el.MethodBinding ;

import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * Component-Type org.richfaces.Tree
 * Component-Family org.richfaces.Tree
  	 * Renderer-Type org.richfaces.TreeRenderer
  	 * 
 */
 public class HtmlTree extends org.richfaces.component.UITree {

  public static final String COMPONENT_TYPE = "org.richfaces.Tree";

  /**
   *  Constructor to init default renderers 
   */ 
  public HtmlTree (){
  	  	setRendererType("org.richfaces.TreeRenderer");
  	  }

// Component properties fields
  	/**
	 * ajaxSubmitSelection
	 * If true, an Ajax request to be submit when selecting node
	 */
	 	 private boolean  _ajaxSubmitSelection = false;		
	/**
	 * Flag indicated what ajaxSubmitSelection is set.
	 */
	 private boolean _ajaxSubmitSelectionSet = false;	
	 	    	/**
	 * onexpand
	 * An action to be fired when expanding a node
	 */
	 	 private String  _onexpand = null; /* Default is null*/
	 	  	/**
	 * switchType
	 * Tree switch algorithm: "client", "server", "ajax"
	 */
	 	 private String  _switchType = null; /* Default is "ajax"*/
	 	    	/**
	 * preserveDataInRequest
	 * If true, data is preserved in a request
	 */
	 	 private boolean  _preserveDataInRequest = true;		
	/**
	 * Flag indicated what preserveDataInRequest is set.
	 */
	 private boolean _preserveDataInRequestSet = false;	
	 	  	/**
	 * ondropend
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 */
	 	 private String  _ondropend = null; /* Default is null*/
	 	   	/**
	 * style
	 * CSS style(s) is/are to be applied when this component is rendered
	 */
	 	 private String  _style = null; /* Default is null*/
	 	  	/**
	 * oncollapse
	 * An action to be fired when collapsing a node
	 */
	 	 private String  _oncollapse = null; /* Default is null*/
	 	   	/**
	 * showConnectingLines
	 * If true, connecting lines are show
	 */
	 	 private boolean  _showConnectingLines = true;		
	/**
	 * Flag indicated what showConnectingLines is set.
	 */
	 private boolean _showConnectingLinesSet = false;	
	 	   	/**
	 * dragListener
	 * dragListener
	 */
	 	 private MethodBinding  _dragListener = null; /* Default is null*/
	 	   	/**
	 * nodeSelectListener
	 * nodeSelectListener
	 */
	 	 private MethodBinding  _nodeSelectListener = null; /* Default is null*/
	 	   	/**
	 * dropListener
	 * dropListener
	 */
	 	 private MethodBinding  _dropListener = null; /* Default is null*/
	 	    	/**
	 * iconLeaf
	 * iconLeaf
	 */
	 	 private String  _iconLeaf = null; /* Default is null*/
	 	  	/**
	 * ondragexit
	 * A JavaScript event handler called after a drag object leaves zone.
	 */
	 	 private String  _ondragexit = null; /* Default is null*/
	 	   	/**
	 * ondragstart
	 * A JavaScript event handler called before drag object.
	 */
	 	 private String  _ondragstart = null; /* Default is null*/
	 	   	/**
	 * nodeFace
	 * Node face facet name
	 */
	 	 private String  _nodeFace = null; /* Default is null*/
	 	  	/**
	 * ondragend
	 * A JavaScript event handler called after a drag operation.
	 */
	 	 private String  _ondragend = null; /* Default is null*/
	 	  	/**
	 * ondragenter
	 * A JavaScript event handler called on enter draggable object to zone.
	 */
	 	 private String  _ondragenter = null; /* Default is null*/
	 	   	/**
	 * iconExpanded
	 * The icon for expanded node
	 */
	 	 private String  _iconExpanded = null; /* Default is null*/
	 	     	/**
	 * reRender
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 */
	 	 private Object  _reRender = null; /* Default is null*/
	 	  	/**
	 * styleClass
	 * Corresponds to the HTML class attribute
	 */
	 	 private String  _styleClass = null; /* Default is null*/
	 	  	/**
	 * iconCollapsed
	 * The icon for collapsed node
	 */
	 	 private String  _iconCollapsed = null; /* Default is null*/
	 	    	/**
	 * selectedClass
	 * Corresponds to the HTML class attribute. Applied to selected node
	 */
	 	 private String  _selectedClass = null; /* Default is null*/
	 	  	/**
	 * icon
	 * The icon for node
	 */
	 	 private String  _icon = null; /* Default is null*/
	 	  	/**
	 * dragIndicator
	 * dragIndicator
	 */
	 	 private String  _dragIndicator = null; /* Default is null*/
	 	  	/**
	 * ondrop
	 * It's an event that is called when something is dropped on a drop zone
	 */
	 	 private String  _ondrop = null; /* Default is null*/
	 	  	/**
	 * changeExpandListener
	 * changeExpandListener
	 */
	 	 private MethodBinding  _changeExpandListener = null; /* Default is null*/
	 	   	/**
	 * preserveModel
	 * It can be "state", "request", "none". The default is "request"
	 */
	 	 private String  _preserveModel = null; /* Default is "request"*/
	 	    	/**
	 * acceptedTypes
	 * List of drag types to be processd by the current drop zone.
	 */
	 	 private Object  _acceptedTypes = null; /* Default is null*/
	 	  	/**
	 * highlightedClass
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 */
	 	 private String  _highlightedClass = null; /* Default is null*/
	 	  	/**
	 * dragType
	 * Key of a drag object. It's used to define a necessity of processing the current dragged element on the drop zone side
	 */
	 	 private String  _dragType = null; /* Default is null*/
	 	   	/**
	 * onselected
	 * An action to be fired when selecting a node
	 */
	 	 private String  _onselected = null; /* Default is null*/
	 	  	/**
	 * immediate
	 * A flag indicating that this component value must be
				converted and validated immediately (during an
				Apply Request Values phase), rather than waiting until a
				Process Validations phase
	 */
	 	 private boolean  _immediate = false;		
	/**
	 * Flag indicated what immediate is set.
	 */
	 private boolean _immediateSet = false;	
	 	    	/**
	 * typeMapping
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 */
	 	 private Object  _typeMapping = null; /* Default is null*/
	 	  
// Getters-setters
  	/*
	 * If true, an Ajax request to be submit when selecting node
	 * Setter for ajaxSubmitSelection
	 * @param ajaxSubmitSelection - new value
	 */
	 public void setAjaxSubmitSelection( boolean  __ajaxSubmitSelection ){
		this._ajaxSubmitSelection = __ajaxSubmitSelection;
	 		this._ajaxSubmitSelectionSet = true;
	 	 }


	/*
	 * If true, an Ajax request to be submit when selecting node
	 * Getter for ajaxSubmitSelection
	 * @return ajaxSubmitSelection value from local variable or value bindings
	 */
	 public boolean isAjaxSubmitSelection(  ){
	 		 if(this._ajaxSubmitSelectionSet){
			return this._ajaxSubmitSelection;
		 }
    	ValueBinding vb = getValueBinding("ajaxSubmitSelection");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._ajaxSubmitSelection;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._ajaxSubmitSelection);
    	}
	 	 }
	     	/*
	 * An action to be fired when expanding a node
	 * Setter for onexpand
	 * @param onexpand - new value
	 */
	 public void setOnexpand( String  __onexpand ){
		this._onexpand = __onexpand;
	 	 }


	/*
	 * An action to be fired when expanding a node
	 * Getter for onexpand
	 * @return onexpand value from local variable or value bindings
	 */
	 public String getOnexpand(  ){
	         if (null != this._onexpand)
        {
            return this._onexpand;
        	    }
        ValueBinding vb = getValueBinding("onexpand");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Tree switch algorithm: "client", "server", "ajax"
	 * Setter for switchType
	 * @param switchType - new value
	 */
	 public void setSwitchType( String  __switchType ){
		this._switchType = __switchType;
	 	 }


	/*
	 * Tree switch algorithm: "client", "server", "ajax"
	 * Getter for switchType
	 * @return switchType value from local variable or value bindings
	 */
	 public String getSwitchType(  ){
	         if (null != this._switchType)
        {
            return this._switchType;
        	    }
        ValueBinding vb = getValueBinding("switchType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "ajax";
        }
	 	 }
	     	/*
	 * If true, data is preserved in a request
	 * Setter for preserveDataInRequest
	 * @param preserveDataInRequest - new value
	 */
	 public void setPreserveDataInRequest( boolean  __preserveDataInRequest ){
		this._preserveDataInRequest = __preserveDataInRequest;
	 		this._preserveDataInRequestSet = true;
	 	 }


	/*
	 * If true, data is preserved in a request
	 * Getter for preserveDataInRequest
	 * @return preserveDataInRequest value from local variable or value bindings
	 */
	 public boolean isPreserveDataInRequest(  ){
	 		 if(this._preserveDataInRequestSet){
			return this._preserveDataInRequest;
		 }
    	ValueBinding vb = getValueBinding("preserveDataInRequest");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._preserveDataInRequest;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._preserveDataInRequest);
    	}
	 	 }
	   	/*
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 * Setter for ondropend
	 * @param ondropend - new value
	 */
	 public void setOndropend( String  __ondropend ){
		this._ondropend = __ondropend;
	 	 }


	/*
	 * A Javascript handler for event fired on a drop even the drop for a given type is not available
	 * Getter for ondropend
	 * @return ondropend value from local variable or value bindings
	 */
	 public String getOndropend(  ){
	         if (null != this._ondropend)
        {
            return this._ondropend;
        	    }
        ValueBinding vb = getValueBinding("ondropend");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Setter for style
	 * @param style - new value
	 */
	 public void setStyle( String  __style ){
		this._style = __style;
	 	 }


	/*
	 * CSS style(s) is/are to be applied when this component is rendered
	 * Getter for style
	 * @return style value from local variable or value bindings
	 */
	 public String getStyle(  ){
	         if (null != this._style)
        {
            return this._style;
        	    }
        ValueBinding vb = getValueBinding("style");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * An action to be fired when collapsing a node
	 * Setter for oncollapse
	 * @param oncollapse - new value
	 */
	 public void setOncollapse( String  __oncollapse ){
		this._oncollapse = __oncollapse;
	 	 }


	/*
	 * An action to be fired when collapsing a node
	 * Getter for oncollapse
	 * @return oncollapse value from local variable or value bindings
	 */
	 public String getOncollapse(  ){
	         if (null != this._oncollapse)
        {
            return this._oncollapse;
        	    }
        ValueBinding vb = getValueBinding("oncollapse");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * If true, connecting lines are show
	 * Setter for showConnectingLines
	 * @param showConnectingLines - new value
	 */
	 public void setShowConnectingLines( boolean  __showConnectingLines ){
		this._showConnectingLines = __showConnectingLines;
	 		this._showConnectingLinesSet = true;
	 	 }


	/*
	 * If true, connecting lines are show
	 * Getter for showConnectingLines
	 * @return showConnectingLines value from local variable or value bindings
	 */
	 public boolean isShowConnectingLines(  ){
	 		 if(this._showConnectingLinesSet){
			return this._showConnectingLines;
		 }
    	ValueBinding vb = getValueBinding("showConnectingLines");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._showConnectingLines;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._showConnectingLines);
    	}
	 	 }
	    	/*
	 * dragListener
	 * Setter for dragListener
	 * @param dragListener - new value
	 */
	 public void setDragListener( MethodBinding  __dragListener ){
		this._dragListener = __dragListener;
	 	 }


	/*
	 * dragListener
	 * Getter for dragListener
	 * @return dragListener value from local variable or value bindings
	 */
	 public MethodBinding getDragListener(  ){
	         if (null != this._dragListener)
        {
            return this._dragListener;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * nodeSelectListener
	 * Setter for nodeSelectListener
	 * @param nodeSelectListener - new value
	 */
	 public void setNodeSelectListener( MethodBinding  __nodeSelectListener ){
		this._nodeSelectListener = __nodeSelectListener;
	 	 }


	/*
	 * nodeSelectListener
	 * Getter for nodeSelectListener
	 * @return nodeSelectListener value from local variable or value bindings
	 */
	 public MethodBinding getNodeSelectListener(  ){
	         if (null != this._nodeSelectListener)
        {
            return this._nodeSelectListener;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * dropListener
	 * Setter for dropListener
	 * @param dropListener - new value
	 */
	 public void setDropListener( MethodBinding  __dropListener ){
		this._dropListener = __dropListener;
	 	 }


	/*
	 * dropListener
	 * Getter for dropListener
	 * @return dropListener value from local variable or value bindings
	 */
	 public MethodBinding getDropListener(  ){
	         if (null != this._dropListener)
        {
            return this._dropListener;
                } else {
            return null;
        }
	 	 }
	     	/*
	 * iconLeaf
	 * Setter for iconLeaf
	 * @param iconLeaf - new value
	 */
	 public void setIconLeaf( String  __iconLeaf ){
		this._iconLeaf = __iconLeaf;
	 	 }


	/*
	 * iconLeaf
	 * Getter for iconLeaf
	 * @return iconLeaf value from local variable or value bindings
	 */
	 public String getIconLeaf(  ){
	         if (null != this._iconLeaf)
        {
            return this._iconLeaf;
        	    }
        ValueBinding vb = getValueBinding("iconLeaf");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A JavaScript event handler called after a drag object leaves zone.
	 * Setter for ondragexit
	 * @param ondragexit - new value
	 */
	 public void setOndragexit( String  __ondragexit ){
		this._ondragexit = __ondragexit;
	 	 }


	/*
	 * A JavaScript event handler called after a drag object leaves zone.
	 * Getter for ondragexit
	 * @return ondragexit value from local variable or value bindings
	 */
	 public String getOndragexit(  ){
	         if (null != this._ondragexit)
        {
            return this._ondragexit;
        	    }
        ValueBinding vb = getValueBinding("ondragexit");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * A JavaScript event handler called before drag object.
	 * Setter for ondragstart
	 * @param ondragstart - new value
	 */
	 public void setOndragstart( String  __ondragstart ){
		this._ondragstart = __ondragstart;
	 	 }


	/*
	 * A JavaScript event handler called before drag object.
	 * Getter for ondragstart
	 * @return ondragstart value from local variable or value bindings
	 */
	 public String getOndragstart(  ){
	         if (null != this._ondragstart)
        {
            return this._ondragstart;
        	    }
        ValueBinding vb = getValueBinding("ondragstart");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * Node face facet name
	 * Setter for nodeFace
	 * @param nodeFace - new value
	 */
	 public void setNodeFace( String  __nodeFace ){
		this._nodeFace = __nodeFace;
	 	 }


	/*
	 * Node face facet name
	 * Getter for nodeFace
	 * @return nodeFace value from local variable or value bindings
	 */
	 public String getNodeFace(  ){
	         if (null != this._nodeFace)
        {
            return this._nodeFace;
        	    }
        ValueBinding vb = getValueBinding("nodeFace");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A JavaScript event handler called after a drag operation.
	 * Setter for ondragend
	 * @param ondragend - new value
	 */
	 public void setOndragend( String  __ondragend ){
		this._ondragend = __ondragend;
	 	 }


	/*
	 * A JavaScript event handler called after a drag operation.
	 * Getter for ondragend
	 * @return ondragend value from local variable or value bindings
	 */
	 public String getOndragend(  ){
	         if (null != this._ondragend)
        {
            return this._ondragend;
        	    }
        ValueBinding vb = getValueBinding("ondragend");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A JavaScript event handler called on enter draggable object to zone.
	 * Setter for ondragenter
	 * @param ondragenter - new value
	 */
	 public void setOndragenter( String  __ondragenter ){
		this._ondragenter = __ondragenter;
	 	 }


	/*
	 * A JavaScript event handler called on enter draggable object to zone.
	 * Getter for ondragenter
	 * @return ondragenter value from local variable or value bindings
	 */
	 public String getOndragenter(  ){
	         if (null != this._ondragenter)
        {
            return this._ondragenter;
        	    }
        ValueBinding vb = getValueBinding("ondragenter");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * The icon for expanded node
	 * Setter for iconExpanded
	 * @param iconExpanded - new value
	 */
	 public void setIconExpanded( String  __iconExpanded ){
		this._iconExpanded = __iconExpanded;
	 	 }


	/*
	 * The icon for expanded node
	 * Getter for iconExpanded
	 * @return iconExpanded value from local variable or value bindings
	 */
	 public String getIconExpanded(  ){
	         if (null != this._iconExpanded)
        {
            return this._iconExpanded;
        	    }
        ValueBinding vb = getValueBinding("iconExpanded");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	      	/*
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 * Setter for reRender
	 * @param reRender - new value
	 */
	 public void setReRender( Object  __reRender ){
		this._reRender = __reRender;
	 	 }


	/*
	 * Id[s] (in format of call  UIComopnent.findComponent()) of components, rendered in case of AjaxRequest  caused by this component. Can be single id, comma-separated list of Ids, or EL Expression  with array or Collection
	 * Getter for reRender
	 * @return reRender value from local variable or value bindings
	 */
	 public Object getReRender(  ){
	         if (null != this._reRender)
        {
            return this._reRender;
        	    }
        ValueBinding vb = getValueBinding("reRender");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute
	 * Setter for styleClass
	 * @param styleClass - new value
	 */
	 public void setStyleClass( String  __styleClass ){
		this._styleClass = __styleClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute
	 * Getter for styleClass
	 * @return styleClass value from local variable or value bindings
	 */
	 public String getStyleClass(  ){
	         if (null != this._styleClass)
        {
            return this._styleClass;
        	    }
        ValueBinding vb = getValueBinding("styleClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The icon for collapsed node
	 * Setter for iconCollapsed
	 * @param iconCollapsed - new value
	 */
	 public void setIconCollapsed( String  __iconCollapsed ){
		this._iconCollapsed = __iconCollapsed;
	 	 }


	/*
	 * The icon for collapsed node
	 * Getter for iconCollapsed
	 * @return iconCollapsed value from local variable or value bindings
	 */
	 public String getIconCollapsed(  ){
	         if (null != this._iconCollapsed)
        {
            return this._iconCollapsed;
        	    }
        ValueBinding vb = getValueBinding("iconCollapsed");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	     	/*
	 * Corresponds to the HTML class attribute. Applied to selected node
	 * Setter for selectedClass
	 * @param selectedClass - new value
	 */
	 public void setSelectedClass( String  __selectedClass ){
		this._selectedClass = __selectedClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute. Applied to selected node
	 * Getter for selectedClass
	 * @return selectedClass value from local variable or value bindings
	 */
	 public String getSelectedClass(  ){
	         if (null != this._selectedClass)
        {
            return this._selectedClass;
        	    }
        ValueBinding vb = getValueBinding("selectedClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * The icon for node
	 * Setter for icon
	 * @param icon - new value
	 */
	 public void setIcon( String  __icon ){
		this._icon = __icon;
	 	 }


	/*
	 * The icon for node
	 * Getter for icon
	 * @return icon value from local variable or value bindings
	 */
	 public String getIcon(  ){
	         if (null != this._icon)
        {
            return this._icon;
        	    }
        ValueBinding vb = getValueBinding("icon");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * dragIndicator
	 * Setter for dragIndicator
	 * @param dragIndicator - new value
	 */
	 public void setDragIndicator( String  __dragIndicator ){
		this._dragIndicator = __dragIndicator;
	 	 }


	/*
	 * dragIndicator
	 * Getter for dragIndicator
	 * @return dragIndicator value from local variable or value bindings
	 */
	 public String getDragIndicator(  ){
	         if (null != this._dragIndicator)
        {
            return this._dragIndicator;
        	    }
        ValueBinding vb = getValueBinding("dragIndicator");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * It's an event that is called when something is dropped on a drop zone
	 * Setter for ondrop
	 * @param ondrop - new value
	 */
	 public void setOndrop( String  __ondrop ){
		this._ondrop = __ondrop;
	 	 }


	/*
	 * It's an event that is called when something is dropped on a drop zone
	 * Getter for ondrop
	 * @return ondrop value from local variable or value bindings
	 */
	 public String getOndrop(  ){
	         if (null != this._ondrop)
        {
            return this._ondrop;
        	    }
        ValueBinding vb = getValueBinding("ondrop");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * changeExpandListener
	 * Setter for changeExpandListener
	 * @param changeExpandListener - new value
	 */
	 public void setChangeExpandListener( MethodBinding  __changeExpandListener ){
		this._changeExpandListener = __changeExpandListener;
	 	 }


	/*
	 * changeExpandListener
	 * Getter for changeExpandListener
	 * @return changeExpandListener value from local variable or value bindings
	 */
	 public MethodBinding getChangeExpandListener(  ){
	         if (null != this._changeExpandListener)
        {
            return this._changeExpandListener;
                } else {
            return null;
        }
	 	 }
	    	/*
	 * It can be "state", "request", "none". The default is "request"
	 * Setter for preserveModel
	 * @param preserveModel - new value
	 */
	 public void setPreserveModel( String  __preserveModel ){
		this._preserveModel = __preserveModel;
	 	 }


	/*
	 * It can be "state", "request", "none". The default is "request"
	 * Getter for preserveModel
	 * @return preserveModel value from local variable or value bindings
	 */
	 public String getPreserveModel(  ){
	         if (null != this._preserveModel)
        {
            return this._preserveModel;
        	    }
        ValueBinding vb = getValueBinding("preserveModel");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return "request";
        }
	 	 }
	     	/*
	 * List of drag types to be processd by the current drop zone.
	 * Setter for acceptedTypes
	 * @param acceptedTypes - new value
	 */
	 public void setAcceptedTypes( Object  __acceptedTypes ){
		this._acceptedTypes = __acceptedTypes;
	 	 }


	/*
	 * List of drag types to be processd by the current drop zone.
	 * Getter for acceptedTypes
	 * @return acceptedTypes value from local variable or value bindings
	 */
	 public Object getAcceptedTypes(  ){
	         if (null != this._acceptedTypes)
        {
            return this._acceptedTypes;
        	    }
        ValueBinding vb = getValueBinding("acceptedTypes");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 * Setter for highlightedClass
	 * @param highlightedClass - new value
	 */
	 public void setHighlightedClass( String  __highlightedClass ){
		this._highlightedClass = __highlightedClass;
	 	 }


	/*
	 * Corresponds to the HTML class attribute. Applied to highlighted node
	 * Getter for highlightedClass
	 * @return highlightedClass value from local variable or value bindings
	 */
	 public String getHighlightedClass(  ){
	         if (null != this._highlightedClass)
        {
            return this._highlightedClass;
        	    }
        ValueBinding vb = getValueBinding("highlightedClass");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * Key of a drag object. It's used to define a necessity of processing the current dragged element on the drop zone side
	 * Setter for dragType
	 * @param dragType - new value
	 */
	 public void setDragType( String  __dragType ){
		this._dragType = __dragType;
	 	 }


	/*
	 * Key of a drag object. It's used to define a necessity of processing the current dragged element on the drop zone side
	 * Getter for dragType
	 * @return dragType value from local variable or value bindings
	 */
	 public String getDragType(  ){
	         if (null != this._dragType)
        {
            return this._dragType;
        	    }
        ValueBinding vb = getValueBinding("dragType");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	    	/*
	 * An action to be fired when selecting a node
	 * Setter for onselected
	 * @param onselected - new value
	 */
	 public void setOnselected( String  __onselected ){
		this._onselected = __onselected;
	 	 }


	/*
	 * An action to be fired when selecting a node
	 * Getter for onselected
	 * @return onselected value from local variable or value bindings
	 */
	 public String getOnselected(  ){
	         if (null != this._onselected)
        {
            return this._onselected;
        	    }
        ValueBinding vb = getValueBinding("onselected");
        if (null != vb){
            return (String)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   	/*
	 * A flag indicating that this component value must be
				converted and validated immediately (during an
				Apply Request Values phase), rather than waiting until a
				Process Validations phase
	 * Setter for immediate
	 * @param immediate - new value
	 */
	 public void setImmediate( boolean  __immediate ){
		this._immediate = __immediate;
	 		this._immediateSet = true;
	 	 }


	/*
	 * A flag indicating that this component value must be
				converted and validated immediately (during an
				Apply Request Values phase), rather than waiting until a
				Process Validations phase
	 * Getter for immediate
	 * @return immediate value from local variable or value bindings
	 */
	 public boolean isImmediate(  ){
	 		 if(this._immediateSet){
			return this._immediate;
		 }
    	ValueBinding vb = getValueBinding("immediate");
    	if (vb != null) {
    	    Boolean value = (Boolean) vb.getValue(getFacesContext());
    	    if (null == value) {
    			return this._immediate;
    	    }
    	    return (value.booleanValue());
    	} else {
    	    return (this._immediate);
    	}
	 	 }
	     	/*
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 * Setter for typeMapping
	 * @param typeMapping - new value
	 */
	 public void setTypeMapping( Object  __typeMapping ){
		this._typeMapping = __typeMapping;
	 	 }


	/*
	 * Map between a draggable type and an indicator name on zone. it's defined with the pair (drag type:indicator name))
	 * Getter for typeMapping
	 * @return typeMapping value from local variable or value bindings
	 */
	 public Object getTypeMapping(  ){
	         if (null != this._typeMapping)
        {
            return this._typeMapping;
        	    }
        ValueBinding vb = getValueBinding("typeMapping");
        if (null != vb){
            return (Object)vb.getValue(getFacesContext());
		        } else {
            return null;
        }
	 	 }
	   
// Component family.
	public static final String COMPONENT_FAMILY = "org.richfaces.Tree";

	public String getFamily() {
		return COMPONENT_FAMILY;
	}

	
// Save state
// ----------------------------------------------------- StateHolder Methods


    public Object saveState(FacesContext context) {
        Object values[] = new Object[38];
        values[0] = super.saveState(context);
  	        values[1] = new Boolean(_ajaxSubmitSelection);
	   	   values[2] = Boolean.valueOf(_ajaxSubmitSelectionSet);	
	   	 	
    	 	          values[3] = _onexpand;
	   	 	
  	 	          values[4] = _switchType;
	   	 	
    	        values[5] = new Boolean(_preserveDataInRequest);
	   	   values[6] = Boolean.valueOf(_preserveDataInRequestSet);	
	   	 	
  	 	          values[7] = _ondropend;
	   	 	
   	 	          values[8] = _style;
	   	 	
  	 	          values[9] = _oncollapse;
	   	 	
   	        values[10] = new Boolean(_showConnectingLines);
	   	   values[11] = Boolean.valueOf(_showConnectingLinesSet);	
	   	 	
   	 	          values[12] = saveAttachedState(context, _dragListener );		
	   	 	
   	 	          values[13] = saveAttachedState(context, _nodeSelectListener );		
	   	 	
   	 	          values[14] = saveAttachedState(context, _dropListener );		
	   	 	
    	 	          values[15] = _iconLeaf;
	   	 	
  	 	          values[16] = _ondragexit;
	   	 	
   	 	          values[17] = _ondragstart;
	   	 	
   	 	          values[18] = _nodeFace;
	   	 	
  	 	          values[19] = _ondragend;
	   	 	
  	 	          values[20] = _ondragenter;
	   	 	
   	 	          values[21] = _iconExpanded;
	   	 	
     	 	          values[22] = _reRender;
	   	 	
  	 	          values[23] = _styleClass;
	   	 	
  	 	          values[24] = _iconCollapsed;
	   	 	
    	 	          values[25] = _selectedClass;
	   	 	
  	 	          values[26] = _icon;
	   	 	
  	 	          values[27] = _dragIndicator;
	   	 	
  	 	          values[28] = _ondrop;
	   	 	
  	 	          values[29] = saveAttachedState(context, _changeExpandListener );		
	   	 	
   	 	          values[30] = _preserveModel;
	   	 	
    	 	          values[31] = _acceptedTypes;
	   	 	
  	 	          values[32] = _highlightedClass;
	   	 	
  	 	          values[33] = _dragType;
	   	 	
   	 	          values[34] = _onselected;
	   	 	
  	        values[35] = new Boolean(_immediate);
	   	   values[36] = Boolean.valueOf(_immediateSet);	
	   	 	
    	 	          values[37] = _typeMapping;
	   	 	
  	  return values;
   }
   

    public void restoreState(FacesContext context, Object state) {
        Object values[] = (Object[]) state;
        super.restoreState(context, values[0]);
  	        _ajaxSubmitSelection = ((Boolean)values[1]).booleanValue();
	   	   _ajaxSubmitSelectionSet = ((Boolean)values[2]).booleanValue();	
	   	 	
    	 	          _onexpand = (String)values[3] ;
	   	 	
  	 	          _switchType = (String)values[4] ;
	   	 	
    	        _preserveDataInRequest = ((Boolean)values[5]).booleanValue();
	   	   _preserveDataInRequestSet = ((Boolean)values[6]).booleanValue();	
	   	 	
  	 	          _ondropend = (String)values[7] ;
	   	 	
   	 	          _style = (String)values[8] ;
	   	 	
  	 	          _oncollapse = (String)values[9] ;
	   	 	
   	        _showConnectingLines = ((Boolean)values[10]).booleanValue();
	   	   _showConnectingLinesSet = ((Boolean)values[11]).booleanValue();	
	   	 	
   	 	          _dragListener = (MethodBinding)restoreAttachedState(context,values[12] );		
	   	 	
   	 	          _nodeSelectListener = (MethodBinding)restoreAttachedState(context,values[13] );		
	   	 	
   	 	          _dropListener = (MethodBinding)restoreAttachedState(context,values[14] );		
	   	 	
    	 	          _iconLeaf = (String)values[15] ;
	   	 	
  	 	          _ondragexit = (String)values[16] ;
	   	 	
   	 	          _ondragstart = (String)values[17] ;
	   	 	
   	 	          _nodeFace = (String)values[18] ;
	   	 	
  	 	          _ondragend = (String)values[19] ;
	   	 	
  	 	          _ondragenter = (String)values[20] ;
	   	 	
   	 	          _iconExpanded = (String)values[21] ;
	   	 	
     	 	          _reRender = (Object)values[22] ;
	   	 	
  	 	          _styleClass = (String)values[23] ;
	   	 	
  	 	          _iconCollapsed = (String)values[24] ;
	   	 	
    	 	          _selectedClass = (String)values[25] ;
	   	 	
  	 	          _icon = (String)values[26] ;
	   	 	
  	 	          _dragIndicator = (String)values[27] ;
	   	 	
  	 	          _ondrop = (String)values[28] ;
	   	 	
  	 	          _changeExpandListener = (MethodBinding)restoreAttachedState(context,values[29] );		
	   	 	
   	 	          _preserveModel = (String)values[30] ;
	   	 	
    	 	          _acceptedTypes = (Object)values[31] ;
	   	 	
  	 	          _highlightedClass = (String)values[32] ;
	   	 	
  	 	          _dragType = (String)values[33] ;
	   	 	
   	 	          _onselected = (String)values[34] ;
	   	 	
  	        _immediate = ((Boolean)values[35]).booleanValue();
	   	   _immediateSet = ((Boolean)values[36]).booleanValue();	
	   	 	
    	 	          _typeMapping = (Object)values[37] ;
	   	 	
  	
		
	}	
// Utilites

}