/**
 * 
 */
package org.richfaces.renderkit;

import java.io.IOException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

import javax.faces.component.NamingContainer;
import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;

import org.ajax4jsf.dnd.Draggable;
import org.ajax4jsf.dnd.Dropzone;
import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.ajax4jsf.framework.renderer.ComponentVariables;
import org.ajax4jsf.framework.renderer.ComponentsVariableResolver;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.ajax4jsf.framework.util.javascript.ScriptUtils;
import org.richfaces.component.TreeRowKey;
import org.richfaces.component.UITree;
import org.richfaces.component.UITreeNode;
import org.richfaces.component.events.AjaxSelectedEvent;
import org.richfaces.component.events.NodeExpandedEvent;
import org.richfaces.component.events.NodeSelectedEvent;
import org.richfaces.component.state.TreeState;
import org.richfaces.component.state.events.CollapseNodeCommandEvent;
import org.richfaces.component.state.events.ExpandNodeCommandEvent;
import org.richfaces.component.util.ViewUtil;

/**
 * @author Nick - mailto:nbelaevski@exadel.com created 23.11.2006
 * 
 */
public abstract class NodeRendererBase extends CompositeRenderer {

	private static class TreeNodeOptions extends ScriptOptions {

		public TreeNodeOptions(UIComponent component) {
			super(component);

			Map params = new HashMap();

			if (((Boolean) (component.getAttributes().get("isLastElement")))
					.booleanValue()) {

				UITree tree = ((UITreeNode) component).getUITree();

				params.put(tree.getBaseClientId(FacesContext
						.getCurrentInstance())
						+ UITree.LAST_ELEMENT_FLAG, Boolean.TRUE);
			}

			addOption("parameters", params);
		}

	}

	public NodeRendererBase() {
		super();

		addContributor(DropzoneRendererContributor.getInstance());
		addContributor(DraggableRendererContributor.getInstance());
	}

	protected String getToggleScript(FacesContext context, UITreeNode treeNode) {
		UITree tree = treeNode.getUITree();
		String id = tree.getClientId(context);
		String toggleId = id + NamingContainer.SEPARATOR_CHAR
				+ UITree.TOGGLE_LINK_ATTRIBUTE;

		if (UITree.SWITCH_AJAX.equals(tree.getSwitchType())) {
			JSFunction function = AjaxRendererUtils.buildAjaxFunction(tree,
					context);
			Map eventOptions = AjaxRendererUtils.buildEventOptions(context,
					tree);
			Map parameters = (Map) eventOptions.get("parameters");
			parameters.remove(id);
			parameters.put(toggleId, toggleId);

			parameters.put(tree.getBaseClientId(context)
					+ UITree.EXPANDED_STATE_PARAMETER_NAME, String.valueOf(tree
					.isExpanded()));

			if (((Boolean) (treeNode.getAttributes().get("isLastElement")))
					.booleanValue()) {
				parameters.put(tree.getBaseClientId(context)
						+ UITree.LAST_ELEMENT_FLAG, Boolean.TRUE);
			}
			function.addParameter(eventOptions);

			StringBuffer buffer = new StringBuffer();
			function.appendScript(buffer);
			buffer.append(";");
			return buffer.toString();
		} else if (UITree.SWITCH_SERVER.equals(tree.getSwitchType())) {
			StringBuffer result = new StringBuffer();
			result.append('{');
			result.append("var params = new Object();");
			result.append("params['");
			result.append(tree.getBaseClientId(context)
					+ UITree.EXPANDED_STATE_PARAMETER_NAME);

			result.append("'] = ");
			result.append(tree.isExpanded());
			result.append(';');
			result.append("_JSFFormSubmit('");
			result.append(toggleId);
			result.append("', ");
			result.append("A4J.findForm(this).id, ");
			result.append("'', ");
			result.append("params);};");

			return result.toString();
		}

		return "";
	}

	public void initializeLines(FacesContext context, UITreeNode treeNode)
			throws IOException {
		ComponentVariables variables = ComponentsVariableResolver.getVariables(
				this, treeNode);

		UITree tree = treeNode.getUITree();

		if (tree.isShowConnectingLines()) {
			if (((Boolean) (treeNode.getAttributes().get("isLastElement")))
					.booleanValue()) {
				variables.setVariable("line", "dr-tree-h-ic-line-last");
			} else {
				variables.setVariable("line", "dr-tree-h-ic-line-node");
			}
			if (tree.isExpanded()) {
				variables
						.setVariable("lineFirst", "dr-tree-h-ic-line-exp");
			} else {
				variables.setVariable("lineFirst",
						"dr-tree-h-ic-line-clp");
			}
		}
	}

	public void initializeResources(FacesContext context, UITreeNode treeNode)
			throws IOException {
		ComponentVariables variables = ComponentsVariableResolver.getVariables(
				this, treeNode);

		UITree tree = treeNode.getUITree();
		String resource;
		String cssClass;
		resource = UITree.DEFAULT_HIGHLIGHTED_CSS_CLASS;
		resource += " rich-tree-node-highlighted";
		cssClass = tree.getHighlightedClass();
		if (cssClass != null) {
			resource += " " + cssClass;
		}
		cssClass = treeNode.getHighlightedClass();
		if (cssClass != null) {
			resource += " " + cssClass;
		}
		variables.setVariable("highlightedClass", resource);

		resource = UITree.DEFAULT_SELECTED_CSS_CLASS;
		resource += " rich-tree-node-selected";
		cssClass = tree.getSelectedClass();
		if (cssClass != null) {
			resource += " " + cssClass;
		}
		cssClass = treeNode.getSelectedClass();
		if (cssClass != null) {
			resource += " " + cssClass;
		}
		variables.setVariable("selectedClass", resource);
		
		
		resource = ViewUtil.getResourceURL(treeNode.getIcon());			
		if (resource == null) {
			resource = ViewUtil.getResourceURL(tree.getIcon());			
		}

		if (resource != null) {
			variables.setVariable("folder", resource);
		}

		resource = ViewUtil.getResourceURL(treeNode.getIconCollapsed());
		if (resource == null) {
			resource = ViewUtil.getResourceURL(tree.getIconCollapsed());
		}

		if (resource != null) {
			variables.setVariable("collapsed", resource);
		}

		resource = ViewUtil.getResourceURL(treeNode.getIconExpanded());
		if (resource == null) {
			resource = ViewUtil.getResourceURL(tree.getIconExpanded());
		}

		if (resource != null) {
			variables.setVariable("expanded", resource);
		}
		
		resource = ViewUtil.getResourceURL(treeNode.getIconLeaf());
		if (resource == null) {
			resource = ViewUtil.getResourceURL(tree.getIconLeaf());
		}
		
		if (resource != null) {
			variables.setVariable("leaf", resource);
		}
	}

	protected void doDecode(FacesContext context, UIComponent component) {
		super.doDecode(context, component);

		UITreeNode node = (UITreeNode) component;
		UITree tree = node.getUITree();

		Map requestMap = context.getExternalContext().getRequestParameterMap();
		String id = tree.getClientId(context);
		TreeState componentState = (TreeState) tree.getComponentState();
		TreeRowKey key = (TreeRowKey) tree.getRowKey();

		String toggleId = id + NamingContainer.SEPARATOR_CHAR
				+ UITree.TOGGLE_LINK_ATTRIBUTE;
		if (requestMap.containsKey(toggleId)
				|| toggleId.equals(tree.getAttributes().get(
						UITree.TOGGLE_LINK_ATTRIBUTE))) {

			if (((Boolean) tree.getAttributes().get(
					UITree.EXPANDED_STATE_PARAMETER_NAME)).booleanValue()) {

				new CollapseNodeCommandEvent(tree, key).queue();
			} else {
				new ExpandNodeCommandEvent(tree, key).queue();
			}

			new NodeExpandedEvent(node).queue();
			new NodeExpandedEvent(tree).queue();

			if (AjaxRendererUtils.isAjaxRequest(context)) {
				Set ajaxKeys = tree.getAjaxKeys();
				if (ajaxKeys == null) {
					ajaxKeys = new HashSet();

					tree.setAjaxKeys(ajaxKeys);
				}

				ajaxKeys.add(key);
			}
		}

		if (id.equals(tree.getAttributes()
				.get(UITree.SELECTION_INPUT_ATTRIBUTE))) {
			if (componentState.setSelected(key)) {

				if (tree.getAttributes().get(
						UITree.SELECTED_NODE_PARAMETER_NAME) == null) {

					new NodeSelectedEvent(node).queue();
					new NodeSelectedEvent(tree).queue();
				} else {
					new AjaxSelectedEvent(node).queue();
					new AjaxSelectedEvent(tree).queue();
				}
			}

			tree.getAttributes().remove(UITree.SELECTION_INPUT_ATTRIBUTE);
		}

	}

	public String getAjaxSelectedListenerFlag(FacesContext context,
			UITreeNode treeNode) throws IOException {
		if (treeNode.hasAjaxSubmitSelection()) {
			return "ajax_selected_listener_flag";
		}

		return null;
	}

	public String getParentClientId(FacesContext context, UITreeNode treeNode)
			throws IOException {
		return treeNode.getUITree().getClientId(context);
	}

	public String getDraggableScriptOptions(FacesContext context,
			UITreeNode component) {
		ScriptOptions options = new TreeNodeOptions(component);
		mergeScriptOptions(options, context, component, Draggable.class);
		return ScriptUtils.toScript(options);
	}

	public String getDropzoneScriptOptions(FacesContext context,
			UITreeNode component) {
		ScriptOptions options = new TreeNodeOptions(component);
		mergeScriptOptions(options, context, component, Dropzone.class);
		return ScriptUtils.toScript(options);
	}

	public void contributorDecodeCallback(UIComponent component,
			FacesContext context, RendererContributor contributor,
			Object argument) {
		super.contributorDecodeCallback(component, context, contributor,
				argument);

		if (Draggable.class.isAssignableFrom(contributor.getAcceptableClass())) {
			UITreeNode treeNode = (UITreeNode) component;
			treeNode.setDragValue(treeNode.getUITree().getRowKey());
		} else if (Dropzone.class.isAssignableFrom(contributor
				.getAcceptableClass())) {
			UITreeNode treeNode = (UITreeNode) component;
			treeNode.setDropValue(treeNode.getUITree().getRowKey());
		}
	}
}
