/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.renderkit.html;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GradientPaint;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.geom.Rectangle2D;
import java.io.Serializable;
import java.util.Date;

import javax.faces.context.FacesContext;

import org.ajax4jsf.framework.resource.GifRenderer;
import org.ajax4jsf.framework.resource.InternetResourceBuilder;
import org.ajax4jsf.framework.resource.Java2Dresource;
import org.ajax4jsf.framework.resource.ResourceContext;
import org.ajax4jsf.framework.skin.Skin;
import org.ajax4jsf.framework.skin.SkinFactory;
import org.ajax4jsf.framework.util.HtmlColor;
import org.ajax4jsf.framework.util.HtmlDimensions;

/**
 * @author Nick Belaevski - nbelaevski@exadel.com
 * created 02.02.2007
 * 
 */
public class BaseGradient extends Java2Dresource {

	private int width;
	private int height;
	private int gradientHeight;
	private String baseColor;
	private String gradientColor;
	
	public BaseGradient(int width, int height, int gradientHeight) {
		super();
		this.width = width;
		this.height = height;
		this.gradientHeight = gradientHeight;

		setRenderer(new GifRenderer());
		setLastModified(new Date(InternetResourceBuilder.getInstance().getStartTime()));
	}

	public BaseGradient(int width, int height, int gradientHeight, String baseColor, String gradientColor) {
		this(width, height, gradientHeight);
		this.baseColor = baseColor;
		this.gradientColor = gradientColor;
	}

	public BaseGradient(int width, int height) {
		this(width, height, height);
	}

	public BaseGradient(int width, int height, String baseColor, String gradientColor) {
		this(width, height, height);
		this.baseColor = baseColor;
		this.gradientColor = gradientColor;
	}

	public BaseGradient() {
		this(30, 50, 20);
	}
	
	public BaseGradient(String baseColor, String gradientColor) {
		this(30, 50, 20);
		this.baseColor = baseColor;
		this.gradientColor = gradientColor;
	}

	public Dimension getDimensions(FacesContext facesContext, Object data) {
		return new Dimension(width, height);
	}

	protected Dimension getDimensions(ResourceContext resourceContext) {
		return getDimensions(null, restoreData(resourceContext));
	}

	protected void paint(ResourceContext resourceContext, Graphics2D g2d) {
		g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
		g2d.setRenderingHint(RenderingHints.KEY_DITHERING, RenderingHints.VALUE_DITHER_ENABLE);
		g2d.setRenderingHint(RenderingHints.KEY_COLOR_RENDERING, RenderingHints.VALUE_COLOR_RENDER_QUALITY);
		Data dataToStore  = (Data)resourceContext.getResourceData();
		if (dataToStore.headerBackgroundColor!=null && dataToStore.headerGradientColor!=null) {
			Color baseColor = new Color(dataToStore.headerBackgroundColor.intValue());
			Dimension dim =getDimensions(resourceContext);
			Rectangle2D rect = 
				new Rectangle2D.Float(
						0, 
						0, 
						dim.width, 
						dim.height);
			int gradStart = 0;
			int gradEnd = gradientHeight;
			Color alternateColor = new Color(dataToStore.headerGradientColor.intValue());
			GradientPaint gragient = new GradientPaint(0, gradStart, baseColor, 0, gradEnd, alternateColor);
			g2d.setPaint(gragient);
			g2d.fill(rect);
		}
	}

	protected Object getDataToStore(FacesContext context, Object data) {
		if (baseColor == null) {
			return new Data(context,data);
		} else {
			return new Data(context,data,baseColor,gradientColor);
		}
	}
	
	public boolean isCacheable() {
		return true;
	}
	
	protected static class Data implements Serializable {

		public Data() {
		}
		
		protected Data(FacesContext context, Object data) {
			this.headerBackgroundColor = getColorValueParameter(context, data, Skin.headerBackgroundColor);
			this.headerGradientColor = getColorValueParameter(context, data, "headerGradientColor");
		}

		protected Data(FacesContext context, Object data, String baseColor, String gradientColor) {
			this.headerBackgroundColor = getColorValueParameter(context, data, baseColor);
			this.headerGradientColor = getColorValueParameter(context, data, gradientColor);
		}

		private Integer getColorValueParameter(FacesContext context, Object data, String name) {
			Skin skin = SkinFactory.getInstance().getSkin(context);
			String tmp = (String) skin.getParameter(context,name); 
			if (tmp!=null) {
				return new Integer(HtmlColor.decode(tmp).getRGB());
			} else {
				return null;
			}
		}
		private Integer getDimensionValueParameter(FacesContext context, Object data, String name) {
			Skin skin = SkinFactory.getInstance().getSkin(context);
			String tmp = (String) skin.getParameter(context,name); 
			if (tmp!=null) {
				return new Integer(HtmlDimensions.decode(tmp).intValue());
			} else {
				return null;
			}
		}
		private Integer getIntegerValueParameter(FacesContext context, Object data, String name) {
			Skin skin = SkinFactory.getInstance().getSkin(context);
			String tmp = (String) skin.getParameter(context,name); 
			if (tmp!=null) {
				return new Integer(tmp);
			} else {
				return null;
			}
		}
		
		/**
		 * 
		 */
		private static final long serialVersionUID = 1732700513743861250L;
		protected Integer headerBackgroundColor;
		protected Integer headerGradientColor;
	}

}
