/**
 * License Agreement.
 *
 *  JBoss RichFaces 3.0 - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */

package org.richfaces.renderkit.html;

import org.ajax4jsf.framework.ajax.AjaxContext;
import org.ajax4jsf.framework.ajax.AjaxEvent;
import org.ajax4jsf.framework.renderer.AjaxComponentRendererBase;
import org.ajax4jsf.framework.renderer.AjaxRendererUtils;
import org.ajax4jsf.framework.renderer.RendererBase;
import org.ajax4jsf.framework.renderer.RendererUtils.HTML;
import org.ajax4jsf.framework.renderer.compiler.HtmlCompiler;
import org.ajax4jsf.framework.renderer.compiler.PreparedTemplate;
import org.ajax4jsf.framework.renderer.compiler.TemplateContext;
import org.ajax4jsf.framework.resource.InternetResource;
import org.ajax4jsf.framework.resource.TemplateCSSResource;
import org.ajax4jsf.framework.skin.Skin;
import org.ajax4jsf.framework.skin.SkinFactory;
import org.ajax4jsf.framework.util.javascript.JSFunction;
import org.ajax4jsf.framework.util.javascript.JSFunctionDefinition;
import org.richfaces.component.SuggestionEvent;
import org.richfaces.component.UISuggestionBox;

import javax.faces.FacesException;
import javax.faces.component.NamingContainer;
import javax.faces.component.UIColumn;
import javax.faces.component.UIComponent;
import javax.faces.component.UIData;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;
import javax.faces.event.FacesEvent;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

public class SuggestionBoxRenderer extends AjaxComponentRendererBase {

    private static final String[] OPTIONS = {"popupClass", "popupStyle",
            "width", "height", "entryClass", "selectedClass", "param",
            "frequency", "minChars", "tokens", "rows"};

    public static final int SHADOW_DEPTH = 4;

    private InternetResource[] styles = {new TemplateCSSResource(
            "org/richfaces/renderkit/html/css/suggestionbox.xcss")};

    private final InternetResource[] additionalScripts = {
            new org.ajax4jsf.framework.resource.PrototypeScript(),
            new org.ajax4jsf.framework.resource.SmartPositionScript(),
            getResource("/org/richfaces/renderkit/html/scripts/browser_info.js"),
            getResource("scripts/scriptaculo.js"),
            getResource("scripts/suggestionbox.js")};

    private PreparedTemplate body = HtmlCompiler
            .compileResource("org/richfaces/renderkit/html/templates/table.jspx");

    private PreparedTemplate popup = HtmlCompiler
            .compileResource("org/richfaces/renderkit/html/templates/popup.jspx");

    protected Class getComponentClass() {
        return UISuggestionBox.class;
    }

    public boolean getRendersChildren() {
        return true;
    }

    /*
      * (non-Javadoc)
      *
      * @see org.ajax4jsf.framework.renderer.RendererBase#doDecode(javax.faces.context.FacesContext,
      *      javax.faces.component.UIComponent)
      */
    protected void doDecode(FacesContext context, UIComponent component) {
        String clientId = component.getClientId(context);
        Map requestParameterMap = context.getExternalContext()
		                .getRequestParameterMap();
		String reqValue = (String) requestParameterMap.get(clientId);
        if (reqValue != null && reqValue.equals(clientId)) {
            String paramName = (String) component.getAttributes().get("param");
            if (null == paramName) {
                paramName = "inputvalue";
            }
            Object elementValue = requestParameterMap.get(paramName);
            FacesEvent event = new SuggestionEvent(component, elementValue);
            component.queueEvent(event);
            component.queueEvent(new AjaxEvent(component));
        }
    }

    protected void doEncodeBegin(ResponseWriter writer, FacesContext context, UIComponent component) throws IOException {
        super.doEncodeBegin(writer, context, component);
        org.richfaces.component.util.FormUtil.throwEnclFormReqExceptionIfNeed(context, component);
    }

    protected void doEncodeEnd(ResponseWriter writer, FacesContext context,
                               UIComponent component) throws IOException {
        UISuggestionBox suggestionBox = (UISuggestionBox) component;
        if (!suggestionBox.isSubmitted()) {
            suggestionBox.setRowIndex(-1);
            writer.startElement(HTML.DIV_ELEM, component);
            getUtils().encodeId(context, component);
            Map attributes = component.getAttributes();

            StringBuffer clazz = new StringBuffer("dr-sb-common-container rich-sb-common-container");
            Object popupClass = attributes.get("popupClass");
            if (null != popupClass) {
                clazz.append(" ").append(popupClass);
            }
            writer.writeAttribute("class", clazz, "popupClass");

            StringBuffer style = new StringBuffer("display:none;z-index:100;");

            style.append(getSizeForStyle(component, "width", null, false));
            style.append(getSizeForStyle(component, "height", null, false));

            Object popupStyle = attributes.get("popupStyle");
            if (null != popupStyle) {
                style.append(popupStyle);
            }
            writer.writeAttribute("style", style, "popupStyle");

            UIComponent popupFacet = component.getFacet("popup");
            if (null == popupFacet) {
                popup.encode(this, context, component);
            } else {
                // Use facet as content of popup window
                // suggestionBox.setPopup(popupFacet.getClientId(context));
                renderChild(context, popupFacet);
            }
            writer.startElement(HTML.SCRIPT_ELEM, component);
            writer.writeText(getScript(context, component), "script");
            writer.endElement(HTML.SCRIPT_ELEM);
            writer.endElement(HTML.DIV_ELEM);
            writer.startElement("iframe", component);
            writer.writeAttribute("src",
                    getResource("/org/richfaces/renderkit/html/images/spacer.gif")
                            .getUri(context, null), null);
            writer.writeAttribute("id", component.getClientId(context)
                    + "_iframe", null);
            writer.writeAttribute("style", "position:absolute;display:none;z-index:0;", null);
            writer.endElement("iframe");
        } else {
            suggestionBox.setSubmitted(false);
        }

        // Fix for bug CH-1323.
        ((UISuggestionBox) component).setValue(null);
    }

    /*
      * (non-Javadoc)
      *
      * @see javax.faces.render.Renderer#encodeChildren(javax.faces.context.FacesContext,
      *      javax.faces.component.UIComponent)
      */
    public void encodeChildren(FacesContext context, UIComponent component)
            throws IOException {
        UISuggestionBox suggestionBox = (UISuggestionBox) component;
        if (suggestionBox.isSubmitted()) {
            body.encode(getTemplateContext(context, suggestionBox));
            // Replace rendered area ID from component to suggestion table
            suggestionBox.setRowIndex(-1);
            AjaxContext ajaxContext = AjaxContext.getCurrentInstance(context);
            ajaxContext.removeRenderedArea(component.getClientId(context));
            ajaxContext.addRenderedArea(getContentId(context, component));
        }
    }

    private UIComponent getTarget(UIComponent component)
            throws FacesException {
        String target = ((UISuggestionBox) component).getFor();
        if (null != target) {
            // Use parent since UIData - naming container
            UIComponent targetComponent = component.getParent().findComponent(
                    target);
            if (null != targetComponent) {
                return targetComponent;
            } else {
                throw new FacesException("Component for target " + target
                        + " not found in SuggestionBox " + component.getId());
            }
        } else {
            throw new FacesException("Component SuggestionBox "
                    + component.getId() + " don't have property 'for' ");
        }
    }

    private String getScript(FacesContext context, UIComponent component) {
        Map attributes = component.getAttributes();
        StringBuffer script = new StringBuffer(" new ");
        // Build ajax function call
        JSFunction submitSuggest = AjaxRendererUtils.buildAjaxFunction(
                component, context, "Exadel.Suggestion");
        UIComponent targetComponent = getTarget(component);
        submitSuggest.addParameter(targetComponent.getClientId(context));
        submitSuggest.addParameter(component.getClientId(context));
        Map options = AjaxRendererUtils.buildEventOptions(context, component);
        options.put("popup", component.getClientId(context));
        for (int i = 0; i < OPTIONS.length; i++) {
            String option = OPTIONS[i];
            Object value = attributes.get(option);
            if (null != value) {
                options.put(option, value);
            }
        }
        // If ajax queue name not set, put clientId
        String eventsQueue = (String) options.get("eventsQueue");
        if (null == eventsQueue) {
            options.put("eventsQueue", component.getClientId(context));
        }
        String onselect = (String) attributes.get("onselect");
        if (null != onselect) {
            JSFunctionDefinition function = new JSFunctionDefinition(
                    "suggestion");
            function.addParameter("event");
            function.addToBody(onselect);

            options.put("onselect", function);

        }
        if (component.getValueBinding("fetchValue") != null
                || attributes.get("fetchValue") != null) {
            options.put("select", attributes.get("selectValueClass"));
        }

        submitSuggest.addParameter(options);
        script.append(submitSuggest.toScript()).append(";\n");
        return script.toString();
    }

    private TemplateContext getTemplateContext(FacesContext context, UIData data) {
        data.setRowIndex(-1);
        return new DataTemplateContext(this, context, data);
    }

    /**
     * Special html templates context class with pre-defined properties for
     * iterations over rows and columns.
     *
     * @author shura (latest modification by $Author: alexsmirnov $)
     * @version $Revision: 1.20 $ $Date: 2007/03/01 22:37:49 $
     */
    private static class DataTemplateContext extends TemplateContext {

        private List columns;

        private int _first;

        private int _last;

        private int _rows;

        private int _rowCount;

        private int _current;

        private String[] _rowClasses = new String[0];

        private String _entryClass;

        /**
         * @param renderer
         * @param facesContext
         * @param component
         */
        public DataTemplateContext(RendererBase renderer,
                                   FacesContext facesContext, UIComponent component) {
            super(renderer, facesContext, component);
            if (component.getFacet("head") != null) {
                this.putParameter("hasHead", Boolean.TRUE);
            }
            if (component.getFacet("head") != null) {
                this.putParameter("hasHead", Boolean.TRUE);
            }
            // Fill child columns components
            columns = new ArrayList(component.getChildCount());
            for (Iterator iter = component.getChildren().iterator(); iter
                    .hasNext();) {
                UIComponent column = (UIComponent) iter.next();
                if (column instanceof UIColumn) {
                    columns.add(column);
                    if (column.getFacet("head") != null) {
                        this.putParameter("hasHead", Boolean.TRUE);
                        this.putParameter("hasColumnHead", Boolean.TRUE);
                    }
                    if (column.getFacet("footer") != null) {
                        this.putParameter("hasFooter", Boolean.TRUE);
                        this.putParameter("hasColumnFooter", Boolean.TRUE);
                    }
                }
            }
            // fill rows counters
            UISuggestionBox box = (UISuggestionBox) component;
            this._first = box.getFirst();
            this._rows = box.getRows();
            this._rowCount = box.getRowCount();
            // return all records; CH-1330
            if (_rows <= 0 || true) {
                _rows = _rowCount - _first;
            }
            _last = _first + _rows;
            if (_last > _rowCount) {
                _last = _rowCount;
            }
            _current = _first;
            // rows classes
            _entryClass = box.getEntryClass();
            String rowClasses = box.getRowClasses();
            if (null != rowClasses && rowClasses.length() > 0) {
                _rowClasses = rowClasses.split("\\s+");
            }

        }

        /*
           * (non-Javadoc)
           *
           * @see org.ajax4jsf.framework.renderer.compiler.TemplateContext#getParameter(java.lang.Object)
           */
        public Object getParameter(Object key) {
            if ("rows".equals(key)) {
                // Iterate over rows in datatable
                return new Iterator() {

                    public boolean hasNext() {
                        if (_current >= _last) {
                            return false;
                        }
                        UIData data = ((UIData) getComponent());
                        data.setRowIndex(_current);
                        return data.isRowAvailable();
                    }

                    public Object next() {
                        // TODO reset rows and columns classes counters
                        _current++;
                        return getComponent();
                    }

                    public void remove() {
                        throw new UnsupportedOperationException(
                                "remove row from UIData not supported");
                    }

                };
            } else if ("rowClass".equals(key)) {
                // Build row class string from entryClass and row classes
                StringBuffer rowClass = new StringBuffer();
                if (null != _entryClass) {
                    rowClass.append(_entryClass);
                    if (_rowClasses.length > 0) {
                        rowClass.append(" ");
                    }
                }
                if (_rowClasses.length > 0) {
                    int currentClass = (_current - _first - 1)
                            % _rowClasses.length;
                    if (currentClass < 0)
                        currentClass = 0;
                    rowClass.append(_rowClasses[currentClass]);
                }
                // for iterate over columns
                return rowClass.toString();
            } else if ("columns".equals(key)) {
                // for iterate over columns
                return columns;
            } else if ("columnsCount".equals(key)) {
                return Integer.valueOf(columns.size());
            } else {
                return super.getParameter(key);
            }
        }

    }

    public String opacityStyle(FacesContext context, UIComponent component) {
        String opacity = (String) component.getAttributes().get("shadowOpacity");
        String filterOpacity;

        if (null == opacity) {
            Skin skin = SkinFactory.getInstance().getSkin(context);
            opacity = (String) skin.getParameter(context, "shadowOpacity");
        }
        try {
            Double op = Double.valueOf(opacity);
            filterOpacity = Integer.toString(op.intValue() * 10);
            opacity = Double.toString(op.doubleValue() / 10);
        } catch (Exception e) {
            // illegal opacity
            return ";";
        }
        return "opacity:" + opacity + "; filter:alpha(opacity=" + filterOpacity + ");";
    }

    public String border(FacesContext context, UIComponent component) {

        String border = (String) component.getAttributes().get("border");

        String frame = (String) component.getAttributes().get("frame");
        if (null == frame)
            frame = "box";
        StringBuffer stringBuffer = new StringBuffer();

        if (null != border && Pattern.matches("\\d*", border))
            border += "px";
        /*
           * if (null == border || !Pattern.matches("\\d*px", border)) { Skin skin =
           * SkinFactory.getInstance().getSkin(context); border = (String)
           * skin.getParameter(context, "suggestionbox.borderWidth"); }
           */

        boolean top = false, right = false, bottom = false, left = false;
        if (frame.equalsIgnoreCase("above"))
            top = true;
            // else if (frame.equalsIgnoreCase("border") |
            // frame.equalsIgnoreCase("box")) top=right=bottom=left=true;
        else if (frame.equalsIgnoreCase("below"))
            bottom = true;
        else if (frame.equalsIgnoreCase("hsides"))
            top = bottom = true;
        else if (frame.equalsIgnoreCase("lhs"))
            left = true;
        else if (frame.equalsIgnoreCase("rhs"))
            right = true;
        else if (frame.equalsIgnoreCase("vsides"))
            right = left = true;
        else
            top = right = bottom = left = true;
        stringBuffer.append("; border-width:");
        if (top)
            stringBuffer.append(" ").append(border).append(" ");
        else
            stringBuffer.append(" 0px ");
        if (right)
            stringBuffer.append(" ").append(border).append(" ");
        else
            stringBuffer.append(" 0px ");
        if (bottom)
            stringBuffer.append(" ").append(border).append(" ");
        else
            stringBuffer.append(" 0px ");
        if (left)
            stringBuffer.append(" ").append(border).append(" ");
        else
            stringBuffer.append(" 0px ");
        stringBuffer.append(";");
        return stringBuffer.toString();
    }

    public String bgcolor(FacesContext context, UIComponent component) {
        String bgcolor = (String) component.getAttributes().get("bgcolor");
        if (bgcolor != null) {
            return "background-color: " + bgcolor + ";";
        }
        return ";";
    }

    public String cellPadding(FacesContext context, UIComponent component) {
    	UISuggestionBox box = (UISuggestionBox)component;
    	String cp = box.getCellpadding();
        if (cp != null) {
            return "padding: " + getUtils().encodePctOrPx(cp) + ";";
        }
        return ";";
    }

    public String getContentId(FacesContext context, UIComponent component) {
        return component.getClientId(context) + NamingContainer.SEPARATOR_CHAR + "suggest";
    }

    public String overflowSize(FacesContext context, UIComponent component) {
        StringBuffer style = new StringBuffer();

        style.append(getSizeForStyle(component, "width", null, true));
        style.append(getSizeForStyle(component, "height", null, true));

        return style.toString();
    }


    public String shadowDepth(FacesContext context, UIComponent component) {
        String shadow = (String) component.getAttributes().get("shadowDepth");
        if (shadow == null) {
            shadow = Integer.toString(SHADOW_DEPTH);
        }

        return "top: " + shadow + "; left: " + shadow;
    }

    /*
      * (non-Javadoc)
      *
      * @see org.ajax4jsf.framework.renderer.AjaxComponentRendererBase#getAdditionalScripts()
      */
    protected InternetResource[] getAdditionalScripts() {
        // TODO Auto-generated method stub
        return additionalScripts;
    }

    /*
      * (non-Javadoc)
      *
      * @see org.ajax4jsf.framework.renderer.HeaderResourcesRendererBase#getStyles()
      */
    protected InternetResource[] getStyles() {
        // TODO Auto-generated method stub
        return styles;
    }

    private String getSizeForStyle(UIComponent component, String attr, String def, boolean isShadow) {
        Map attributes = component.getAttributes();
        StringBuffer style = new StringBuffer();

        String attribute = (String) attributes.get(attr);
        if (attribute == null && def != null) {
            attribute = def;
        }

        if (attribute != null) {
            if (isShadow) {
                attribute = String.valueOf(Integer.parseInt(attribute) - SHADOW_DEPTH);
            }

            style.append(attr).append(":").append(attribute);
            if (Pattern.matches("\\d*", attribute)) {
                style.append("px");
            }
            style.append(";");
        }

        return style.toString();
    }
}
